@@ -11,8 +11,8 @@ version_added: 1.0.0
 short_description: Create and optionally attach an Elastic Network Interface (ENI) to an instance
 description:
   - Create and optionally attach an Elastic Network Interface (ENI) to an instance.
-  - If I(eni_id) or I(private_ip) is provided, the existing ENI (if any) will be modified.
-  - The I(attached) parameter controls the attachment status of the network interface.
+  - If O(eni_id) or O(private_ip_address) is provided, the existing ENI (if any) will be modified.
+  - The O(attached) parameter controls the attachment status of the network interface.
 author:
   - "Rob White (@wimnat)"
   - "Mike Healey (@healem)"
@@ -20,7 +20,7 @@ options:
   eni_id:
     description:
       - The ID of the ENI (to modify).
-      - If I(eni_id=None) and I(state=present), a new ENI will be created.
+      - If O(eni_id=None) and O(state=present), a new ENI will be created.
     type: str
   instance_id:
     description:
@@ -41,7 +41,7 @@ options:
   security_groups:
     description:
       - List of security groups associated with the interface.
-      - Ignored when I(state=absent).
+      - Ignored when O(state=absent).
     type: list
     elements: str
     default: []
@@ -63,8 +63,8 @@ options:
     type: bool
   force_detach:
     description:
-      - Force detachment of the interface. This applies either when explicitly detaching the interface by setting I(instance_id=None)
-        or when deleting an interface with I(state=absent).
+      - Force detachment of the interface. This applies either when explicitly detaching the interface by setting O(instance_id=None)
+        or when deleting an interface with O(state=absent).
     default: false
     type: bool
   delete_on_termination:
@@ -82,20 +82,20 @@ options:
   secondary_private_ip_addresses:
     description:
       - A list of IP addresses to assign as secondary IP addresses to the network interface.
-      - This option is mutually exclusive of I(secondary_private_ip_address_count).
+      - This option is mutually exclusive of O(secondary_private_ip_address_count).
     required: false
     type: list
     elements: str
   purge_secondary_private_ip_addresses:
     description:
-      - To be used with I(secondary_private_ip_addresses) to determine whether or not to remove any secondary IP addresses other than those specified.
-      - Set I(secondary_private_ip_addresses=[]) to purge all secondary addresses.
+      - To be used with O(secondary_private_ip_addresses) to determine whether or not to remove any secondary IP addresses other than those specified.
+      - Set O(secondary_private_ip_addresses=[]) to purge all secondary addresses.
     default: false
     type: bool
   secondary_private_ip_address_count:
     description:
       - The number of secondary IP addresses to assign to the network interface.
-      - This option is mutually exclusive of I(secondary_private_ip_addresses).
+      - This option is mutually exclusive of O(secondary_private_ip_addresses).
     required: false
     type: int
   allow_reassignment:
@@ -107,10 +107,10 @@ options:
     type: bool
   name:
     description:
-      - Name for the ENI. This will create a tag with the key C(Name) and the value assigned here.
-      - This can be used in conjunction with I(subnet_id) as another means of identifiying a network interface.
-      - AWS does not enforce unique C(Name) tags, so duplicate names are possible if you configure it that way.
-        If that is the case, you will need to provide other identifying information such as I(private_ip_address) or I(eni_id).
+      - Name for the ENI. This will create a tag with the key V(Name) and the value assigned here.
+      - This can be used in conjunction with O(subnet_id) as another means of identifiying a network interface.
+      - AWS does not enforce unique V(Name) tags, so duplicate names are possible if you configure it that way.
+        If that is the case, you will need to provide other identifying information such as O(private_ip_address) or O(eni_id).
     required: false
     type: str
 extends_documentation_fragment:
@@ -119,9 +119,9 @@ extends_documentation_fragment:
   - amazon.aws.tags
   - amazon.aws.boto3
 notes:
-  - This module identifies and ENI based on either the I(eni_id), a combination of I(private_ip_address) and I(subnet_id),
-    or a combination of I(instance_id) and I(device_id). Any of these options will let you specify a particular ENI.
-  - Support for I(tags) and I(purge_tags) was added in release 1.3.0.
+  - This module identifies and ENI based on either the O(eni_id), a combination of O(private_ip_address) and O(subnet_id),
+    or a combination of O(instance_id) and O(device_index). Any of these options will let you specify a particular ENI.
+  - Support for O(tags) and O(purge_tags) was added in release 1.3.0.
 """
 
 EXAMPLES = r"""
@@ -213,62 +213,72 @@ EXAMPLES = r"""
 
 RETURN = r"""
 interface:
-  description: Network interface attributes
+  description: Network interface attributes.
   returned: when state != absent
   type: complex
   contains:
+    attachment:
+      description: The network interface attachment.
+      type: dict
+      sample: {
+            "attach_time": "2024-04-25T20:57:20+00:00",
+            "attachment_id": "eni-attach-0ddce58b341a1846f",
+            "delete_on_termination": true,
+            "device_index": 0,
+            "instance_id": "i-032cb1cceb29250d2",
+            "status": "attached"
+        }
     description:
-      description: interface description
+      description: Interface description.
       type: str
       sample: Firewall network interface
     groups:
-      description: list of security groups
-      type: list
-      elements: dict
-      sample: [ { "sg-f8a8a9da": "default" } ]
+      description: Dict of security groups.
+      type: dict
+      sample: { "sg-f8a8a9da": "default" }
     id:
-      description: network interface id
+      description: Network interface id.
       type: str
       sample: "eni-1d889198"
     mac_address:
-      description: interface's physical address
+      description: Interface's physical address.
       type: str
       sample: "00:00:5E:00:53:23"
     name:
-      description: The name of the ENI
+      description: The name of the ENI.
       type: str
       sample: "my-eni-20"
     owner_id:
-      description: aws account id
+      description: AWS account id.
       type: str
       sample: 812381371
     private_ip_address:
-      description: primary ip address of this interface
+      description: Primary ip address of this interface.
       type: str
       sample: 10.20.30.40
     private_ip_addresses:
-      description: list of all private ip addresses associated to this interface
+      description: List of all private ip addresses associated to this interface.
       type: list
       elements: dict
       sample: [ { "primary_address": true, "private_ip_address": "10.20.30.40" } ]
     source_dest_check:
-      description: value of source/dest check flag
+      description: Value of source/dest check flag.
       type: bool
       sample: True
     status:
-      description: network interface status
+      description: Network interface status.
       type: str
       sample: "pending"
     subnet_id:
-      description: which vpc subnet the interface is bound
+      description: Which vpc subnet the interface is bound.
       type: str
       sample: subnet-b0a0393c
     tags:
-      description: The dictionary of tags associated with the ENI
+      description: The dictionary of tags associated with the ENI.
       type: dict
       sample: { "Name": "my-eni", "group": "Finance" }
     vpc_id:
-      description: which vpc this network interface is bound
+      description: Which vpc this network interface is bound.
       type: str
       sample: vpc-9a9a9da
 """
@@ -277,19 +287,22 @@ import time
 from ipaddress import ip_address
 from ipaddress import ip_network
 
-try:
-    import botocore.exceptions
-except ImportError:
-    pass  # Handled by AnsibleAWSModule
-
-from ansible_collections.amazon.aws.plugins.module_utils.botocore import is_boto3_error_code
+from ansible_collections.amazon.aws.plugins.module_utils.ec2 import AnsibleEC2Error
+from ansible_collections.amazon.aws.plugins.module_utils.ec2 import assign_private_ip_addresses
+from ansible_collections.amazon.aws.plugins.module_utils.ec2 import attach_network_interface
+from ansible_collections.amazon.aws.plugins.module_utils.ec2 import create_network_interface
+from ansible_collections.amazon.aws.plugins.module_utils.ec2 import delete_network_interface
+from ansible_collections.amazon.aws.plugins.module_utils.ec2 import describe_network_interfaces
+from ansible_collections.amazon.aws.plugins.module_utils.ec2 import describe_subnets
+from ansible_collections.amazon.aws.plugins.module_utils.ec2 import detach_network_interface
 from ansible_collections.amazon.aws.plugins.module_utils.ec2 import ensure_ec2_tags
 from ansible_collections.amazon.aws.plugins.module_utils.ec2 import get_ec2_security_group_ids_from_names
+from ansible_collections.amazon.aws.plugins.module_utils.ec2 import modify_network_interface_attribute
+from ansible_collections.amazon.aws.plugins.module_utils.ec2 import unassign_private_ip_addresses
 from ansible_collections.amazon.aws.plugins.module_utils.modules import AnsibleAWSModule
-from ansible_collections.amazon.aws.plugins.module_utils.retries import AWSRetry
 from ansible_collections.amazon.aws.plugins.module_utils.tagging import boto3_tag_list_to_ansible_dict
 from ansible_collections.amazon.aws.plugins.module_utils.tagging import boto3_tag_specifications
-from ansible_collections.amazon.aws.plugins.module_utils.waiters import get_waiter
+from ansible_collections.amazon.aws.plugins.module_utils.waiters import wait_for_resource_state
 
 
 def get_eni_info(interface):
@@ -368,10 +381,7 @@ def correct_ip_count(connection, ip_count, module, eni_id):
         for ip in eni["PrivateIpAddresses"]:
             private_addresses.add(ip["PrivateIpAddress"])
 
-    if len(private_addresses) == ip_count:
-        return True
-    else:
-        return False
+    return bool(len(private_addresses) == ip_count)
 
 
 def wait_for(function_pointer, *args):
@@ -407,76 +417,79 @@ def create_eni(connection, vpc_id, module):
     if name:
         tags["Name"] = name
 
+    args = {"SubnetId": subnet_id}
+    if private_ip_address:
+        args["PrivateIpAddress"] = private_ip_address
+    if description:
+        args["Description"] = description
+    if len(security_groups) > 0:
+        args["Groups"] = security_groups
+    if tags:
+        args["TagSpecifications"] = boto3_tag_specifications(tags, types="network-interface")
+
+    # check if provided private_ip_address is within the subnet's address range
+    if private_ip_address:
+        try:
+            cidr_block = describe_subnets(connection, SubnetIds=[str(subnet_id)])[0]["CidrBlock"]
+        except AnsibleEC2Error as e:
+            module.fail_json_aws_error(e)
+        valid_private_ip = ip_address(private_ip_address) in ip_network(cidr_block)
+        if not valid_private_ip:
+            module.fail_json(
+                changed=False,
+                msg="Error: cannot create ENI - Address does not fall within the subnet's address range.",
+            )
+    if module.check_mode:
+        module.exit_json(changed=True, msg="Would have created ENI if not in check mode.")
+
     try:
-        args = {"SubnetId": subnet_id}
-        if private_ip_address:
-            args["PrivateIpAddress"] = private_ip_address
-        if description:
-            args["Description"] = description
-        if len(security_groups) > 0:
-            args["Groups"] = security_groups
-        if tags:
-            args["TagSpecifications"] = boto3_tag_specifications(tags, types="network-interface")
+        eni = create_network_interface(connection, **args)
+    except AnsibleEC2Error as e:
+        module.fail_json_aws_error(e)
+    # Once we have an ID make sure we're always modifying the same object
+    eni_id = eni["NetworkInterfaceId"]
+    wait_for_resource_state(connection, module, "network_interface_available", NetworkInterfaceIds=[eni_id])
 
-        # check if provided private_ip_address is within the subnet's address range
-        if private_ip_address:
-            cidr_block = connection.describe_subnets(SubnetIds=[str(subnet_id)])["Subnets"][0]["CidrBlock"]
-            valid_private_ip = ip_address(private_ip_address) in ip_network(cidr_block)
-            if not valid_private_ip:
-                module.fail_json(
-                    changed=False,
-                    msg="Error: cannot create ENI - Address does not fall within the subnet's address range.",
-                )
-        if module.check_mode:
-            module.exit_json(changed=True, msg="Would have created ENI if not in check mode.")
+    if attached and instance_id is not None:
+        try:
+            attach_network_interface(
+                connection,
+                InstanceId=instance_id,
+                DeviceIndex=device_index,
+                NetworkInterfaceId=eni["NetworkInterfaceId"],
+            )
+        except AnsibleEC2Error as e:
+            delete_network_interface(connection, eni_id)
+            module.fail_json_aws_error(e)
+        wait_for_resource_state(connection, module, "network_interface_attached", NetworkInterfaceIds=[eni_id])
 
-        eni_dict = connection.create_network_interface(aws_retry=True, **args)
-        eni = eni_dict["NetworkInterface"]
-        # Once we have an ID make sure we're always modifying the same object
-        eni_id = eni["NetworkInterfaceId"]
-        get_waiter(connection, "network_interface_available").wait(NetworkInterfaceIds=[eni_id])
+    if secondary_private_ip_address_count is not None:
+        try:
+            assign_private_ip_addresses(
+                connection,
+                NetworkInterfaceId=eni["NetworkInterfaceId"],
+                SecondaryPrivateIpAddressCount=secondary_private_ip_address_count,
+            )
+            wait_for(correct_ip_count, connection, secondary_private_ip_address_count, module, eni_id)
+        except AnsibleEC2Error as e:
+            delete_network_interface(connection, eni_id)
+            module.fail_json_aws_error(e)
 
-        if attached and instance_id is not None:
-            try:
-                connection.attach_network_interface(
-                    aws_retry=True,
-                    InstanceId=instance_id,
-                    DeviceIndex=device_index,
-                    NetworkInterfaceId=eni["NetworkInterfaceId"],
-                )
-            except (botocore.exceptions.ClientError, botocore.exceptions.BotoCoreError):
-                connection.delete_network_interface(aws_retry=True, NetworkInterfaceId=eni_id)
-                raise
-            get_waiter(connection, "network_interface_attached").wait(NetworkInterfaceIds=[eni_id])
+    if secondary_private_ip_addresses is not None:
+        try:
+            assign_private_ip_addresses(
+                connection,
+                NetworkInterfaceId=eni["NetworkInterfaceId"],
+                PrivateIpAddresses=secondary_private_ip_addresses,
+            )
+            wait_for(correct_ips, connection, secondary_private_ip_addresses, module, eni_id)
+        except AnsibleEC2Error as e:
+            delete_network_interface(connection, eni_id)
+            module.fail_json_aws_error(e)
 
-        if secondary_private_ip_address_count is not None:
-            try:
-                connection.assign_private_ip_addresses(
-                    aws_retry=True,
-                    NetworkInterfaceId=eni["NetworkInterfaceId"],
-                    SecondaryPrivateIpAddressCount=secondary_private_ip_address_count,
-                )
-                wait_for(correct_ip_count, connection, secondary_private_ip_address_count, module, eni_id)
-            except (botocore.exceptions.ClientError, botocore.exceptions.BotoCoreError):
-                connection.delete_network_interface(aws_retry=True, NetworkInterfaceId=eni_id)
-                raise
-
-        if secondary_private_ip_addresses is not None:
-            try:
-                connection.assign_private_ip_addresses(
-                    NetworkInterfaceId=eni["NetworkInterfaceId"], PrivateIpAddresses=secondary_private_ip_addresses
-                )
-                wait_for(correct_ips, connection, secondary_private_ip_addresses, module, eni_id)
-            except (botocore.exceptions.ClientError, botocore.exceptions.BotoCoreError):
-                connection.delete_network_interface(aws_retry=True, NetworkInterfaceId=eni_id)
-                raise
-
-        # Refresh the eni data
-        eni = describe_eni(connection, module, eni_id)
-        changed = True
-
-    except (botocore.exceptions.ClientError, botocore.exceptions.BotoCoreError) as e:
-        module.fail_json_aws(e, f"Failed to create eni {name} for {subnet_id} in {vpc_id} with {private_ip_address}")
+    # Refresh the eni data
+    eni = describe_eni(connection, module, eni_id)
+    changed = True
 
     module.exit_json(changed=changed, interface=get_eni_info(eni))
 
@@ -505,30 +518,28 @@ def modify_eni(connection, module, eni):
         if description is not None:
             if "Description" not in eni or eni["Description"] != description:
                 if not module.check_mode:
-                    connection.modify_network_interface_attribute(
-                        aws_retry=True, NetworkInterfaceId=eni_id, Description={"Value": description}
+                    modify_network_interface_attribute(
+                        connection, NetworkInterfaceId=eni_id, Description={"Value": description}
                     )
                 changed = True
         if len(security_groups) > 0:
             groups = get_ec2_security_group_ids_from_names(security_groups, connection, vpc_id=eni["VpcId"])
             if sorted(get_sec_group_list(eni["Groups"])) != sorted(groups):
                 if not module.check_mode:
-                    connection.modify_network_interface_attribute(
-                        aws_retry=True, NetworkInterfaceId=eni_id, Groups=groups
-                    )
+                    modify_network_interface_attribute(connection, NetworkInterfaceId=eni_id, Groups=groups)
                 changed = True
         if source_dest_check is not None:
             if "SourceDestCheck" not in eni or eni["SourceDestCheck"] != source_dest_check:
                 if not module.check_mode:
-                    connection.modify_network_interface_attribute(
-                        aws_retry=True, NetworkInterfaceId=eni_id, SourceDestCheck={"Value": source_dest_check}
+                    modify_network_interface_attribute(
+                        connection, NetworkInterfaceId=eni_id, SourceDestCheck={"Value": source_dest_check}
                     )
                 changed = True
         if delete_on_termination is not None and "Attachment" in eni:
             if eni["Attachment"]["DeleteOnTermination"] is not delete_on_termination:
                 if not module.check_mode:
-                    connection.modify_network_interface_attribute(
-                        aws_retry=True,
+                    modify_network_interface_attribute(
+                        connection,
                         NetworkInterfaceId=eni_id,
                         Attachment={
                             "AttachmentId": eni["Attachment"]["AttachmentId"],
@@ -539,7 +550,7 @@ def modify_eni(connection, module, eni):
                         waiter = "network_interface_delete_on_terminate"
                     else:
                         waiter = "network_interface_no_delete_on_terminate"
-                    get_waiter(connection, waiter).wait(NetworkInterfaceIds=[eni_id])
+                    wait_for_resource_state(connection, module, waiter, NetworkInterfaceIds=[eni_id])
                 changed = True
 
         current_secondary_addresses = []
@@ -550,8 +561,8 @@ def modify_eni(connection, module, eni):
             secondary_addresses_to_remove = list(set(current_secondary_addresses) - set(secondary_private_ip_addresses))
             if secondary_addresses_to_remove and purge_secondary_private_ip_addresses:
                 if not module.check_mode:
-                    connection.unassign_private_ip_addresses(
-                        aws_retry=True,
+                    unassign_private_ip_addresses(
+                        connection,
                         NetworkInterfaceId=eni_id,
                         PrivateIpAddresses=list(set(current_secondary_addresses) - set(secondary_private_ip_addresses)),
                     )
@@ -560,8 +571,8 @@ def modify_eni(connection, module, eni):
             secondary_addresses_to_add = list(set(secondary_private_ip_addresses) - set(current_secondary_addresses))
             if secondary_addresses_to_add:
                 if not module.check_mode:
-                    connection.assign_private_ip_addresses(
-                        aws_retry=True,
+                    assign_private_ip_addresses(
+                        connection,
                         NetworkInterfaceId=eni_id,
                         PrivateIpAddresses=secondary_addresses_to_add,
                         AllowReassignment=allow_reassignment,
@@ -573,8 +584,8 @@ def modify_eni(connection, module, eni):
             current_secondary_address_count = len(current_secondary_addresses)
             if secondary_private_ip_address_count > current_secondary_address_count:
                 if not module.check_mode:
-                    connection.assign_private_ip_addresses(
-                        aws_retry=True,
+                    assign_private_ip_addresses(
+                        connection,
                         NetworkInterfaceId=eni_id,
                         SecondaryPrivateIpAddressCount=(
                             secondary_private_ip_address_count - current_secondary_address_count
@@ -589,8 +600,8 @@ def modify_eni(connection, module, eni):
                     secondary_addresses_to_remove_count = (
                         current_secondary_address_count - secondary_private_ip_address_count
                     )
-                    connection.unassign_private_ip_addresses(
-                        aws_retry=True,
+                    unassign_private_ip_addresses(
+                        connection,
                         NetworkInterfaceId=eni_id,
                         PrivateIpAddresses=current_secondary_addresses[:secondary_addresses_to_remove_count],
                     )
@@ -601,33 +612,37 @@ def modify_eni(connection, module, eni):
             if "Attachment" in eni and eni["Attachment"]["InstanceId"] != instance_id:
                 if not module.check_mode:
                     detach_eni(connection, eni, module)
-                    connection.attach_network_interface(
-                        aws_retry=True,
+                    attach_network_interface(
+                        connection,
                         InstanceId=instance_id,
                         DeviceIndex=device_index,
                         NetworkInterfaceId=eni_id,
                     )
-                    get_waiter(connection, "network_interface_attached").wait(NetworkInterfaceIds=[eni_id])
+                    wait_for_resource_state(
+                        connection, module, "network_interface_attached", NetworkInterfaceIds=[eni_id]
+                    )
                 changed = True
             if "Attachment" not in eni:
                 if not module.check_mode:
-                    connection.attach_network_interface(
-                        aws_retry=True,
+                    attach_network_interface(
+                        connection,
                         InstanceId=instance_id,
                         DeviceIndex=device_index,
                         NetworkInterfaceId=eni_id,
                     )
-                    get_waiter(connection, "network_interface_attached").wait(NetworkInterfaceIds=[eni_id])
+                    wait_for_resource_state(
+                        connection, module, "network_interface_attached", NetworkInterfaceIds=[eni_id]
+                    )
                 changed = True
 
         elif attached is False:
             changed |= detach_eni(connection, eni, module)
-            get_waiter(connection, "network_interface_available").wait(NetworkInterfaceIds=[eni_id])
+            wait_for_resource_state(connection, module, "network_interface_available", NetworkInterfaceIds=[eni_id])
 
         changed |= manage_tags(connection, module, eni, name, tags, purge_tags)
 
-    except (botocore.exceptions.ClientError, botocore.exceptions.BotoCoreError) as e:
-        module.fail_json_aws(e, f"Failed to modify eni {eni_id}")
+    except AnsibleEC2Error as e:
+        module.fail_json_aws_error(e)
 
     eni = describe_eni(connection, module, eni_id)
     if module.check_mode and changed:
@@ -637,16 +652,6 @@ def modify_eni(connection, module, eni):
     module.exit_json(changed=changed, interface=get_eni_info(eni))
 
 
-def _wait_for_detach(connection, module, eni_id):
-    try:
-        get_waiter(connection, "network_interface_available").wait(
-            NetworkInterfaceIds=[eni_id],
-            WaiterConfig={"Delay": 5, "MaxAttempts": 80},
-        )
-    except botocore.exceptions.WaiterError as e:
-        module.fail_json_aws(e, f"Timeout waiting for ENI {eni_id} to detach")
-
-
 def delete_eni(connection, module):
     eni = uniquely_find_eni(connection, module)
     if not eni:
@@ -661,26 +666,26 @@ def delete_eni(connection, module):
     try:
         if force_detach is True:
             if "Attachment" in eni:
-                connection.detach_network_interface(
-                    aws_retry=True,
-                    AttachmentId=eni["Attachment"]["AttachmentId"],
-                    Force=True,
+                detach_network_interface(
+                    connection,
+                    attachment_id=eni["Attachment"]["AttachmentId"],
+                    force=True,
                 )
-                _wait_for_detach(connection, module, eni_id)
-            connection.delete_network_interface(aws_retry=True, NetworkInterfaceId=eni_id)
-            changed = True
+                wait_for_resource_state(
+                    connection,
+                    module,
+                    "network_interface_available",
+                    delay=5,
+                    max_attempts=80,
+                    NetworkInterfaceIds=[eni_id],
+                )
+            changed = delete_network_interface(connection, eni_id)
         else:
-            connection.delete_network_interface(aws_retry=True, NetworkInterfaceId=eni_id)
-            changed = True
+            changed = delete_network_interface(connection, eni_id)
 
         module.exit_json(changed=changed)
-    except is_boto3_error_code("InvalidNetworkInterfaceID.NotFound"):
-        module.exit_json(changed=False)
-    except (
-        botocore.exceptions.ClientError,
-        botocore.exceptions.BotoCoreError,
-    ) as e:  # pylint: disable=duplicate-except
-        module.fail_json_aws(e, f"Failure during delete of {eni_id}")
+    except AnsibleEC2Error as e:
+        module.fail_json_aws_error(e)
 
 
 def detach_eni(connection, eni, module):
@@ -691,12 +696,14 @@ def detach_eni(connection, eni, module):
 
     force_detach = module.params.get("force_detach")
     if "Attachment" in eni:
-        connection.detach_network_interface(
-            aws_retry=True,
-            AttachmentId=eni["Attachment"]["AttachmentId"],
-            Force=force_detach,
+        detach_network_interface(
+            connection,
+            attachment_id=eni["Attachment"]["AttachmentId"],
+            force=force_detach,
+        )
+        wait_for_resource_state(
+            connection, module, "network_interface_available", delay=5, max_attempts=80, NetworkInterfaceIds=[eni_id]
         )
-        _wait_for_detach(connection, module, eni_id)
         return True
 
     return False
@@ -704,13 +711,13 @@ def detach_eni(connection, eni, module):
 
 def describe_eni(connection, module, eni_id):
     try:
-        eni_result = connection.describe_network_interfaces(aws_retry=True, NetworkInterfaceIds=[eni_id])
-        if eni_result["NetworkInterfaces"]:
-            return eni_result["NetworkInterfaces"][0]
-        else:
-            return None
-    except (botocore.exceptions.ClientError, botocore.exceptions.BotoCoreError) as e:
-        module.fail_json_aws(e, f"Failed to describe eni with id: {eni_id}")
+        result = None
+        enis = describe_network_interfaces(connection, NetworkInterfaceIds=[eni_id])
+        if enis:
+            result = enis[0]
+        return result
+    except AnsibleEC2Error as e:
+        module.fail_json_aws_error(e)
 
 
 def uniquely_find_eni(connection, module, eni=None):
@@ -755,15 +762,13 @@ def uniquely_find_eni(connection, module, eni=None):
         return None
 
     try:
-        eni_result = connection.describe_network_interfaces(aws_retry=True, Filters=filters)["NetworkInterfaces"]
-        if len(eni_result) == 1:
-            return eni_result[0]
-        else:
-            return None
-    except (botocore.exceptions.ClientError, botocore.exceptions.BotoCoreError) as e:
-        module.fail_json_aws(e, f"Failed to find unique eni with filters: {filters}")
-
-    return None
+        result = None
+        enis = describe_network_interfaces(connection, Filters=filters)
+        if len(enis) == 1:
+            result = enis[0]
+        return result
+    except AnsibleEC2Error as e:
+        module.fail_json_aws_error(e)
 
 
 def get_sec_group_list(groups):
@@ -777,10 +782,9 @@ def get_sec_group_list(groups):
 
 def _get_vpc_id(connection, module, subnet_id):
     try:
-        subnets = connection.describe_subnets(aws_retry=True, SubnetIds=[subnet_id])
-        return subnets["Subnets"][0]["VpcId"]
-    except (botocore.exceptions.ClientError, botocore.exceptions.BotoCoreError) as e:
-        module.fail_json_aws(e, f"Failed to get vpc_id for {subnet_id}")
+        return describe_subnets(connection, SubnetIds=[subnet_id])[0]["VpcId"]
+    except AnsibleEC2Error as e:
+        module.fail_json_aws_error(e)
 
 
 def manage_tags(connection, module, eni, name, tags, purge_tags):
@@ -833,10 +837,7 @@ def main():
         supports_check_mode=True,
     )
 
-    retry_decorator = AWSRetry.jittered_backoff(
-        catch_extra_error_codes=["IncorrectState"],
-    )
-    connection = module.client("ec2", retry_decorator=retry_decorator)
+    connection = module.client("ec2")
     state = module.params.get("state")
 
     if state == "present":
