@@ -7,41 +7,31 @@
 DOCUMENTATION = r"""
 ---
 module: assign_to_site_apply
-short_description: Resource module for Assign To Site
-  Apply
+short_description: Resource module for Assign To Site Apply
 description:
-  - Manage operation create of the resource Assign To
-    Site Apply. - > Assign unprovisioned network devices
-    to a site. Along with that it can also be used to
-    assign unprovisioned network devices to a different
-    site. If device controllability is enabled, it will
-    be triggered once device assigned to site successfully.
-    Device Controllability can be enabled/disabled using
-    `/dna/intent/api/v1/networkDevices/deviceControllability/settings`.
+  - Manage operation create of the resource Assign To Site Apply. - > Assign unprovisioned network devices to a site. Along
+    with that it can also be used to assign unprovisioned network devices to a different site. If device controllability is
+    enabled, it will be triggered once device assigned to site successfully. Device Controllability can be enabled/disabled
+    using `/dna/intent/api/v1/networkDevices/deviceControllability/settings`.
 version_added: '6.15.0'
 extends_documentation_fragment:
   - cisco.dnac.module
 author: Rafael Campos (@racampos)
 options:
   deviceIds:
-    description: Unassigned network devices, ranging
-      from a minimum of 1 to a maximum of 100.
+    description: Unassigned network devices, ranging from a minimum of 1 to a maximum of 100.
     elements: str
     type: list
   siteId:
-    description: This must be building Id or floor Id.
-      Access points, Sensors are assigned to floor.
-      Remaining network devices are assigned to building.
-      Site Id can be retrieved using '/intent/api/v1/sites'.
+    description: This must be building Id or floor Id. Access points, Sensors are assigned to floor. Remaining network devices
+      are assigned to building. Site Id can be retrieved using '/intent/api/v1/sites'.
     type: str
 requirements:
-  - dnacentersdk >= 2.10.1
-  - python >= 3.5
+  - dnacentersdk >= 2.11.0
+  - python >= 3.12
 seealso:
-  - name: Cisco DNA Center documentation for Site Design
-      AssignNetworkDevicesToASite
-    description: Complete reference of the AssignNetworkDevicesToASite
-      API.
+  - name: Cisco DNA Center documentation for Site Design AssignNetworkDevicesToASite
+    description: Complete reference of the AssignNetworkDevicesToASite API.
     link: https://developer.cisco.com/docs/dna-center/#!assign-network-devices-to-a-site
 notes:
   - SDK Method used are
@@ -74,8 +64,7 @@ dnac_response:
     {
       "version": "string",
       "response": {
-        "url": "string",
-        "taskId": "string"
+        "count": 0
       }
     }
 """
