@@ -7,16 +7,11 @@
 DOCUMENTATION = r"""
 ---
 module: assurance_issues_query
-short_description: Resource module for Assurance Issues
-  Query
+short_description: Resource module for Assurance Issues Query
 description:
-  - Manage operation create of the resource Assurance
-    Issues Query. - > Returns all details of each issue
-    along with suggested actions for given set of filters
-    specified in request body. If there is no start
-    and/or end time, then end time will be defaulted
-    to current time and start time will be defaulted
-    to 24-hours ago from end time. Https //github.com/cisco-en-programmability/catalyst-center-
+  - Manage operation create of the resource Assurance Issues Query. - > Returns all details of each issue along with suggested
+    actions for given set of filters specified in request body. If there is no start and/or end time, then end time will be
+    defaulted to current time and start time will be defaulted to 24-hours ago from end time. Https //github.com/cisco-en-programmability/catalyst-center-
     api-specs/blob/main/Assurance/CE_Cat_Center_Org-IssuesList-1.0.0-resolved.yaml.
 version_added: '6.15.0'
 extends_documentation_fragment:
@@ -64,13 +59,11 @@ options:
     description: Start Time.
     type: int
 requirements:
-  - dnacentersdk >= 2.10.1
-  - python >= 3.5
+  - dnacentersdk >= 2.11.0
+  - python >= 3.12
 seealso:
-  - name: Cisco DNA Center documentation for Issues
-      GetTheDetailsOfIssuesForGivenSetOfFilters
-    description: Complete reference of the GetTheDetailsOfIssuesForGivenSetOfFilters
-      API.
+  - name: Cisco DNA Center documentation for Issues GetTheDetailsOfIssuesForGivenSetOfFilters
+    description: Complete reference of the GetTheDetailsOfIssuesForGivenSetOfFilters API.
     link: https://developer.cisco.com/docs/dna-center/#!get-the-details-of-issues-for-given-set-of-filters
 notes:
   - SDK Method used are
@@ -137,7 +130,7 @@ dnac_response:
             {
               "message": "string",
               "steps": [
-                {}
+                "string"
               ]
             }
           ],
