@@ -7,26 +7,19 @@
 DOCUMENTATION = r"""
 ---
 module: assurance_issues_trend_analytics
-short_description: Resource module for Assurance Issues
-  Trend Analytics
+short_description: Resource module for Assurance Issues Trend Analytics
 description:
-  - Manage operation create of the resource Assurance
-    Issues Trend Analytics. - > Gets the trend analytics
-    data related to issues based on given filters and
-    group by field. This data can be used to find issue
-    counts in different intervals over a period of time.
-    For detailed information about the usage of the
-    API, please refer to the Open API specification
-    document - https //github.com/cisco-en- programmability/catalyst-center-api-specs/blob/main/Assurance/CE_Cat_Center_Org-
-    IssuesList-1.0.1-resolved.yaml.
+  - Manage operation create of the resource Assurance Issues Trend Analytics. - > Gets the trend analytics data related to
+    issues based on given filters and group by field. This data can be used to find issue counts in different intervals over
+    a period of time. For detailed information about the usage of the API, please refer to the Open API specification document
+    - https //github.com/cisco-en- programmability/catalyst-center-api-specs/blob/main/Assurance/CE_Cat_Center_Org- IssuesList-1.0.1-resolved.yaml.
 version_added: '6.15.0'
 extends_documentation_fragment:
   - cisco.dnac.module
 author: Rafael Campos (@racampos)
 options:
   aggregateAttributes:
-    description: Assurance Issues Trend Analytics's
-      aggregateAttributes.
+    description: Assurance Issues Trend Analytics's aggregateAttributes.
     elements: dict
     suboptions:
       function:
@@ -44,8 +37,7 @@ options:
     description: End Time.
     type: int
   filters:
-    description: Assurance Issues Trend Analytics's
-      filters.
+    description: Assurance Issues Trend Analytics's filters.
     elements: dict
     suboptions:
       key:
@@ -66,8 +58,7 @@ options:
     description: Additional headers.
     type: dict
   page:
-    description: Assurance Issues Trend Analytics's
-      page.
+    description: Assurance Issues Trend Analytics's page.
     suboptions:
       limit:
         description: Limit.
@@ -86,13 +77,11 @@ options:
     description: Trend Interval.
     type: str
 requirements:
-  - dnacentersdk >= 2.10.1
-  - python >= 3.5
+  - dnacentersdk >= 2.11.0
+  - python >= 3.12
 seealso:
-  - name: Cisco DNA Center documentation for Issues
-      GetTrendAnalyticsDataOfIssues
-    description: Complete reference of the GetTrendAnalyticsDataOfIssues
-      API.
+  - name: Cisco DNA Center documentation for Issues GetTrendAnalyticsDataOfIssues
+    description: Complete reference of the GetTrendAnalyticsDataOfIssues API.
     link: https://developer.cisco.com/docs/dna-center/#!get-trend-analytics-data-of-issues
 notes:
   - SDK Method used are
