@@ -24,13 +24,11 @@ options:
       - Id path parameter. Building Id.
     type: str
 requirements:
-  - dnacentersdk >= 2.10.1
-  - python >= 3.5
+  - dnacentersdk >= 2.11.0
+  - python >= 3.12
 seealso:
-  - name: Cisco DNA Center documentation for Site Design
-      GetsABuildingV2
-    description: Complete reference of the GetsABuildingV2
-      API.
+  - name: Cisco DNA Center documentation for Site Design GetsABuildingV2
+    description: Complete reference of the GetsABuildingV2 API.
     link: https://developer.cisco.com/docs/dna-center/#!gets-a-building-v-2
 notes:
   - SDK Method used are
@@ -67,11 +65,7 @@ dnac_response:
         "latitude": 0,
         "longitude": 0,
         "address": "string",
-        "country": "string",
-        "type": "string",
-        "id": "string",
-        "nameHierarchy": "string",
-        "siteHierarchyId": "string"
+        "country": "string"
       }
     }
 """
