@@ -7,11 +7,9 @@
 DOCUMENTATION = r"""
 ---
 module: configuration_template_create
-short_description: Resource module for Configuration
-  Template Create
+short_description: Resource module for Configuration Template Create
 description:
-  - Manage operation create of the resource Configuration
-    Template Create.
+  - Manage operation create of the resource Configuration Template Create.
   - API to create a template by project id.
 version_added: '3.1.0'
 extends_documentation_fragment:
@@ -35,8 +33,7 @@ options:
         description: Description of template.
         type: str
       deviceTypes:
-        description: Configuration Template Create's
-          deviceTypes.
+        description: Configuration Template Create's deviceTypes.
         elements: dict
         suboptions:
           productFamily:
@@ -62,8 +59,7 @@ options:
         description: Project name.
         type: str
       rollbackTemplateParams:
-        description: Configuration Template Create's
-          rollbackTemplateParams.
+        description: Configuration Template Create's rollbackTemplateParams.
         elements: dict
         suboptions:
           binding:
@@ -112,8 +108,7 @@ options:
             description: Provider.
             type: str
           range:
-            description: Configuration Template Create's
-              range.
+            description: Configuration Template Create's range.
             elements: dict
             suboptions:
               id:
@@ -130,8 +125,7 @@ options:
             description: Is param required.
             type: bool
           selection:
-            description: Configuration Template Create's
-              selection.
+            description: Configuration Template Create's selection.
             suboptions:
               defaultSelectedValues:
                 description: Default selection values.
@@ -141,17 +135,15 @@ options:
                 description: UUID of selection.
                 type: str
               selectionType:
-                description: Type of selection(SINGLE_SELECT
-                  or MULTI_SELECT).
+                description: Type of selection(SINGLE_SELECT or MULTI_SELECT).
                 type: str
               selectionValues:
-                description: Selection values.
+                description: Configuration Template Create's selectionValues.
                 type: dict
             type: dict
         type: list
       tags:
-        description: Configuration Template Create's
-          tags.
+        description: Configuration Template Create's tags.
         elements: dict
         suboptions:
           id:
@@ -165,8 +157,7 @@ options:
         description: Template content.
         type: str
       templateParams:
-        description: Configuration Template Create's
-          templateParams.
+        description: Configuration Template Create's templateParams.
         elements: dict
         suboptions:
           binding:
@@ -215,8 +206,7 @@ options:
             description: Provider.
             type: str
           range:
-            description: Configuration Template Create's
-              range.
+            description: Configuration Template Create's range.
             elements: dict
             suboptions:
               id:
@@ -233,8 +223,7 @@ options:
             description: Is param required.
             type: bool
           selection:
-            description: Configuration Template Create's
-              selection.
+            description: Configuration Template Create's selection.
             suboptions:
               defaultSelectedValues:
                 description: Default selection values.
@@ -244,11 +233,10 @@ options:
                 description: UUID of selection.
                 type: str
               selectionType:
-                description: Type of selection(SINGLE_SELECT
-                  or MULTI_SELECT).
+                description: Type of selection(SINGLE_SELECT or MULTI_SELECT).
                 type: str
               selectionValues:
-                description: Selection values.
+                description: Configuration Template Create's selectionValues.
                 type: dict
             type: dict
         type: list
@@ -280,8 +268,7 @@ options:
         type: str
     type: list
   failurePolicy:
-    description: Define failure policy if template provisioning
-      fails.
+    description: Define failure policy if template provisioning fails.
     type: str
   id:
     description: UUID of template.
@@ -360,8 +347,7 @@ options:
         description: Provider.
         type: str
       range:
-        description: Configuration Template Create's
-          range.
+        description: Configuration Template Create's range.
         elements: dict
         suboptions:
           id:
@@ -378,8 +364,7 @@ options:
         description: Is param required.
         type: bool
       selection:
-        description: Configuration Template Create's
-          selection.
+        description: Configuration Template Create's selection.
         suboptions:
           defaultSelectedValues:
             description: Default selection values.
@@ -389,11 +374,10 @@ options:
             description: UUID of selection.
             type: str
           selectionType:
-            description: Type of selection(SINGLE_SELECT
-              or MULTI_SELECT).
+            description: Type of selection(SINGLE_SELECT or MULTI_SELECT).
             type: str
           selectionValues:
-            description: Selection values.
+            description: Configuration Template Create's selectionValues.
             type: dict
         type: dict
     type: list
@@ -470,8 +454,7 @@ options:
         description: Provider.
         type: str
       range:
-        description: Configuration Template Create's
-          range.
+        description: Configuration Template Create's range.
         elements: dict
         suboptions:
           id:
@@ -488,8 +471,7 @@ options:
         description: Is param required.
         type: bool
       selection:
-        description: Configuration Template Create's
-          selection.
+        description: Configuration Template Create's selection.
         suboptions:
           defaultSelectedValues:
             description: Default selection values.
@@ -499,11 +481,10 @@ options:
             description: UUID of selection.
             type: str
           selectionType:
-            description: Type of selection(SINGLE_SELECT
-              or MULTI_SELECT).
+            description: Type of selection(SINGLE_SELECT or MULTI_SELECT).
             type: str
           selectionValues:
-            description: Selection values.
+            description: Configuration Template Create's selectionValues.
             type: dict
         type: dict
     type: list
@@ -511,12 +492,10 @@ options:
     description: Configuration Template Create's validationErrors.
     suboptions:
       rollbackTemplateErrors:
-        description: Validation or design conflicts
-          errors of rollback template.
+        description: Validation or design conflicts errors of rollback template.
         type: dict
       templateErrors:
-        description: Validation or design conflicts
-          errors.
+        description: Validation or design conflicts errors.
         type: dict
       templateId:
         description: UUID of template.
@@ -529,13 +508,11 @@ options:
     description: Current version of template.
     type: str
 requirements:
-  - dnacentersdk >= 2.10.1
-  - python >= 3.5
+  - dnacentersdk >= 2.11.0
+  - python >= 3.12
 seealso:
-  - name: Cisco DNA Center documentation for Configuration
-      Templates CreateTemplate
-    description: Complete reference of the CreateTemplate
-      API.
+  - name: Cisco DNA Center documentation for Configuration Templates CreateTemplate
+    description: Complete reference of the CreateTemplate API.
     link: https://developer.cisco.com/docs/dna-center/#!create-template
 notes:
   - SDK Method used are
