@@ -4,13 +4,13 @@
 # Copyright (c) 2021, Cisco Systems
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
 
-
 DOCUMENTATION = r"""
 ---
 module: configuration_template_deploy_status_info
-short_description: Information module for Configuration Template Deploy Status Info
+short_description: Information module for Configuration Template Deploy Status
 description:
-- This module represents an alias of the module configuration_template_deploy_status_v1_info
+  - Get Configuration Template Deploy Status by id.
+  - API to retrieve the status of template deployment.
 version_added: '3.1.0'
 extends_documentation_fragment:
   - cisco.dnac.module_info
@@ -21,27 +21,25 @@ options:
     type: dict
   deploymentId:
     description:
-    - DeploymentId path parameter. UUID of deployment to retrieve template deployment status.
+      - DeploymentId path parameter. UUID of deployment to retrieve template deployment status.
     type: str
 requirements:
-- dnacentersdk >= 2.4.9
-- python >= 3.5
+  - dnacentersdk >= 2.11.0
+  - python >= 3.12
 seealso:
-- name: Cisco DNA Center documentation for Configuration Templates StatusOfTemplateDeploymentV1
-  description: Complete reference of the StatusOfTemplateDeploymentV1 API.
-  link: https://developer.cisco.com/docs/dna-center/#!status-of-template-deployment
+  - name: Cisco DNA Center documentation for Configuration Templates StatusOfTemplateDeployment
+    description: Complete reference of the StatusOfTemplateDeployment API.
+    link: https://developer.cisco.com/docs/dna-center/#!status-of-template-deployment
 notes:
   - SDK Method used are
     configuration_templates.ConfigurationTemplates.get_template_deployment_status,
-
   - Paths used are
     get /dna/intent/api/v1/template-programmer/template/deploy/status/{deploymentId},
-  - It should be noted that this module is an alias of configuration_template_deploy_status_v1_info
-
 """
 
 EXAMPLES = r"""
-- name: Get Configuration Template Deploy Status Info by id
+---
+- name: Get Configuration Template Deploy Status by id
   cisco.dnac.configuration_template_deploy_status_info:
     dnac_host: "{{dnac_host}}"
     dnac_username: "{{dnac_username}}"
@@ -53,7 +51,6 @@ EXAMPLES = r"""
     headers: "{{my_headers | from_json}}"
     deploymentId: string
   register: result
-
 """
 RETURN = r"""
 dnac_response:
