@@ -1,13 +1,16 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
+
 # Copyright (c) 2021, Cisco Systems
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
+
 DOCUMENTATION = r"""
 ---
 module: device_credential_info
-short_description: Information module for Device Credential Info
+short_description: Information module for Device Credential
 description:
-  - This module represents an alias of the module device_credential_v1_info
+  - Get all Device Credential.
+  - API to get device credential details.
 version_added: '3.1.0'
 extends_documentation_fragment:
   - cisco.dnac.module_info
@@ -18,23 +21,25 @@ options:
     type: dict
   siteId:
     description:
-      - SiteId query parameter. Site id to retrieve the credential details associated
-        with the site.
+      - SiteId query parameter. Site id to retrieve the credential details associated with the site.
     type: str
 requirements:
-  - dnacentersdk >= 2.4.9
-  - python >= 3.5
+  - dnacentersdk >= 2.11.0
+  - python >= 3.12
 seealso:
-  - name: Cisco DNA Center documentation for Network Settings GetDeviceCredentialDetailsV1
-    description: Complete reference of the GetDeviceCredentialDetailsV1 API.
+  - name: Cisco DNA Center documentation for Network Settings GetDeviceCredentialDetails
+    description: Complete reference of the GetDeviceCredentialDetails API.
     link: https://developer.cisco.com/docs/dna-center/#!get-device-credential-details
 notes:
-  - SDK Method used are network_settings.NetworkSettings.get_device_credential_details_v1,
-  - Paths used are get /dna/intent/api/v1/device-credential,
-  - It should be noted that this module is an alias of device_credential_v1_info
+  - SDK Method used are
+    network_settings.NetworkSettings.get_device_credential_details,
+  - Paths used are
+    get /dna/intent/api/v1/device-credential,
 """
+
 EXAMPLES = r"""
-- name: Get all Device Credential Info
+---
+- name: Get all Device Credential
   cisco.dnac.device_credential_info:
     dnac_host: "{{dnac_host}}"
     dnac_username: "{{dnac_username}}"
