@@ -7,12 +7,10 @@
 DOCUMENTATION = r"""
 ---
 module: device_interface_by_ip_info
-short_description: Information module for Device Interface
-  By Ip
+short_description: Information module for Device Interface By Ip
 description:
   - Get Device Interface By Ip by id.
-  - Returns list of interfaces for specified device
-    management IP address.
+  - Returns list of interfaces for specified device management IP address.
 version_added: '3.1.0'
 extends_documentation_fragment:
   - cisco.dnac.module_info
@@ -23,17 +21,14 @@ options:
     type: dict
   ipAddress:
     description:
-      - IpAddress path parameter. IP address of the
-        interface.
+      - IpAddress path parameter. IP address of the interface.
     type: str
 requirements:
-  - dnacentersdk >= 2.10.1
-  - python >= 3.5
+  - dnacentersdk >= 2.11.0
+  - python >= 3.12
 seealso:
-  - name: Cisco DNA Center documentation for Devices
-      GetInterfaceByIP
-    description: Complete reference of the GetInterfaceByIP
-      API.
+  - name: Cisco DNA Center documentation for Devices GetInterfaceByIP
+    description: Complete reference of the GetInterfaceByIP API.
     link: https://developer.cisco.com/docs/dna-center/#!get-interface-by-ip
 notes:
   - SDK Method used are
