@@ -7,15 +7,11 @@
 DOCUMENTATION = r"""
 ---
 module: dhcp_services_trend_analytics
-short_description: Resource module for Dhcp Services
-  Trend Analytics
+short_description: Resource module for Dhcp Services Trend Analytics
 description:
-  - Manage operation create of the resource Dhcp Services
-    Trend Analytics. - > Gets the trend analytics data
-    related to DHCP Services based on given filters
-    and group by field. For detailed information about
-    the usage of the API, please refer to the Open API
-    specification document - https //github.com/cisco-en-programmability/catalyst-center-api-specs/blob/main/Assurance/CE_Cat_Center_Org-
+  - Manage operation create of the resource Dhcp Services Trend Analytics. - > Gets the trend analytics data related to DHCP
+    Services based on given filters and group by field. For detailed information about the usage of the API, please refer
+    to the Open API specification document - https //github.com/cisco-en-programmability/catalyst-center-api-specs/blob/main/Assurance/CE_Cat_Center_Org-
     DHCPServices-1.0.0-resolved.yaml.
 version_added: '6.17.0'
 extends_documentation_fragment:
@@ -58,7 +54,7 @@ options:
         description: Operator.
         type: str
       value:
-        description: Value.
+        description: Dhcp Services Trend Analytics's value.
         type: dict
     type: list
   groupBy:
@@ -88,13 +84,11 @@ options:
     description: Trend Interval.
     type: str
 requirements:
-  - dnacentersdk >= 2.10.1
-  - python >= 3.5
+  - dnacentersdk >= 2.11.0
+  - python >= 3.12
 seealso:
-  - name: Cisco DNA Center documentation for Devices
-      GetTrendAnalyticsDataOfDHCPServicesForGivenSetOfComplexFilters
-    description: Complete reference of the GetTrendAnalyticsDataOfDHCPServicesForGivenSetOfComplexFilters
-      API.
+  - name: Cisco DNA Center documentation for Devices GetTrendAnalyticsDataOfDHCPServicesForGivenSetOfComplexFilters
+    description: Complete reference of the GetTrendAnalyticsDataOfDHCPServicesForGivenSetOfComplexFilters API.
     link: https://developer.cisco.com/docs/dna-center/#!get-trend-analytics-data-of-dhcp-services-for-given-set-of-complex-filters
 notes:
   - SDK Method used are
