@@ -9,8 +9,8 @@ DOCUMENTATION = r"""
 module: discovery_range_info
 short_description: Information module for Discovery Range
 description:
-- Get all Discovery Range.
-- Returns the discovery by specified range.
+  - Get all Discovery Range.
+  - Returns the discoveries by specified range.
 version_added: '3.1.0'
 extends_documentation_fragment:
   - cisco.dnac.module_info
@@ -21,29 +21,28 @@ options:
     type: dict
   startIndex:
     description:
-    - StartIndex path parameter. Start index.
+      - StartIndex path parameter. Starting index for the records.
     type: int
   recordsToReturn:
     description:
-    - RecordsToReturn path parameter. Number of records to return.
+      - RecordsToReturn path parameter. Number of records to fetch from the starting index.
     type: int
 requirements:
-- dnacentersdk >= 2.6.0
-- python >= 3.9
+  - dnacentersdk >= 2.11.0
+  - python >= 3.12
 seealso:
-- name: Cisco DNA Center documentation for Discovery GetDiscoveriesByRange
-  description: Complete reference of the GetDiscoveriesByRange API.
-  link: https://developer.cisco.com/docs/dna-center/#!get-discoveries-by-range
+  - name: Cisco DNA Center documentation for Discovery GetDiscoveriesByRange
+    description: Complete reference of the GetDiscoveriesByRange API.
+    link: https://developer.cisco.com/docs/dna-center/#!get-discoveries-by-range
 notes:
   - SDK Method used are
     discovery.Discovery.get_discoveries_by_range,
-
   - Paths used are
     get /dna/intent/api/v1/discovery/{startIndex}/{recordsToReturn},
-
 """
 
 EXAMPLES = r"""
+---
 - name: Get all Discovery Range
   cisco.dnac.discovery_range_info:
     dnac_host: "{{dnac_host}}"
@@ -57,9 +56,7 @@ EXAMPLES = r"""
     startIndex: 0
     recordsToReturn: 0
   register: result
-
 """
-
 RETURN = r"""
 dnac_response:
   description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
