@@ -1,13 +1,16 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
+
 # Copyright (c) 2021, Cisco Systems
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
+
 DOCUMENTATION = r"""
 ---
 module: endpoint_analytics_profiling_rules_bulk
-short_description: Resource module for Endpoint Analytics Profiling Rules Bulk
+short_description: Resource module for Endpoint Analytics Profiling-Rules Bulk
 description:
-  - This module represents an alias of the module endpoint_analytics_profiling_rules_bulk_v1
+  - Manage operation create of the resource Endpoint Analytics Profiling-Rules Bulk.
+  - This API imports the given list of profiling rules. For each record,.
 version_added: '6.16.0'
 extends_documentation_fragment:
   - cisco.dnac.module
@@ -54,19 +57,17 @@ options:
         description: Flag to indicate whether the rule was deleted.
         type: bool
       lastModifiedBy:
-        description: User that last modified the rule. It is read-only, and is ignored
-          if provided as part of input request.
+        description: User that last modified the rule. It is read-only, and is ignored if provided as part of input request.
         type: str
       lastModifiedOn:
-        description: Timestamp (in epoch milliseconds) of last modification. It is
-          read-only, and is ignored if provided as part of input request.
+        description: Timestamp (in epoch milliseconds) of last modification. It is read-only, and is ignored if provided as
+          part of input request.
         type: int
       pluginId:
         description: Plugin for the rule. Only applicable for 'Cisco Default' rules.
         type: str
       rejected:
-        description: Flag to indicate whether rule has been rejected by user or not.
-          Only applicable for 'ML Rule'.
+        description: Flag to indicate whether rule has been rejected by user or not. Only applicable for 'ML Rule'.
         type: bool
       result:
         description: Endpoint Analytics Profiling Rules Bulk's result.
@@ -76,8 +77,7 @@ options:
             elements: str
             type: list
           hardwareManufacturer:
-            description: List of hardware manufacturers determined by the current
-              rule.
+            description: List of hardware manufacturers determined by the current rule.
             elements: str
             type: list
           hardwareModel:
@@ -90,9 +90,8 @@ options:
             type: list
         type: dict
       ruleId:
-        description: Unique identifier for the rule. This is normally generated by
-          the system, and client does not need to provide it for rules that need to
-          be newly created.
+        description: Unique identifier for the rule. This is normally generated by the system, and client does not need to
+          provide it for rules that need to be newly created.
         type: str
       ruleName:
         description: Human readable name for the rule.
@@ -110,20 +109,22 @@ options:
         description: Source priority for the rule.
         type: int
       usedAttributes:
-        description: List of attributes used in the rule. Only applicable for 'Cisco
-          Default' rules.
+        description: List of attributes used in the rule. Only applicable for 'Cisco Default' rules.
         elements: str
         type: list
     type: list
 requirements:
-  - dnacentersdk >= 2.4.9
-  - python >= 3.5
+  - dnacentersdk >= 2.11.0
+  - python >= 3.12
 notes:
-  - SDK Method used are a_i_endpoint_analytics.AIEndpointAnalytics.import_profiling_rules_in_bulk_v1,
-  - Paths used are post /dna/intent/api/v1/endpoint-analytics/profiling-rules/bulk,
-  - It should be noted that this module is an alias of endpoint_analytics_profiling_rules_bulk_v1
+  - SDK Method used are
+    ai_endpoint_analytics.AiEndpointAnalytics.import_profiling_rules_in_bulk,
+  - Paths used are
+    post /dna/intent/api/v1/endpoint-analytics/profiling-rules/bulk,
 """
+
 EXAMPLES = r"""
+---
 - name: Create
   cisco.dnac.endpoint_analytics_profiling_rules_bulk:
     dnac_host: "{{dnac_host}}"
