@@ -1,13 +1,16 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
+
 # Copyright (c) 2021, Cisco Systems
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
+
 DOCUMENTATION = r"""
 ---
 module: endpoint_analytics_tasks_info
-short_description: Information module for Endpoint Analytics Tasks Info
+short_description: Information module for Endpoint Analytics Tasks
 description:
-  - This module represents an alias of the module endpoint_analytics_tasks_v1_info
+  - Get Endpoint Analytics Tasks by id. - > Fetches the details of backend task. Task is typically created by making call
+    to some other API that takes longer time to execute.
 version_added: '6.16.0'
 extends_documentation_fragment:
   - cisco.dnac.module_info
@@ -21,19 +24,22 @@ options:
       - TaskId path parameter. Unique identifier for the task.
     type: str
 requirements:
-  - dnacentersdk >= 2.4.9
-  - python >= 3.5
+  - dnacentersdk >= 2.11.0
+  - python >= 3.12
 seealso:
-  - name: Cisco DNA Center documentation for AI Endpoint Analytics GetTaskDetailsV1
-    description: Complete reference of the GetTaskDetailsV1 API.
+  - name: Cisco DNA Center documentation for AI Endpoint Analytics GetTaskDetails
+    description: Complete reference of the GetTaskDetails API.
     link: https://developer.cisco.com/docs/dna-center/#!get-task-details
 notes:
-  - SDK Method used are a_i_endpoint_analytics.AIEndpointAnalytics.get_task_details_v1,
-  - Paths used are get /dna/intent/api/v1/endpoint-analytics/tasks/{taskId},
-  - It should be noted that this module is an alias of endpoint_analytics_tasks_v1_info
+  - SDK Method used are
+    ai_endpoint_analytics.AiEndpointAnalytics.get_task_details,
+  - Paths used are
+    get /dna/intent/api/v1/endpoint-analytics/tasks/{taskId},
 """
+
 EXAMPLES = r"""
-- name: Get Endpoint Analytics Tasks Info by id
+---
+- name: Get Endpoint Analytics Tasks by id
   cisco.dnac.endpoint_analytics_tasks_info:
     dnac_host: "{{dnac_host}}"
     dnac_username: "{{dnac_username}}"
