@@ -9,11 +9,11 @@ DOCUMENTATION = r"""
 module: eox_status_device_info
 short_description: Information module for Eox Status Device
 description:
-- Get all Eox Status Device.
-- Get Eox Status Device by id.
-- Retrieves EoX details for a device.
-- Retrieves EoX status for all devices in the network.
-version_added: '6.7.0'
+  - Get all Eox Status Device.
+  - Get Eox Status Device by id.
+  - Retrieves EoX details for a device.
+  - Retrieves EoX status for all devices in the network.
+version_added: '3.1.0'
 extends_documentation_fragment:
   - cisco.dnac.module_info
 author: Rafael Campos (@racampos)
@@ -21,32 +21,41 @@ options:
   headers:
     description: Additional headers.
     type: dict
+  limit:
+    description:
+      - >
+        Limit query parameter. The number of records to show for this page. Default is 500 if not specified.
+        Maximum allowed limit is 500.
+    type: int
+  offset:
+    description:
+      - Offset query parameter. The first record to show for this page, the first record is numbered 1.
+    type: int
   deviceId:
     description:
-    - DeviceId path parameter. Device instance UUID.
+      - DeviceId path parameter. Device instance UUID.
     type: str
 requirements:
-- dnacentersdk >= 2.6.0
-- python >= 3.9
+  - dnacentersdk >= 2.11.0
+  - python >= 3.12
 seealso:
-- name: Cisco DNA Center documentation for EoX GetEoXDetailsPerDevice
-  description: Complete reference of the GetEoXDetailsPerDevice API.
-  link: https://developer.cisco.com/docs/dna-center/#!get-eo-x-details-per-device
-- name: Cisco DNA Center documentation for EoX GetEoXStatusForAllDevices
-  description: Complete reference of the GetEoXStatusForAllDevices API.
-  link: https://developer.cisco.com/docs/dna-center/#!get-eo-x-status-for-all-devices
+  - name: Cisco DNA Center documentation for EoX GetEoXDetailsPerDevice
+    description: Complete reference of the GetEoXDetailsPerDevice API.
+    link: https://developer.cisco.com/docs/dna-center/#!get-eo-x-details-per-device
+  - name: Cisco DNA Center documentation for EoX GetEoXStatusForAllDevices
+    description: Complete reference of the GetEoXStatusForAllDevices API.
+    link: https://developer.cisco.com/docs/dna-center/#!get-eo-x-status-for-all-devices
 notes:
   - SDK Method used are
-    eo_x.EoX.get_eo_x_details_per_device,
-    eo_x.EoX.get_eo_x_status_for_all_devices,
-
+    eox.Eox.get_eox_details_per_device,
+    eox.Eox.get_eox_status_for_all_devices,
   - Paths used are
     get /dna/intent/api/v1/eox-status/device,
     get /dna/intent/api/v1/eox-status/device/{deviceId},
-
 """
 
 EXAMPLES = r"""
+---
 - name: Get all Eox Status Device
   cisco.dnac.eox_status_device_info:
     dnac_host: "{{dnac_host}}"
@@ -57,8 +66,9 @@ EXAMPLES = r"""
     dnac_version: "{{dnac_version}}"
     dnac_debug: "{{dnac_debug}}"
     headers: "{{my_headers | from_json}}"
+    limit: 0
+    offset: 0
   register: result
-
 - name: Get Eox Status Device by id
   cisco.dnac.eox_status_device_info:
     dnac_host: "{{dnac_host}}"
@@ -71,9 +81,7 @@ EXAMPLES = r"""
     headers: "{{my_headers | from_json}}"
     deviceId: string
   register: result
-
 """
-
 RETURN = r"""
 dnac_response:
   description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
@@ -86,27 +94,30 @@ dnac_response:
         "alertCount": 0,
         "eoxDetails": [
           {
+            "name": "string",
             "bulletinHeadline": "string",
+            "bulletinName": "string",
             "bulletinNumber": "string",
             "bulletinURL": "string",
-            "endOfHardwareNewServiceAttachmentDate": 0,
-            "endOfHardwareServiceContractRenewalDate": 0,
-            "endOfLastHardwareShipDate": 0,
-            "endOfLifeDate": 0,
-            "endOfLifeExternalAnnouncementDate": 0,
-            "endOfSaleDate": 0,
-            "endOfSignatureReleasesDate": 0,
-            "endOfSoftwareVulnerabilityOrSecuritySupportDate": 0,
-            "endOfSoftwareVulnerabilityOrSecuritySupportDateHw": 0,
-            "endOfSoftwareMaintenanceReleasesDate": 0,
+            "endOfHardwareNewServiceAttachmentDate": "string",
+            "endOfHardwareServiceContractRenewalDate": "string",
+            "endOfLastHardwareShipDate": "string",
+            "endOfLifeExternalAnnouncementDate": "string",
+            "endOfSignatureReleasesDate": "string",
+            "endOfSoftwareVulnerabilityOrSecuritySupportDate": "string",
+            "endOfSoftwareVulnerabilityOrSecuritySupportDateHw": "string",
+            "endOfSaleDate": "string",
+            "endOfLifeDate": "string",
+            "lastDateOfSupport": "string",
+            "endOfSoftwareMaintenanceReleasesDate": "string",
             "eoxAlertType": "string",
-            "lastDateOfSupport": 0,
-            "name": "string"
+            "eoXPhysicalType": "string",
+            "bulletinPID": "string"
           }
         ],
         "scanStatus": "string",
         "comments": [
-          {}
+          "string"
         ],
         "lastScanTime": 0
       },
