@@ -1,13 +1,16 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
+
 # Copyright (c) 2021, Cisco Systems
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
+
 DOCUMENTATION = r"""
 ---
 module: event_count_info
-short_description: Information module for Event Count Info
+short_description: Information module for Event Count
 description:
-  - This module represents an alias of the module event_count_v1_info
+  - Get all Event Count.
+  - Get the count of registered events with provided eventIds or tags as mandatory.
 version_added: '3.1.0'
 extends_documentation_fragment:
   - cisco.dnac.module_info
@@ -25,19 +28,22 @@ options:
       - Tags query parameter. The registered Tags should be provided.
     type: str
 requirements:
-  - dnacentersdk >= 2.4.9
-  - python >= 3.5
+  - dnacentersdk >= 2.11.0
+  - python >= 3.12
 seealso:
-  - name: Cisco DNA Center documentation for Event Management CountOfEventsV1
-    description: Complete reference of the CountOfEventsV1 API.
+  - name: Cisco DNA Center documentation for Event Management CountOfEvents
+    description: Complete reference of the CountOfEvents API.
     link: https://developer.cisco.com/docs/dna-center/#!count-of-events
 notes:
-  - SDK Method used are event_management.EventManagement.count_of_events_v1,
-  - Paths used are get /dna/intent/api/v1/events/count,
-  - It should be noted that this module is an alias of event_count_v1_info
+  - SDK Method used are
+    event_management.EventManagement.count_of_events,
+  - Paths used are
+    get /dna/intent/api/v1/events/count,
 """
+
 EXAMPLES = r"""
-- name: Get all Event Count Info
+---
+- name: Get all Event Count
   cisco.dnac.event_count_info:
     dnac_host: "{{dnac_host}}"
     dnac_username: "{{dnac_username}}"
