@@ -7,14 +7,10 @@
 DOCUMENTATION = r"""
 ---
 module: field_notices_results_network_devices_network_device_id_notices_count_info
-short_description: Information module for Field Notices
-  Results Network Devices Network Device Id Notices
-  Count
+short_description: Information module for Field Notices Results Network Devices Network Device Id Notices Count
 description:
-  - Get all Field Notices Results Network Devices Network
-    Device Id Notices Count.
-  - Get count of field notices affecting the network
-    device.
+  - Get all Field Notices Results Network Devices Network Device Id Notices Count.
+  - Get count of field notices affecting the network device.
 version_added: '6.17.0'
 extends_documentation_fragment:
   - cisco.dnac.module_info
@@ -25,8 +21,7 @@ options:
     type: dict
   networkDeviceId:
     description:
-      - NetworkDeviceId path parameter. Id of the network
-        device.
+      - NetworkDeviceId path parameter. Id of the network device.
     type: str
   id:
     description:
@@ -34,17 +29,14 @@ options:
     type: str
   type:
     description:
-      - Type query parameter. Return field notices with
-        this type. Available values SOFTWARE, HARDWARE.
+      - Type query parameter. Return field notices with this type. Available values SOFTWARE, HARDWARE.
     type: str
 requirements:
-  - dnacentersdk >= 2.10.1
-  - python >= 3.5
+  - dnacentersdk >= 2.11.0
+  - python >= 3.12
 seealso:
-  - name: Cisco DNA Center documentation for Compliance
-      GetCountOfFieldNoticesAffectingTheNetworkDevice
-    description: Complete reference of the GetCountOfFieldNoticesAffectingTheNetworkDevice
-      API.
+  - name: Cisco DNA Center documentation for Compliance GetCountOfFieldNoticesAffectingTheNetworkDevice
+    description: Complete reference of the GetCountOfFieldNoticesAffectingTheNetworkDevice API.
     link: https://developer.cisco.com/docs/dna-center/#!get-count-of-field-notices-affecting-the-network-device
 notes:
   - SDK Method used are
@@ -55,8 +47,7 @@ notes:
 
 EXAMPLES = r"""
 ---
-- name: Get all Field Notices Results Network Devices
-    Network Device Id Notices Count
+- name: Get all Field Notices Results Network Devices Network Device Id Notices Count
   cisco.dnac.field_notices_results_network_devices_network_device_id_notices_count_info:
     dnac_host: "{{dnac_host}}"
     dnac_username: "{{dnac_username}}"
