@@ -7,11 +7,11 @@
 DOCUMENTATION = r"""
 ---
 module: field_notices_results_notices_id_network_devices_info
-short_description: Information module for Field Notices
-  Results Notices Id Network Devices
+short_description: Information module for Field Notices Results Notices Id Network Devices
 description:
-  - Get all Field Notices Results Notices Id Network
-    Devices.
+  - Get all Field Notices Results Notices Id Network Devices.
+  - Get Field Notices Results Notices Id Network Devices by id.
+  - Get field notice network device for the notice by network device id.
   - Get field notice network devices for the notice.
 version_added: '6.17.0'
 extends_documentation_fragment:
@@ -27,63 +27,58 @@ options:
     type: str
   networkDeviceId:
     description:
-      - NetworkDeviceId query parameter. Id of the network
-        device.
+      - NetworkDeviceId query parameter. Id of the network device.
     type: str
   scanStatus:
     description:
       - >
-        ScanStatus query parameter. Status of the scan
-        on the network device. Available values NOT_SCANNED,
+        ScanStatus query parameter. Status of the scan on the network device. Available values NOT_SCANNED,
         IN_PROGRESS, SUCCESS, FAILED.
     type: str
   offset:
     description:
       - >
-        Offset query parameter. The first record to
-        show for this page; the first record is numbered
-        1. Default value is 1.
+        Offset query parameter. The first record to show for this page; the first record is numbered 1. Default
+        value is 1.
     type: int
   limit:
     description:
       - >
-        Limit query parameter. The number of records
-        to show for this page. Minimum value is 1. Maximum
-        value is 500. Default value is 500.
+        Limit query parameter. The number of records to show for this page. Minimum value is 1. Maximum value is
+        500. Default value is 500.
     type: int
   sortBy:
     description:
-      - SortBy query parameter. A property within the
-        response to sort by.
+      - SortBy query parameter. A property within the response to sort by.
     type: str
   order:
     description:
       - >
-        Order query parameter. Whether ascending or
-        descending order should be used to sort the
-        response. Available values asc, desc. Default
-        value is asc.
+        Order query parameter. Whether ascending or descending order should be used to sort the response.
+        Available values asc, desc. Default value is asc.
     type: str
 requirements:
-  - dnacentersdk >= 2.10.1
-  - python >= 3.5
+  - dnacentersdk >= 2.11.0
+  - python >= 3.12
 seealso:
-  - name: Cisco DNA Center documentation for Compliance
-      GetFieldNoticeNetworkDevicesForTheNotice
-    description: Complete reference of the GetFieldNoticeNetworkDevicesForTheNotice
-      API.
+  - name: Cisco DNA Center documentation for Compliance GetFieldNoticeNetworkDeviceForTheNoticeByNetworkDeviceId
+    description: Complete reference of the GetFieldNoticeNetworkDeviceForTheNoticeByNetworkDeviceId API.
+    link: https://developer.cisco.com/docs/dna-center/#!get-field-notice-network-device-for-the-notice-by-network-device-id
+  - name: Cisco DNA Center documentation for Compliance GetFieldNoticeNetworkDevicesForTheNotice
+    description: Complete reference of the GetFieldNoticeNetworkDevicesForTheNotice API.
     link: https://developer.cisco.com/docs/dna-center/#!get-field-notice-network-devices-for-the-notice
 notes:
   - SDK Method used are
+    compliance.Compliance.get_field_notice_network_device_for_the_notice_by_network_device_id,
     compliance.Compliance.get_field_notice_network_devices_for_the_notice,
   - Paths used are
     get /dna/intent/api/v1/fieldNotices/results/notices/{id}/networkDevices,
+    get /dna/intent/api/v1/fieldNotices/results/notices/{id}/networkDevices/{networkDeviceId},
 """
 
 EXAMPLES = r"""
 ---
-- name: Get all Field Notices Results Notices Id Network
-    Devices
+- name: Get all Field Notices Results Notices Id Network Devices
   cisco.dnac.field_notices_results_notices_id_network_devices_info:
     dnac_host: "{{dnac_host}}"
     dnac_username: "{{dnac_username}}"
@@ -101,6 +96,19 @@ EXAMPLES = r"""
     order: string
     id: string
   register: result
+- name: Get Field Notices Results Notices Id Network Devices by id
+  cisco.dnac.field_notices_results_notices_id_network_devices_info:
+    dnac_host: "{{dnac_host}}"
+    dnac_username: "{{dnac_username}}"
+    dnac_password: "{{dnac_password}}"
+    dnac_verify: "{{dnac_verify}}"
+    dnac_port: "{{dnac_port}}"
+    dnac_version: "{{dnac_version}}"
+    dnac_debug: "{{dnac_debug}}"
+    headers: "{{my_headers | from_json}}"
+    id: string
+    networkDeviceId: string
+  register: result
 """
 RETURN = r"""
 dnac_response:
@@ -109,16 +117,14 @@ dnac_response:
   type: dict
   sample: >
     {
-      "response": [
-        {
-          "networkDeviceId": "string",
-          "noticeCount": 0,
-          "potentialNoticeCount": 0,
-          "scanStatus": "string",
-          "comments": "string",
-          "lastScanTime": 0
-        }
-      ],
+      "response": {
+        "networkDeviceId": "string",
+        "noticeCount": 0,
+        "potentialNoticeCount": 0,
+        "scanStatus": "string",
+        "comments": "string",
+        "lastScanTime": 0
+      },
       "version": "string"
     }
 """
