@@ -7,18 +7,14 @@
 DOCUMENTATION = r"""
 ---
 module: icap_settings_configuration_models_preview_activity_id_network_device_status_details_info
-short_description: Information module for Icap Settings
-  Configuration Models Preview Activity Id Network Device
-  Status Details
+short_description: Information module for Icap Settings Configuration Models Preview Activity Id Network Device Status Details
 description:
-  - Get all Icap Settings Configuration Models Preview
-    Activity Id Network Device Status Details. - > Get
-    ICAP configuration status per network device using
-    the activity ID, which was returned in property
-    "taskId" of the TaskResponse of the POST. For detailed
-    information about the usage of the API, please refer
-    to the Open API specification document - https //github.com/cisco-en-programmability/catalyst-center-api-
-    specs/blob/main/Assurance/CE_Cat_Center_Org-ICAP_APIs-1.0.0-resolved.yaml.
+  - Get all Icap Settings Configuration Models Preview Activity Id Network Device Status Details.
+  - Get ICAP configuration status per network device using the activity ID.
+  - The activity ID was returned in property "taskId" of the TaskResponse of the POST.
+  - For detailed information about the usage of the API, please refer to the Open API specification document
+    https //github.com/cisco-en-programmability/catalyst-center-api-specs/blob/main/Assurance/
+    CE_Cat_Center_Org-ICAP_APIs-1.0.0-resolved.yaml.
 version_added: '6.17.0'
 extends_documentation_fragment:
   - cisco.dnac.module_info
@@ -29,17 +25,14 @@ options:
     type: dict
   previewActivityId:
     description:
-      - PreviewActivityId path parameter. Activity from
-        the POST /deviceConfigugrationModels task response.
+      - PreviewActivityId path parameter. Activity from the POST /deviceConfigugrationModels task response.
     type: str
 requirements:
-  - dnacentersdk >= 2.10.1
-  - python >= 3.5
+  - dnacentersdk >= 2.11.0
+  - python >= 3.12
 seealso:
-  - name: Cisco DNA Center documentation for Sensors
-      GetICAPConfigurationStatusPerNetworkDevice
-    description: Complete reference of the GetICAPConfigurationStatusPerNetworkDevice
-      API.
+  - name: Cisco DNA Center documentation for Sensors GetICAPConfigurationStatusPerNetworkDevice
+    description: Complete reference of the GetICAPConfigurationStatusPerNetworkDevice API.
     link: https://developer.cisco.com/docs/dna-center/#!get-icap-configuration-status-per-network-device
 notes:
   - SDK Method used are
@@ -50,8 +43,7 @@ notes:
 
 EXAMPLES = r"""
 ---
-- name: Get all Icap Settings Configuration Models Preview
-    Activity Id Network Device Status Details
+- name: Get all Icap Settings Configuration Models Preview Activity Id Network Device Status Details
   cisco.dnac.icap_settings_configuration_models_preview_activity_id_network_device_status_details_info:
     dnac_host: "{{dnac_host}}"
     dnac_username: "{{dnac_username}}"
