@@ -7,58 +7,40 @@
 DOCUMENTATION = r"""
 ---
 module: images_site_wise_product_names
-short_description: Resource module for Images Site Wise
-  Product Names
+short_description: Resource module for Images Site Wise Product Names
 description:
-  - Manage operations create, update and delete of the
-    resource Images Site Wise Product Names. - > Assign
-    network device product name and sites for the given
-    image identifier. Refer `/dna/intent/api/v1/images`
-    API for obtaining imageId.
-  - This API unassigns the network device product name
-    from all the sites for the given software image.
-    - > Update the list of sites for the network device
-    product name assigned to the software image. Refer
-    to `/dna/intent/api/v1/images` and `/dna/intent/api/v1/images/{imageId}/siteWiseProductNames`
-    GET APIs for obtaining `imageId` and `productNameOrdinal`
-    respectively.
+  - Manage operations create, update and delete of the resource Images Site Wise Product Names. - > Assign network device
+    product name and sites for the given image identifier. Refer `/dna/intent/api/v1/images` API for obtaining imageId.
+  - This API unassigns the network device product name from all the sites for the given software image. - > Update the list
+    of sites for the network device product name assigned to the software image. Refer to `/dna/intent/api/v1/images` and
+    `/dna/intent/api/v1/images/{imageId}/siteWiseProductNames` GET APIs for obtaining `imageId` and `productNameOrdinal` respectively.
 version_added: '6.15.0'
 extends_documentation_fragment:
   - cisco.dnac.module
 author: Rafael Campos (@racampos)
 options:
   imageId:
-    description: ImageId path parameter. Software image
-      identifier. Refer `/dna/intent/api/v1/images`
-      API for obtaining `imageId`.
+    description: ImageId path parameter. Software image identifier. Refer `/dna/intent/api/v1/images` API for obtaining `imageId`.
     type: str
   productNameOrdinal:
-    description: Product name ordinal is unique value
-      for each network device product.
+    description: Product name ordinal is unique value for each network device product.
     type: float
   siteIds:
-    description: Sites where this image needs to be
-      assigned. Ref https //developer.cisco.com/docs/dna-center/#!sites.
+    description: Sites where this image needs to be assigned. Ref https //developer.cisco.com/docs/dna-center/#!sites.
     elements: str
     type: list
 requirements:
-  - dnacentersdk >= 2.10.1
-  - python >= 3.5
+  - dnacentersdk >= 2.11.0
+  - python >= 3.12
 seealso:
-  - name: Cisco DNA Center documentation for Software
-      Image Management (SWIM) AssignNetworkDeviceProductNameToTheGivenSoftwareImage
-    description: Complete reference of the AssignNetworkDeviceProductNameToTheGivenSoftwareImage
-      API.
+  - name: Cisco DNA Center documentation for Software Image Management (SWIM) AssignNetworkDeviceProductNameToTheGivenSoftwareImage
+    description: Complete reference of the AssignNetworkDeviceProductNameToTheGivenSoftwareImage API.
     link: https://developer.cisco.com/docs/dna-center/#!assign-network-device-product-name-to-the-given-software-image
-  - name: Cisco DNA Center documentation for Software
-      Image Management (SWIM) UnassignNetworkDeviceProductNameFromTheGivenSoftwareImage
-    description: Complete reference of the UnassignNetworkDeviceProductNameFromTheGivenSoftwareImage
-      API.
+  - name: Cisco DNA Center documentation for Software Image Management (SWIM) UnassignNetworkDeviceProductNameFromTheGivenSoftwareImage
+    description: Complete reference of the UnassignNetworkDeviceProductNameFromTheGivenSoftwareImage API.
     link: https://developer.cisco.com/docs/dna-center/#!unassign-network-device-product-name-from-the-given-software-image
-  - name: Cisco DNA Center documentation for Software
-      Image Management (SWIM) UpdateTheListOfSitesForTheNetworkDeviceProductNameAssignedToTheSoftwareImage
-    description: Complete reference of the UpdateTheListOfSitesForTheNetworkDeviceProductNameAssignedToTheSoftwareImage
-      API.
+  - name: Cisco DNA Center documentation for Software Image Management (SWIM) UpdateTheListOfSitesForTheNetworkDeviceProductNameAssignedToTheSoftwareImage
+    description: Complete reference of the UpdateTheListOfSitesForTheNetworkDeviceProductNameAssignedToTheSoftwareImage API.
     link: https://developer.cisco.com/docs/dna-center/#!update-the-list-of-sites-for-the-network-device-product-name-assigned-to-the-software-image
 notes:
   - SDK Method used are
