@@ -4,22 +4,22 @@
 # Copyright (c) 2021, Cisco Systems
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
 
-
 DOCUMENTATION = r"""
 ---
 module: interface_operation_create
 short_description: Resource module for Interface Operation Create
 description:
-- This module represents an alias of the module interface_operation_create_v1
+  - Manage operation create of the resource Interface Operation Create. - > Clear mac-address on an individual port. In request
+    body, operation needs to be specified as 'ClearMacAddress'. In the future more possible operations will be added to this
+    API.
 version_added: '6.0.0'
 extends_documentation_fragment:
   - cisco.dnac.module
 author: Rafael Campos (@racampos)
 options:
   deploymentMode:
-    description: DeploymentMode query parameter. Preview/Deploy 'Preview' means the
-      configuration is not pushed to the device. 'Deploy' makes the configuration pushed
-      to the device.
+    description: DeploymentMode query parameter. Preview/Deploy 'Preview' means the configuration is not pushed to the device.
+      'Deploy' makes the configuration pushed to the device.
     type: str
   interfaceUuid:
     description: InterfaceUuid path parameter. Interface Id.
@@ -28,26 +28,24 @@ options:
     description: Operation needs to be specified as 'ClearMacAddress'.
     type: str
   payload:
-    description: Payload is not applicable.
+    description: Interface Operation Create's payload.
     type: dict
 requirements:
-- dnacentersdk >= 2.4.9
-- python >= 3.5
+  - dnacentersdk >= 2.11.0
+  - python >= 3.12
 seealso:
-- name: Cisco DNA Center documentation for Devices ClearMacAddressTableV1
-  description: Complete reference of the ClearMacAddressTableV1 API.
-  link: https://developer.cisco.com/docs/dna-center/#!clear-mac-address-table
+  - name: Cisco DNA Center documentation for Devices ClearMacAddressTable
+    description: Complete reference of the ClearMacAddressTable API.
+    link: https://developer.cisco.com/docs/dna-center/#!clear-mac-address-table
 notes:
   - SDK Method used are
-    devices.Devices.clear_mac_address_table_v1,
-
+    devices.Devices.clear_mac_address_table,
   - Paths used are
     post /dna/intent/api/v1/interface/{interfaceUuid}/operation,
-  - It should be noted that this module is an alias of interface_operation_create_v1
-
 """
 
 EXAMPLES = r"""
+---
 - name: Create
   cisco.dnac.interface_operation_create:
     dnac_host: "{{dnac_host}}"
@@ -61,7 +59,6 @@ EXAMPLES = r"""
     interfaceUuid: string
     operation: string
     payload: {}
-
 """
 RETURN = r"""
 dnac_response:
