@@ -1,13 +1,16 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
+
 # Copyright (c) 2021, Cisco Systems
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
+
 DOCUMENTATION = r"""
 ---
 module: lan_automation_create
 short_description: Resource module for Lan Automation Create
 description:
-  - This module represents an alias of the module lan_automation_create_v1
+  - Manage operation create of the resource Lan Automation Create.
+  - Invoke this API to start LAN Automation for the given site.
 version_added: '6.0.0'
 extends_documentation_fragment:
   - cisco.dnac.module
@@ -21,8 +24,8 @@ options:
         description: Discovered device site name.
         type: str
       hostNameFileId:
-        description: Use /dna/intent/api/v1/file/namespace/nw_orch api to get the
-          file id for the already uploaded file in nw_orch namespace.
+        description: Use /dna/intent/api/v1/file/namespace/nw_orch api to get the file id for the already uploaded file in
+          nw_orch namespace.
         type: str
       hostNamePrefix:
         description: Host name prefix which shall be assigned to the discovered device.
@@ -48,8 +51,7 @@ options:
         description: Peer seed management IP address.
         type: str
       primaryDeviceInterfaceNames:
-        description: The list of interfaces on primary seed via which the discovered
-          devices are connected.
+        description: The list of interfaces on primary seed via which the discovered devices are connected.
         elements: str
         type: list
       primaryDeviceManagmentIPAddress:
@@ -60,18 +62,21 @@ options:
         type: bool
     type: list
 requirements:
-  - dnacentersdk >= 2.4.9
-  - python >= 3.5
+  - dnacentersdk >= 2.11.0
+  - python >= 3.12
 seealso:
-  - name: Cisco DNA Center documentation for LAN Automation LANAutomationStartV1
-    description: Complete reference of the LANAutomationStartV1 API.
+  - name: Cisco DNA Center documentation for LAN Automation LANAutomationStart
+    description: Complete reference of the LANAutomationStart API.
     link: https://developer.cisco.com/docs/dna-center/#!l-an-automation-start
 notes:
-  - SDK Method used are lan_automation.LanAutomation.lan_automation_start_v1,
-  - Paths used are post /dna/intent/api/v1/lan-automation,
-  - It should be noted that this module is an alias of lan_automation_create_v1
+  - SDK Method used are
+    lan_automation.LanAutomation.lan_automation_start,
+  - Paths used are
+    post /dna/intent/api/v1/lan-automation,
 """
+
 EXAMPLES = r"""
+---
 - name: Create
   cisco.dnac.lan_automation_create:
     dnac_host: "{{dnac_host}}"
