@@ -9,8 +9,7 @@ DOCUMENTATION = r"""
 module: netconf_credential
 short_description: Resource module for Netconf Credential
 description:
-  - Manage operations create and update of the resource
-    Netconf Credential.
+  - Manage operations create and update of the resource Netconf Credential.
   - Adds global netconf credentials.
   - Updates global netconf credentials.
 version_added: '3.1.0'
@@ -22,15 +21,13 @@ options:
     description: Comments to identify the netconf credential.
     type: str
   credentialType:
-    description: Credential type to identify the application
-      that uses the netconf credential.
+    description: Credential type to identify the application that uses the netconf credential.
     type: str
   description:
     description: Description for Netconf Credentials.
     type: str
   id:
-    description: Id of the Netconf Credential in UUID
-      format.
+    description: Id of the Netconf Credential in UUID format.
     type: str
   instanceTenantId:
     description: Deprecated.
@@ -39,22 +36,17 @@ options:
     description: Deprecated.
     type: str
   netconfPort:
-    description: Netconf port on the device. Valid port
-      should be in the range of 1 to 65535.
+    description: Netconf port on the device. Valid port should be in the range of 1 to 65535.
     type: str
 requirements:
-  - dnacentersdk >= 2.10.1
-  - python >= 3.5
+  - dnacentersdk >= 2.11.0
+  - python >= 3.12
 seealso:
-  - name: Cisco DNA Center documentation for Discovery
-      CreateNetconfCredentials
-    description: Complete reference of the CreateNetconfCredentials
-      API.
+  - name: Cisco DNA Center documentation for Discovery CreateNetconfCredentials
+    description: Complete reference of the CreateNetconfCredentials API.
     link: https://developer.cisco.com/docs/dna-center/#!create-netconf-credentials
-  - name: Cisco DNA Center documentation for Discovery
-      UpdateNetconfCredentials
-    description: Complete reference of the UpdateNetconfCredentials
-      API.
+  - name: Cisco DNA Center documentation for Discovery UpdateNetconfCredentials
+    description: Complete reference of the UpdateNetconfCredentials API.
     link: https://developer.cisco.com/docs/dna-center/#!update-netconf-credentials
 notes:
   - SDK Method used are
@@ -67,23 +59,6 @@ notes:
 
 EXAMPLES = r"""
 ---
-- name: Update all
-  cisco.dnac.netconf_credential:
-    dnac_host: "{{dnac_host}}"
-    dnac_username: "{{dnac_username}}"
-    dnac_password: "{{dnac_password}}"
-    dnac_verify: "{{dnac_verify}}"
-    dnac_port: "{{dnac_port}}"
-    dnac_version: "{{dnac_version}}"
-    dnac_debug: "{{dnac_debug}}"
-    state: present
-    comments: string
-    credentialType: string
-    description: string
-    id: string
-    instanceTenantId: string
-    instanceUuid: string
-    netconfPort: string
 - name: Create
   cisco.dnac.netconf_credential:
     dnac_host: "{{dnac_host}}"
@@ -102,6 +77,23 @@ EXAMPLES = r"""
         instanceTenantId: string
         instanceUuid: string
         netconfPort: string
+- name: Update all
+  cisco.dnac.netconf_credential:
+    dnac_host: "{{dnac_host}}"
+    dnac_username: "{{dnac_username}}"
+    dnac_password: "{{dnac_password}}"
+    dnac_verify: "{{dnac_verify}}"
+    dnac_port: "{{dnac_port}}"
+    dnac_version: "{{dnac_version}}"
+    dnac_debug: "{{dnac_debug}}"
+    state: present
+    comments: string
+    credentialType: string
+    description: string
+    id: string
+    instanceTenantId: string
+    instanceUuid: string
+    netconfPort: string
 """
 RETURN = r"""
 dnac_response:
