@@ -9,10 +9,8 @@ DOCUMENTATION = r"""
 module: network_create
 short_description: Resource module for Network Create
 description:
-  - Manage operation create of the resource Network
-    Create. - > API to create a network for DHCP, Syslog,
-    SNMP, NTP, Network AAA, Client and EndPoint AAA,
-    and/or DNS center server settings.
+  - Manage operation create of the resource Network Create. - > API to create a network for DHCP, Syslog, SNMP, NTP, Network
+    AAA, Client and EndPoint AAA, and/or DNS center server settings.
 version_added: '3.1.0'
 extends_documentation_fragment:
   - cisco.dnac.module
@@ -28,20 +26,16 @@ options:
         description: Network Create's clientAndEndpoint_aaa.
         suboptions:
           ipAddress:
-            description: IP address for ISE serve (eg
-              1.1.1.4).
+            description: IP address for ISE serve (eg 1.1.1.4).
             type: str
           network:
-            description: IP address for AAA or ISE server
-              (eg 2.2.2.1).
+            description: IP address for AAA or ISE server (eg 2.2.2.1).
             type: str
           protocol:
-            description: Protocol for AAA or ISE serve
-              (eg RADIUS).
+            description: Protocol for AAA or ISE serve (eg RADIUS).
             type: str
           servers:
-            description: Server type AAA or ISE server
-              (eg AAA).
+            description: Server type AAA or ISE server (eg AAA).
             type: str
           sharedSecret:
             description: Shared secret for ISE server.
@@ -58,56 +52,46 @@ options:
             description: Domain Name of DHCP (eg; cisco).
             type: str
           primaryIpAddress:
-            description: Primary IP Address for DHCP
-              (eg 2.2.2.2).
+            description: Primary IP Address for DHCP (eg 2.2.2.2).
             type: str
           secondaryIpAddress:
-            description: Secondary IP Address for DHCP
-              (eg 3.3.3.3).
+            description: Secondary IP Address for DHCP (eg 3.3.3.3).
             type: str
         type: dict
       messageOfTheday:
         description: Network Create's messageOfTheday.
         suboptions:
           bannerMessage:
-            description: Massage for Banner message
-              (eg; Good day).
+            description: Massage for Banner message (eg; Good day).
             type: str
           retainExistingBanner:
-            description: Retain existing Banner Message
-              (eg "true" or "false").
+            description: Retain existing Banner Message (eg "true" or "false").
             type: str
         type: dict
       netflowcollector:
         description: Network Create's netflowcollector.
         suboptions:
           ipAddress:
-            description: IP Address for NetFlow collector
-              (eg 3.3.3.1).
+            description: IP Address for NetFlow collector (eg 3.3.3.1).
             type: str
           port:
-            description: Port for NetFlow Collector
-              (eg; 443).
+            description: Port for NetFlow Collector (eg; 443).
             type: float
         type: dict
       network_aaa:
         description: Network Create's network_aaa.
         suboptions:
           ipAddress:
-            description: IP address for AAA and ISE
-              server (eg 1.1.1.1).
+            description: IP address for AAA and ISE server (eg 1.1.1.1).
             type: str
           network:
-            description: IP Address for AAA or ISE server
-              (eg 2.2.2.2).
+            description: IP Address for AAA or ISE server (eg 2.2.2.2).
             type: str
           protocol:
-            description: Protocol for AAA or ISE serve
-              (eg RADIUS).
+            description: Protocol for AAA or ISE serve (eg RADIUS).
             type: str
           servers:
-            description: Server type for AAA Network
-              (eg AAA).
+            description: Server type for AAA Network (eg AAA).
             type: str
           sharedSecret:
             description: Shared secret for ISE Server.
@@ -121,12 +105,10 @@ options:
         description: Network Create's snmpServer.
         suboptions:
           configureDnacIP:
-            description: Configuration DNAC IP for SNMP
-              Server (eg true).
+            description: Configuration DNAC IP for SNMP Server (eg true).
             type: bool
           ipAddresses:
-            description: IP Address for SNMP Server
-              (eg 4.4.4.1).
+            description: IP Address for SNMP Server (eg 4.4.4.1).
             elements: str
             type: list
         type: dict
@@ -134,12 +116,10 @@ options:
         description: Network Create's syslogServer.
         suboptions:
           configureDnacIP:
-            description: Configuration DNAC IP for syslog
-              server (eg true).
+            description: Configuration DNAC IP for syslog server (eg true).
             type: bool
           ipAddresses:
-            description: IP Address for syslog server
-              (eg 4.4.4.4).
+            description: IP Address for syslog server (eg 4.4.4.4).
             elements: str
             type: list
         type: dict
@@ -148,17 +128,14 @@ options:
         type: str
     type: dict
   siteId:
-    description: SiteId path parameter. Site id to which
-      site details to associate with the network settings.
+    description: SiteId path parameter. Site id to which site details to associate with the network settings.
     type: str
 requirements:
-  - dnacentersdk >= 2.10.1
-  - python >= 3.5
+  - dnacentersdk >= 2.11.0
+  - python >= 3.12
 seealso:
-  - name: Cisco DNA Center documentation for Network
-      Settings CreateNetwork
-    description: Complete reference of the CreateNetwork
-      API.
+  - name: Cisco DNA Center documentation for Network Settings CreateNetwork
+    description: Complete reference of the CreateNetwork API.
     link: https://developer.cisco.com/docs/dna-center/#!create-network
 notes:
   - SDK Method used are
