@@ -1,13 +1,16 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
+
 # Copyright (c) 2021, Cisco Systems
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
+
 DOCUMENTATION = r"""
 ---
 module: pnp_device_history_info
-short_description: Information module for Pnp Device History Info
+short_description: Information module for Pnp Device History
 description:
-  - This module represents an alias of the module pnp_device_history_v1_info
+  - Get all Pnp Device History.
+  - Returns history for a specific device. Serial number is a required parameter.
 version_added: '3.1.0'
 extends_documentation_fragment:
   - cisco.dnac.module_info
@@ -30,19 +33,22 @@ options:
       - SortOrder query parameter. Sort Order Ascending (asc) or Descending (des).
     type: str
 requirements:
-  - dnacentersdk >= 2.4.9
-  - python >= 3.5
+  - dnacentersdk >= 2.11.0
+  - python >= 3.12
 seealso:
-  - name: Cisco DNA Center documentation for Device Onboarding (PnP) GetDeviceHistoryV1
-    description: Complete reference of the GetDeviceHistoryV1 API.
+  - name: Cisco DNA Center documentation for Device Onboarding (PnP) GetDeviceHistory
+    description: Complete reference of the GetDeviceHistory API.
     link: https://developer.cisco.com/docs/dna-center/#!get-device-history
 notes:
-  - SDK Method used are device_onboarding_pnp.DeviceOnboardingPnp.get_device_history_v1,
-  - Paths used are get /dna/intent/api/v1/onboarding/pnp-device/history,
-  - It should be noted that this module is an alias of pnp_device_history_v1_info
+  - SDK Method used are
+    device_onboarding_pnp.DeviceOnboardingPnp.get_device_history,
+  - Paths used are
+    get /dna/intent/api/v1/onboarding/pnp-device/history,
 """
+
 EXAMPLES = r"""
-- name: Get all Pnp Device History Info
+---
+- name: Get all Pnp Device History
   cisco.dnac.pnp_device_history_info:
     dnac_host: "{{dnac_host}}"
     dnac_username: "{{dnac_username}}"
