@@ -7,8 +7,7 @@
 DOCUMENTATION = r"""
 ---
 module: pnp_global_settings_info
-short_description: Information module for Pnp Global
-  Settings
+short_description: Information module for Pnp Global Settings
 description:
   - Get all Pnp Global Settings.
   - Returns global PnP settings of the user.
@@ -21,13 +20,11 @@ options:
     description: Additional headers.
     type: dict
 requirements:
-  - dnacentersdk >= 2.10.1
-  - python >= 3.5
+  - dnacentersdk >= 2.11.0
+  - python >= 3.12
 seealso:
-  - name: Cisco DNA Center documentation for Device
-      Onboarding (PnP) GetPnPGlobalSettings
-    description: Complete reference of the GetPnPGlobalSettings
-      API.
+  - name: Cisco DNA Center documentation for Device Onboarding (PnP) GetPnPGlobalSettings
+    description: Complete reference of the GetPnPGlobalSettings API.
     link: https://developer.cisco.com/docs/dna-center/#!get-pn-p-global-settings
 notes:
   - SDK Method used are
