@@ -4,13 +4,15 @@
 # Copyright (c) 2021, Cisco Systems
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
 
-
 DOCUMENTATION = r"""
 ---
 module: pnp_virtual_account_deregister
 short_description: Resource module for Pnp Virtual Account Deregister
 description:
-- This module represents an alias of the module pnp_virtual_account_deregister_v1
+  - Manage operation delete of the resource Pnp Virtual Account Deregister. - > Deregisters the specified smart account &
+    virtual account info and the associated device information from the PnP System & database. The devices associated with
+    the deregistered virtual account are removed from the PnP database as well. The response payload contains the deregistered
+    smart & virtual account information.
 version_added: '3.1.0'
 extends_documentation_fragment:
   - cisco.dnac.module
@@ -23,23 +25,21 @@ options:
     description: Name query parameter. Virtual Account Name.
     type: str
 requirements:
-- dnacentersdk >= 2.4.9
-- python >= 3.5
+  - dnacentersdk >= 2.11.0
+  - python >= 3.12
 seealso:
-- name: Cisco DNA Center documentation for Device Onboarding (PnP) DeregisterVirtualAccountV1
-  description: Complete reference of the DeregisterVirtualAccountV1 API.
-  link: https://developer.cisco.com/docs/dna-center/#!deregister-virtual-account
+  - name: Cisco DNA Center documentation for Device Onboarding (PnP) DeregisterVirtualAccount
+    description: Complete reference of the DeregisterVirtualAccount API.
+    link: https://developer.cisco.com/docs/dna-center/#!deregister-virtual-account
 notes:
   - SDK Method used are
-    device_onboarding_pnp.DeviceOnboardingPnp.deregister_virtual_account_v1,
-
+    device_onboarding_pnp.DeviceOnboardingPnp.deregister_virtual_account,
   - Paths used are
     delete /dna/intent/api/v1/onboarding/pnp-settings/vacct,
-  - It should be noted that this module is an alias of pnp_virtual_account_deregister_v1
-
 """
 
 EXAMPLES = r"""
+---
 - name: Delete all
   cisco.dnac.pnp_virtual_account_deregister:
     dnac_host: "{{dnac_host}}"
@@ -51,7 +51,6 @@ EXAMPLES = r"""
     dnac_debug: "{{dnac_debug}}"
     domain: string
     name: string
-
 """
 RETURN = r"""
 dnac_response:
