@@ -7,12 +7,10 @@
 DOCUMENTATION = r"""
 ---
 module: sda_anycast_gateways_count_info
-short_description: Information module for Sda Anycast
-  Gateways Count
+short_description: Information module for Sda Anycast Gateways Count
 description:
   - Get all Sda Anycast Gateways Count.
-  - Returns the count of anycast gateways that match
-    the provided query parameters.
+  - Returns the count of anycast gateways that match the provided query parameters.
 version_added: '6.14.0'
 extends_documentation_fragment:
   - cisco.dnac.module_info
@@ -23,40 +21,32 @@ options:
     type: dict
   fabricId:
     description:
-      - FabricId query parameter. ID of the fabric the
-        anycast gateway is assigned to.
+      - FabricId query parameter. ID of the fabric the anycast gateway is assigned to.
     type: str
   virtualNetworkName:
     description:
-      - VirtualNetworkName query parameter. Name of
-        the virtual network associated with the anycast
-        gateways.
+      - VirtualNetworkName query parameter. Name of the virtual network associated with the anycast gateways.
     type: str
   ipPoolName:
     description:
-      - IpPoolName query parameter. Name of the IP pool
-        associated with the anycast gateways.
+      - IpPoolName query parameter. Name of the IP pool associated with the anycast gateways.
     type: str
   vlanName:
     description:
-      - VlanName query parameter. VLAN name of the anycast
-        gateways.
+      - VlanName query parameter. VLAN name of the anycast gateways.
     type: str
   vlanId:
     description:
       - >
-        VlanId query parameter. VLAN ID of the anycast
-        gateways. The allowed range for vlanId is 2-4093
-        except for reserved VLANs 1002-1005, 2046, and
-        4094.
+        VlanId query parameter. VLAN ID of the anycast gateways. The allowed range for vlanId is 2-4093 except
+        for reserved VLANs 1002-1005, 2046, and 4094.
     type: float
 requirements:
-  - dnacentersdk >= 2.10.1
-  - python >= 3.5
+  - dnacentersdk >= 2.11.0
+  - python >= 3.12
 seealso:
   - name: Cisco DNA Center documentation for SDA GetAnycastGatewayCount
-    description: Complete reference of the GetAnycastGatewayCount
-      API.
+    description: Complete reference of the GetAnycastGatewayCount API.
     link: https://developer.cisco.com/docs/dna-center/#!get-anycast-gateway-count
 notes:
   - SDK Method used are
