@@ -1,13 +1,16 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
+
 # Copyright (c) 2021, Cisco Systems
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
+
 DOCUMENTATION = r"""
 ---
 module: sda_extranet_policies_count_info
-short_description: Information module for Sda Extranet Policies Count Info
+short_description: Information module for Sda Extranet Policies Count
 description:
-  - This module represents an alias of the module sda_extranet_policies_count_v1_info
+  - Get all Sda Extranet Policies Count.
+  - Returns the count of extranet policies that match the provided query parameters.
 version_added: '6.14.0'
 extends_documentation_fragment:
   - cisco.dnac.module_info
@@ -17,19 +20,22 @@ options:
     description: Additional headers.
     type: dict
 requirements:
-  - dnacentersdk >= 2.4.9
-  - python >= 3.5
+  - dnacentersdk >= 2.11.0
+  - python >= 3.12
 seealso:
-  - name: Cisco DNA Center documentation for SDA GetExtranetPolicyCountV1
-    description: Complete reference of the GetExtranetPolicyCountV1 API.
+  - name: Cisco DNA Center documentation for SDA GetExtranetPolicyCount
+    description: Complete reference of the GetExtranetPolicyCount API.
     link: https://developer.cisco.com/docs/dna-center/#!get-extranet-policy-count
 notes:
-  - SDK Method used are sda.Sda.get_extranet_policy_count_v1,
-  - Paths used are get /dna/intent/api/v1/sda/extranetPolicies/count,
-  - It should be noted that this module is an alias of sda_extranet_policies_count_v1_info
+  - SDK Method used are
+    sda.Sda.get_extranet_policy_count,
+  - Paths used are
+    get /dna/intent/api/v1/sda/extranetPolicies/count,
 """
+
 EXAMPLES = r"""
-- name: Get all Sda Extranet Policies Count Info
+---
+- name: Get all Sda Extranet Policies Count
   cisco.dnac.sda_extranet_policies_count_info:
     dnac_host: "{{dnac_host}}"
     dnac_username: "{{dnac_username}}"
