@@ -7,8 +7,7 @@
 DOCUMENTATION = r"""
 ---
 module: sda_fabric_authentication_profile_info
-short_description: Information module for Sda Fabric
-  Authentication Profile
+short_description: Information module for Sda Fabric Authentication Profile
 description:
   - Get all Sda Fabric Authentication Profile.
   - Get default authentication profile from SDA Fabric.
@@ -30,12 +29,11 @@ options:
       - AuthenticateTemplateName query parameter.
     type: str
 requirements:
-  - dnacentersdk >= 2.10.1
-  - python >= 3.5
+  - dnacentersdk >= 2.11.0
+  - python >= 3.12
 seealso:
   - name: Cisco DNA Center documentation for SDA GetDefaultAuthenticationProfileFromSDAFabric
-    description: Complete reference of the GetDefaultAuthenticationProfileFromSDAFabric
-      API.
+    description: Complete reference of the GetDefaultAuthenticationProfileFromSDAFabric API.
     link: https://developer.cisco.com/docs/dna-center/#!get-default-authentication-profile-from-sda-fabric
 notes:
   - SDK Method used are
