@@ -7,12 +7,10 @@
 DOCUMENTATION = r"""
 ---
 module: sda_fabric_devices_layer2_handoffs_info
-short_description: Information module for Sda Fabricdevices
-  Layer2handoffs
+short_description: Information module for Sda Fabric Devices Layer2 Handoffs
 description:
-  - Get all Sda Fabricdevices Layer2handoffs.
-  - Returns a list of layer 2 handoffs of fabric devices
-    that match the provided query parameters.
+  - Get all Sda Fabric Devices Layer2 Handoffs.
+  - Returns a list of layer 2 handoffs of fabric devices that match the provided query parameters.
 version_added: '6.14.0'
 extends_documentation_fragment:
   - cisco.dnac.module_info
@@ -23,33 +21,28 @@ options:
     type: dict
   fabricId:
     description:
-      - FabricId query parameter. ID of the fabric this
-        device belongs to.
+      - FabricId query parameter. ID of the fabric this device belongs to.
     type: str
   networkDeviceId:
     description:
-      - NetworkDeviceId query parameter. Network device
-        ID of the fabric device.
+      - NetworkDeviceId query parameter. Network device ID of the fabric device.
     type: str
   offset:
     description:
-      - Offset query parameter. Starting record for
-        pagination.
+      - Offset query parameter. Starting record for pagination.
     type: int
   limit:
     description:
       - >
-        Limit query parameter. Maximum number of records
-        to return. The maximum number of objects supported
-        in a single request is 500.
+        Limit query parameter. Maximum number of records to return. The maximum number of objects supported in a
+        single request is 500.
     type: int
 requirements:
-  - dnacentersdk >= 2.10.1
-  - python >= 3.5
+  - dnacentersdk >= 2.11.0
+  - python >= 3.12
 seealso:
   - name: Cisco DNA Center documentation for SDA GetFabricDevicesLayer2Handoffs
-    description: Complete reference of the GetFabricDevicesLayer2Handoffs
-      API.
+    description: Complete reference of the GetFabricDevicesLayer2Handoffs API.
     link: https://developer.cisco.com/docs/dna-center/#!get-fabric-devices-layer-2-handoffs
 notes:
   - SDK Method used are
@@ -60,8 +53,8 @@ notes:
 
 EXAMPLES = r"""
 ---
-- name: Get all Sda Fabricdevices Layer2handoffs
-  cisco.dnac.sda_fabricDevices_layer2Handoffs_info:
+- name: Get all Sda Fabric Devices Layer2 Handoffs
+  cisco.dnac.sda_fabric_devices_layer2_handoffs_info:
     dnac_host: "{{dnac_host}}"
     dnac_username: "{{dnac_username}}"
     dnac_password: "{{dnac_password}}"
@@ -86,11 +79,19 @@ dnac_response:
       "response": [
         {
           "id": "string",
-          "networkDeviceId": "string",
-          "fabricId": "string",
-          "interfaceName": "string",
-          "internalVlanId": 0,
-          "externalVlanId": 0
+          "name": "string",
+          "siteId": "string",
+          "type": "string",
+          "ipTransitSettings": {
+            "routingProtocolName": "string",
+            "autonomousSystemNumber": "string"
+          },
+          "sdaTransitSettings": {
+            "isMulticastOverTransitEnabled": true,
+            "controlPlaneNetworkDeviceIds": [
+              "string"
+            ]
+          }
         }
       ],
       "version": "string"
