@@ -7,11 +7,10 @@
 DOCUMENTATION = r"""
 ---
 module: sda_layer3_virtual_networks_info
-short_description: Information module for Sda Layer3virtualnetworks
+short_description: Information module for Sda Layer3 Virtual Networks
 description:
-  - Get all Sda Layer3virtualnetworks.
-  - Returns a list of layer 3 virtual networks that
-    match the provided query parameters.
+  - Get all Sda Layer3 Virtual Networks.
+  - Returns a list of layer 3 virtual networks that match the provided query parameters.
 version_added: '6.15.0'
 extends_documentation_fragment:
   - cisco.dnac.module_info
@@ -22,39 +21,32 @@ options:
     type: dict
   virtualNetworkName:
     description:
-      - VirtualNetworkName query parameter. Name of
-        the layer 3 virtual network.
+      - VirtualNetworkName query parameter. Name of the layer 3 virtual network.
     type: str
   fabricId:
     description:
-      - FabricId query parameter. ID of the fabric the
-        layer 3 virtual network is assigned to.
+      - FabricId query parameter. ID of the fabric the layer 3 virtual network is assigned to.
     type: str
   anchoredSiteId:
     description:
-      - AnchoredSiteId query parameter. Fabric ID of
-        the fabric site the layer 3 virtual network
-        is anchored at.
+      - AnchoredSiteId query parameter. Fabric ID of the fabric site the layer 3 virtual network is anchored at.
     type: str
   offset:
     description:
-      - Offset query parameter. Starting record for
-        pagination.
+      - Offset query parameter. Starting record for pagination.
     type: int
   limit:
     description:
       - >
-        Limit query parameter. Maximum number of records
-        to return. The maximum number of objects supported
-        in a single request is 500.
+        Limit query parameter. Maximum number of records to return. The maximum number of objects supported in a
+        single request is 500.
     type: int
 requirements:
-  - dnacentersdk >= 2.10.1
-  - python >= 3.5
+  - dnacentersdk >= 2.11.0
+  - python >= 3.12
 seealso:
   - name: Cisco DNA Center documentation for SDA GetLayer3VirtualNetworks
-    description: Complete reference of the GetLayer3VirtualNetworks
-      API.
+    description: Complete reference of the GetLayer3VirtualNetworks API.
     link: https://developer.cisco.com/docs/dna-center/#!get-layer-3-virtual-networks
 notes:
   - SDK Method used are
@@ -65,8 +57,8 @@ notes:
 
 EXAMPLES = r"""
 ---
-- name: Get all Sda Layer3virtualnetworks
-  cisco.dnac.sda_layer3VirtualNetworks_info:
+- name: Get all Sda Layer3 Virtual Networks
+  cisco.dnac.sda_layer3_virtual_networks_info:
     dnac_host: "{{dnac_host}}"
     dnac_username: "{{dnac_username}}"
     dnac_password: "{{dnac_password}}"
