@@ -1,13 +1,16 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
+
 # Copyright (c) 2021, Cisco Systems
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
+
 DOCUMENTATION = r"""
 ---
 module: sda_port_channels_info
-short_description: Information module for Sda Port Channels Info
+short_description: Information module for Sda Port Channels
 description:
-  - This module represents an alias of the module sda_port_channels_v1_info
+  - Get all Sda Port Channels.
+  - Returns a list of port channels that match the provided query parameters.
 version_added: '6.15.0'
 extends_documentation_fragment:
   - cisco.dnac.module_info
@@ -31,35 +34,43 @@ options:
   connectedDeviceType:
     description:
       - >
-        ConnectedDeviceType query parameter. Connected device type of the port channel.
-        The allowed values are
+        ConnectedDeviceType query parameter. Connected device type of the port channel. The allowed values are
         TRUNK, EXTENDED_NODE.
     type: str
+  nativeVlanId:
+    description:
+      - >
+        NativeVlanId query parameter. Native VLAN of the port channel, this option is only applicable to TRUNK
+        connectedDeviceType.(VLAN must be between 1 and 4094. In cases value not set when connectedDeviceType is
+        TRUNK, default value will be '1').
+    type: float
   offset:
     description:
       - Offset query parameter. Starting record for pagination.
-    type: float
+    type: int
   limit:
     description:
       - >
-        Limit query parameter. Maximum number of records to return. The maximum number
-        of objects supported in a
+        Limit query parameter. Maximum number of records to return. The maximum number of objects supported in a
         single request is 500.
-    type: float
+    type: int
 requirements:
-  - dnacentersdk >= 2.4.9
-  - python >= 3.5
+  - dnacentersdk >= 2.11.0
+  - python >= 3.12
 seealso:
-  - name: Cisco DNA Center documentation for SDA GetPortChannelsV1
-    description: Complete reference of the GetPortChannelsV1 API.
-    link: https://developer.cisco.com/docs/dna-center/#!get-port-channels
+  - name: Cisco DNA Center documentation for SDA GetPortChannelsConnectivity
+    description: Complete reference of the GetPortChannelsConnectivity API.
+    link: https://developer.cisco.com/docs/dna-center/#!get-port-channels-connectivity
 notes:
-  - SDK Method used are sda.Sda.get_port_channels_v1,
-  - Paths used are get /dna/intent/api/v1/sda/portChannels,
-  - It should be noted that this module is an alias of sda_port_channels_v1_info
+  - SDK Method used are
+    sda.Sda.get_port_channels_connectivity,
+  - Paths used are
+    get /dna/intent/api/v1/sda/portChannels,
 """
+
 EXAMPLES = r"""
-- name: Get all Sda Port Channels Info
+---
+- name: Get all Sda Port Channels
   cisco.dnac.sda_port_channels_info:
     dnac_host: "{{dnac_host}}"
     dnac_username: "{{dnac_username}}"
@@ -73,6 +84,7 @@ EXAMPLES = r"""
     networkDeviceId: string
     portChannelName: string
     connectedDeviceType: string
+    nativeVlanId: 0
     offset: 0
     limit: 0
   register: result
@@ -95,7 +107,9 @@ dnac_response:
           ],
           "connectedDeviceType": "string",
           "protocol": "string",
-          "description": "string"
+          "description": "string",
+          "nativeVlanId": 0,
+          "allowedVlanRanges": "string"
         }
       ],
       "version": "string"
