@@ -7,12 +7,10 @@
 DOCUMENTATION = r"""
 ---
 module: sda_provision_devices_info
-short_description: Information module for Sda Provision
-  Devices
+short_description: Information module for Sda Provision Devices
 description:
   - Get all Sda Provision Devices.
-  - Returns the list of provisioned devices based on
-    query parameters.
+  - Returns the list of provisioned devices based on query parameters.
 version_added: '6.14.0'
 extends_documentation_fragment:
   - cisco.dnac.module_info
@@ -27,32 +25,28 @@ options:
     type: str
   networkDeviceId:
     description:
-      - NetworkDeviceId query parameter. ID of the network
-        device.
+      - NetworkDeviceId query parameter. ID of the network device.
     type: str
   siteId:
     description:
-      - SiteId query parameter. ID of the site hierarchy.
+      - SiteId query parameter. ID of the site. This will fetch all the devices in this site hierarchy.
     type: str
   offset:
     description:
-      - Offset query parameter. Starting record for
-        pagination.
+      - Offset query parameter. Starting record for pagination.
     type: int
   limit:
     description:
       - >
-        Limit query parameter. Maximum number of devices
-        to return. The maximum number of objects supported
-        in a single request is 500.
+        Limit query parameter. Maximum number of devices to return. The maximum number of objects supported in a
+        single request is 500.
     type: int
 requirements:
-  - dnacentersdk >= 2.10.1
-  - python >= 3.5
+  - dnacentersdk >= 2.11.0
+  - python >= 3.12
 seealso:
   - name: Cisco DNA Center documentation for SDA GetProvisionedDevices
-    description: Complete reference of the GetProvisionedDevices
-      API.
+    description: Complete reference of the GetProvisionedDevices API.
     link: https://developer.cisco.com/docs/dna-center/#!get-provisioned-devices
 notes:
   - SDK Method used are
