@@ -37,13 +37,11 @@ options:
         type: str
     type: list
 requirements:
-  - dnacentersdk >= 2.10.1
-  - python >= 3.5
+  - dnacentersdk >= 2.11.0
+  - python >= 3.12
 seealso:
-  - name: Cisco DNA Center documentation for Discovery
-      CreateUpdateSNMPProperties
-    description: Complete reference of the CreateUpdateSNMPProperties
-      API.
+  - name: Cisco DNA Center documentation for Discovery CreateUpdateSNMPProperties
+    description: Complete reference of the CreateUpdateSNMPProperties API.
     link: https://developer.cisco.com/docs/dna-center/#!create-update-snmp-properties
 notes:
   - SDK Method used are
