@@ -7,12 +7,10 @@
 DOCUMENTATION = r"""
 ---
 module: wireless_controllers_anchor_managed_ap_locations_info
-short_description: Information module for Wireless Controllers
-  Anchor Managed Ap Locations
+short_description: Information module for Wireless Controllers Anchor Managed Ap Locations
 description:
   - Get all Wireless Controllers Anchor Managed Ap Locations.
-  - Retrieves all the details of Anchor Managed AP locations
-    associated with the specific Wireless Controller.
+  - Retrieves all the details of Anchor Managed AP locations associated with the specific Wireless Controller.
 version_added: '6.15.0'
 extends_documentation_fragment:
   - cisco.dnac.module_info
@@ -24,30 +22,25 @@ options:
   networkDeviceId:
     description:
       - >
-        NetworkDeviceId path parameter. Obtain the network
-        device ID value by using the API call GET /dna/intent/api/v1/network-device/ip-address/${ipAddress}.
+        NetworkDeviceId path parameter. Obtain the network device ID value by using the API call GET
+        /dna/intent/api/v1/network-device/ip-address/${ipAddress}.
     type: str
   limit:
     description:
       - >
-        Limit query parameter. The number of records
-        to show for this page. Default is 500 if not
-        specified. Maximum allowed limit is 500.
-    type: float
+        Limit query parameter. The number of records to show for this page. Default is 500 if not specified.
+        Maximum allowed limit is 500.
+    type: int
   offset:
     description:
-      - Offset query parameter. The first record to
-        show for this page; the first record is numbered
-        1.
-    type: float
+      - Offset query parameter. The first record to show for this page; the first record is numbered 1.
+    type: int
 requirements:
-  - dnacentersdk >= 2.10.1
-  - python >= 3.5
+  - dnacentersdk >= 2.11.0
+  - python >= 3.12
 seealso:
-  - name: Cisco DNA Center documentation for Wireless
-      GetAnchorManagedAPLocationsForSpecificWirelessController
-    description: Complete reference of the GetAnchorManagedAPLocationsForSpecificWirelessController
-      API.
+  - name: Cisco DNA Center documentation for Wireless GetAnchorManagedAPLocationsForSpecificWirelessController
+    description: Complete reference of the GetAnchorManagedAPLocationsForSpecificWirelessController API.
     link: https://developer.cisco.com/docs/dna-center/#!get-anchor-managed-ap-locations-for-specific-wireless-controller
 notes:
   - SDK Method used are
@@ -58,8 +51,7 @@ notes:
 
 EXAMPLES = r"""
 ---
-- name: Get all Wireless Controllers Anchor Managed
-    Ap Locations
+- name: Get all Wireless Controllers Anchor Managed Ap Locations
   cisco.dnac.wireless_controllers_anchor_managed_ap_locations_info:
     dnac_host: "{{dnac_host}}"
     dnac_username: "{{dnac_username}}"
