@@ -1,13 +1,17 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
+
 # Copyright (c) 2021, Cisco Systems
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
+
 DOCUMENTATION = r"""
 ---
 module: wireless_dynamic_interface
 short_description: Resource module for Wireless Dynamic Interface
 description:
-  - This module represents an alias of the module wireless_dynamic_interface_v1
+  - Manage operations create and delete of the resource Wireless Dynamic Interface.
+  - API to create or update an dynamic interface.
+  - Delete a dynamic interface.
 version_added: '3.1.0'
 extends_documentation_fragment:
   - cisco.dnac.module
@@ -23,21 +27,26 @@ options:
     description: Vlan Id.
     type: float
 requirements:
-  - dnacentersdk >= 2.4.9
-  - python >= 3.5
+  - dnacentersdk >= 2.11.0
+  - python >= 3.12
 seealso:
-  - name: Cisco DNA Center documentation for Wireless CreateUpdateDynamicInterfaceV1
-    description: Complete reference of the CreateUpdateDynamicInterfaceV1 API.
+  - name: Cisco DNA Center documentation for Wireless CreateUpdateDynamicInterface
+    description: Complete reference of the CreateUpdateDynamicInterface API.
     link: https://developer.cisco.com/docs/dna-center/#!create-update-dynamic-interface
-  - name: Cisco DNA Center documentation for Wireless DeleteDynamicInterfaceV1
-    description: Complete reference of the DeleteDynamicInterfaceV1 API.
+  - name: Cisco DNA Center documentation for Wireless DeleteDynamicInterface
+    description: Complete reference of the DeleteDynamicInterface API.
     link: https://developer.cisco.com/docs/dna-center/#!delete-dynamic-interface
 notes:
-  - SDK Method used are wireless.Wireless.create_update_dynamic_interface_v1, wireless.Wireless.delete_dynamic_interface_v1,
-  - Paths used are post /dna/intent/api/v1/wireless/dynamic-interface, delete /dna/intent/api/v1/wireless/dynamic-interface,
-  - It should be noted that this module is an alias of wireless_dynamic_interface_v1
+  - SDK Method used are
+    wireless.Wireless.create_update_dynamic_interface,
+    wireless.Wireless.delete_dynamic_interface,
+  - Paths used are
+    post /dna/intent/api/v1/wireless/dynamic-interface,
+    delete /dna/intent/api/v1/wireless/dynamic-interface,
 """
+
 EXAMPLES = r"""
+---
 - name: Delete all
   cisco.dnac.wireless_dynamic_interface:
     dnac_host: "{{dnac_host}}"
@@ -60,6 +69,7 @@ EXAMPLES = r"""
     dnac_version: "{{dnac_version}}"
     dnac_debug: "{{dnac_debug}}"
     state: present
+    headers: '{{my_headers | from_json}}'
     interfaceName: string
     vlanId: 0
 """
