@@ -9,14 +9,10 @@ DOCUMENTATION = r"""
 module: wireless_profile
 short_description: Resource module for Wireless Profile
 description:
-  - Manage operations create, update and delete of the
-    resource Wireless Profile.
-  - Creates Wireless Network Profile on Cisco DNA Center
-    and associates sites and SSIDs to it.
-  - Delete the Wireless Profile whose name is provided.
-    - > Updates the wireless Network Profile with updated
-    details provided. All sites to be present in the
-    network profile should be provided.
+  - Manage operations create, update and delete of the resource Wireless Profile.
+  - Creates Wireless Network Profile on Cisco DNA Center and associates sites and SSIDs to it.
+  - Delete the Wireless Profile whose name is provided. - > Updates the wireless Network Profile with updated details provided.
+    All sites to be present in the network profile should be provided.
 version_added: '3.1.0'
 extends_documentation_fragment:
   - cisco.dnac.module
@@ -29,8 +25,7 @@ options:
         description: Profile Name.
         type: str
       sites:
-        description: Array of site name hierarchies(eg
-          "Global/aaa/zzz", "Global/aaa/zzz").
+        description: Array of site name hierarchies(eg "Global/aaa/zzz", "Global/aaa/zzz").
         elements: str
         type: list
       ssidDetails:
@@ -38,19 +33,16 @@ options:
         elements: dict
         suboptions:
           enableFabric:
-            description: True if ssid is fabric else
-              false.
+            description: true if ssid is fabric else false.
             type: bool
           flexConnect:
             description: Wireless Profile's flexConnect.
             suboptions:
               enableFlexConnect:
-                description: True if flex connect is
-                  enabled else false.
+                description: true if flex connect is enabled else false.
                 type: bool
               localToVlan:
-                description: Local to VLAN ID. Required
-                  if enableFlexConnect is true.
+                description: Local to VLAN ID. Required if enableFlexConnect is true.
                 type: int
             type: dict
           interfaceName:
@@ -68,27 +60,20 @@ options:
         type: list
     type: dict
   wirelessProfileName:
-    description: WirelessProfileName path parameter.
-      Wireless Profile Name.
+    description: WirelessProfileName path parameter. Wireless Profile Name.
     type: str
 requirements:
-  - dnacentersdk >= 2.10.1
-  - python >= 3.5
+  - dnacentersdk >= 2.11.0
+  - python >= 3.12
 seealso:
-  - name: Cisco DNA Center documentation for Wireless
-      CreateWirelessProfile
-    description: Complete reference of the CreateWirelessProfile
-      API.
+  - name: Cisco DNA Center documentation for Wireless CreateWirelessProfile
+    description: Complete reference of the CreateWirelessProfile API.
     link: https://developer.cisco.com/docs/dna-center/#!create-wireless-profile
-  - name: Cisco DNA Center documentation for Wireless
-      DeleteWirelessProfile
-    description: Complete reference of the DeleteWirelessProfile
-      API.
+  - name: Cisco DNA Center documentation for Wireless DeleteWirelessProfile
+    description: Complete reference of the DeleteWirelessProfile API.
     link: https://developer.cisco.com/docs/dna-center/#!delete-wireless-profile
-  - name: Cisco DNA Center documentation for Wireless
-      UpdateWirelessProfile
-    description: Complete reference of the UpdateWirelessProfile
-      API.
+  - name: Cisco DNA Center documentation for Wireless UpdateWirelessProfile
+    description: Complete reference of the UpdateWirelessProfile API.
     link: https://developer.cisco.com/docs/dna-center/#!update-wireless-profile
 notes:
   - SDK Method used are
@@ -114,7 +99,7 @@ EXAMPLES = r"""
     dnac_debug: "{{dnac_debug}}"
     state: absent
     wirelessProfileName: string
-- name: Update all
+- name: Create
   cisco.dnac.wireless_profile:
     dnac_host: "{{dnac_host}}"
     dnac_username: "{{dnac_username}}"
@@ -137,7 +122,7 @@ EXAMPLES = r"""
           name: string
           policyProfileName: string
           wlanProfileName: string
-- name: Create
+- name: Update all
   cisco.dnac.wireless_profile:
     dnac_host: "{{dnac_host}}"
     dnac_username: "{{dnac_username}}"
