@@ -4,13 +4,15 @@
 # Copyright (c) 2021, Cisco Systems
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
 
-
 DOCUMENTATION = r"""
 ---
 module: wireless_settings_interfaces_info
-short_description: Information module for Wireless Settings Interfaces Info
+short_description: Information module for Wireless Settings Interfaces
 description:
-- This module represents an alias of the module wireless_settings_interfaces_v1_info
+  - Get all Wireless Settings Interfaces.
+  - Get Wireless Settings Interfaces by id.
+  - This API allows the user to get all Interfaces.
+  - This API allows the user to get an interface by ID.
 version_added: '6.15.0'
 extends_documentation_fragment:
   - cisco.dnac.module_info
@@ -21,50 +23,48 @@ options:
     type: dict
   limit:
     description:
-    - >
-      Limit query parameter. The number of records to show for this page. Default is 500 if not specified. Maximum
-      allowed limit is 500.
-    type: float
+      - >
+        Limit query parameter. The number of records to show for this page. Default is 500 if not specified.
+        Maximum allowed limit is 500.
+    type: int
   offset:
     description:
-    - Offset query parameter. The first record to show for this page. The first record is numbered 1.
-    type: float
+      - Offset query parameter. The first record to show for this page. The first record is numbered 1.
+    type: int
   interfaceName:
     description:
-    - InterfaceName query parameter. Interface Name.
+      - InterfaceName query parameter. Interface Name.
     type: str
   vlanId:
     description:
-    - VlanId query parameter. Vlan Id.
+      - VlanId query parameter. Vlan Id.
     type: float
   id:
     description:
-    - Id path parameter. Interface ID.
+      - Id path parameter. Interface ID.
     type: str
 requirements:
-- dnacentersdk >= 2.4.9
-- python >= 3.5
+  - dnacentersdk >= 2.11.0
+  - python >= 3.12
 seealso:
-- name: Cisco DNA Center documentation for Wireless GetInterfaceByIDV1
-  description: Complete reference of the GetInterfaceByIDV1 API.
-  link: https://developer.cisco.com/docs/dna-center/#!get-interface-by-id
-- name: Cisco DNA Center documentation for Wireless GetInterfacesV1
-  description: Complete reference of the GetInterfacesV1 API.
-  link: https://developer.cisco.com/docs/dna-center/#!get-interfaces
+  - name: Cisco DNA Center documentation for Wireless GetInterfaceByID
+    description: Complete reference of the GetInterfaceByID API.
+    link: https://developer.cisco.com/docs/dna-center/#!get-interface-by-id
+  - name: Cisco DNA Center documentation for Wireless GetInterfaces
+    description: Complete reference of the GetInterfaces API.
+    link: https://developer.cisco.com/docs/dna-center/#!get-interfaces
 notes:
   - SDK Method used are
-    wireless.Wireless.get_interface_by_id_v1,
-    wireless.Wireless.get_interfaces_v1,
-
+    wireless.Wireless.get_interface_by_id,
+    wireless.Wireless.get_interfaces,
   - Paths used are
     get /dna/intent/api/v1/wirelessSettings/interfaces,
     get /dna/intent/api/v1/wirelessSettings/interfaces/{id},
-  - It should be noted that this module is an alias of wireless_settings_interfaces_v1_info
-
 """
 
 EXAMPLES = r"""
-- name: Get all Wireless Settings Interfaces Info
+---
+- name: Get all Wireless Settings Interfaces
   cisco.dnac.wireless_settings_interfaces_info:
     dnac_host: "{{dnac_host}}"
     dnac_username: "{{dnac_username}}"
@@ -79,8 +79,7 @@ EXAMPLES = r"""
     interfaceName: string
     vlanId: 0
   register: result
-
-- name: Get Wireless Settings Interfaces Info by id
+- name: Get Wireless Settings Interfaces by id
   cisco.dnac.wireless_settings_interfaces_info:
     dnac_host: "{{dnac_host}}"
     dnac_username: "{{dnac_username}}"
@@ -92,7 +91,6 @@ EXAMPLES = r"""
     headers: "{{my_headers | from_json}}"
     id: string
   register: result
-
 """
 RETURN = r"""
 dnac_response:
@@ -101,11 +99,13 @@ dnac_response:
   type: dict
   sample: >
     {
-      "response": {
-        "interfaceName": "string",
-        "vlanId": 0,
-        "id": "string"
-      },
+      "response": [
+        {
+          "interfaceName": "string",
+          "vlanId": 0,
+          "id": "string"
+        }
+      ],
       "version": "string"
     }
 """
