@@ -6,10 +6,12 @@
 
 DOCUMENTATION = r"""
 module: networks_sensor_mqtt_brokers
-short_description: Resource module for networks _sensor _mqtt _brokers
+short_description: Resource module for networks _sensor _mqttbrokers
 description:
-  - Manage operation update of the resource networks _sensor _mqtt _brokers. - > Update the sensor settings of an MQTT broker. To update the broker
-    itself, use /networks/{networkId}/mqttBrokers/{mqttBrokerId}.
+  - Manage operation update of the resource networks _sensor _mqttbrokers.
+  - >
+    Update the sensor settings of an MQTT broker. To update the broker itself, use
+    /networks/{networkId}/mqttBrokers/{mqttBrokerId}.
 version_added: '1.0.0'
 extends_documentation_fragment:
   - cisco.meraki.module
@@ -74,7 +76,7 @@ meraki_response:
   type: dict
   sample: >
     {
-      "enabled": true,
-      "mqttBrokerId": "string"
+      "mqttBrokerId": "string",
+      "enabled": true
     }
 """
