@@ -1,16 +1,11 @@
 #!/usr/bin/python
-# -*- coding: utf-8 -*-
-
 # Copyright (c) 2024 Felix Fontein <felix@fontein.de>
 # GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
 # SPDX-License-Identifier: GPL-3.0-or-later
 
-from __future__ import absolute_import, division, print_function
-__metaclass__ = type
+from __future__ import annotations
 
-
-DOCUMENTATION = '''
----
+DOCUMENTATION = """
 module: acme_certificate_order_finalize
 author: Felix Fontein (@felixfontein)
 version_added: 2.24.0
@@ -19,9 +14,8 @@ description:
   - Finalizes an ACME v2 order and obtains the certificate and certificate chains.
     This is the final step of obtaining a new certificate with the
     L(ACME protocol,https://tools.ietf.org/html/rfc8555) from a Certificate
-    Authority such as L(Let's Encrypt,https://letsencrypt.org/) or
-    L(Buypass,https://www.buypass.com/). This module does not support ACME v1, the
-    original version of the ACME protocol before standardization.
+    Authority such as L(Let's Encrypt,https://letsencrypt.org/).
+    This module does not support ACME v1, the original version of the ACME protocol before standardization.
   - This module needs to be used in conjunction with the
     M(community.crypto.acme_certificate_order_create) and.
     M(community.crypto.acme_certificate_order_validate) modules.
@@ -36,10 +30,6 @@ seealso:
     description: Documentation for the Let's Encrypt Certification Authority.
                  Provides useful information for example on rate limits.
     link: https://letsencrypt.org/docs/
-  - name: Buypass Go SSL
-    description: Documentation for the Buypass Certification Authority.
-                 Provides useful information for example on rate limits.
-    link: https://www.buypass.com/ssl/products/acme
   - name: Automatic Certificate Management Environment (ACME)
     description: The specification of the ACME protocol (RFC 8555).
     link: https://tools.ietf.org/html/rfc8555
@@ -52,12 +42,12 @@ seealso:
   - module: community.crypto.acme_certificate_deactivate_authz
     description: Allows to deactivate (invalidate) ACME v2 orders.
 extends_documentation_fragment:
-  - community.crypto.acme.basic
-  - community.crypto.acme.account
-  - community.crypto.acme.certificate
-  - community.crypto.attributes
-  - community.crypto.attributes.actiongroup_acme
-  - community.crypto.attributes.files
+  - community.crypto._acme.basic
+  - community.crypto._acme.account
+  - community.crypto._acme.certificate
+  - community.crypto._attributes
+  - community.crypto._attributes.actiongroup_acme
+  - community.crypto._attributes.files
 attributes:
   check_mode:
     support: none
@@ -169,9 +159,10 @@ options:
           - "The identifier must be of the form
              V(C4:A7:B1:A4:7B:2C:71:FA:DB:E1:4B:90:75:FF:C4:15:60:85:89:10)."
         type: str
-'''
+"""
 
-EXAMPLES = r'''
+EXAMPLES = r"""
+---
 ### Example with HTTP-01 challenge ###
 
 - name: Create a challenge for sample.com using a account key from a variable
@@ -219,12 +210,12 @@ EXAMPLES = r'''
     fullchain_dest: /etc/httpd/ssl/sample.com-fullchain.crt
     chain_dest: /etc/httpd/ssl/sample.com-intermediate.crt
 
+---
 ### Example with DNS challenge against production ACME server ###
 
 - name: Create a challenge for sample.com using a account key file.
   community.crypto.acme_certificate_order_create:
     acme_directory: https://acme-v01.api.letsencrypt.org/directory
-    acme_version: 2
     account_key_src: /etc/pki/cert/private/account.key
     csr: /etc/pki/cert/csr/sample.com.csr
   register: sample_com_challenge
@@ -247,7 +238,6 @@ EXAMPLES = r'''
 - name: Let the challenge be validated
   community.crypto.acme_certificate_order_validate:
     acme_directory: https://acme-v01.api.letsencrypt.org/directory
-    acme_version: 2
     account_key_src: /etc/pki/cert/private/account.key
     order_uri: "{{ sample_com_challenge.order_uri }}"
     challenge: dns-01
@@ -255,16 +245,15 @@ EXAMPLES = r'''
 - name: Retrieve the cert and intermediate certificate
   community.crypto.acme_certificate_order_finalize:
     acme_directory: https://acme-v01.api.letsencrypt.org/directory
-    acme_version: 2
     account_key_src: /etc/pki/cert/private/account.key
     csr: /etc/pki/cert/csr/sample.com.csr
     order_uri: "{{ sample_com_challenge.order_uri }}"
     cert_dest: /etc/httpd/ssl/sample.com.crt
     fullchain_dest: /etc/httpd/ssl/sample.com-fullchain.crt
     chain_dest: /etc/httpd/ssl/sample.com-intermediate.crt
-'''
+"""
 
-RETURN = '''
+RETURN = """
 account_uri:
   description: ACME account URI.
   returned: success
@@ -320,58 +309,77 @@ selected_chain:
           as concatenated PEM certificates.
       type: str
       returned: always
-'''
+"""
 
-from ansible_collections.community.crypto.plugins.module_utils.acme.acme import (
+import typing as t
+
+from ansible_collections.community.crypto.plugins.module_utils._acme.acme import (
     create_backend,
     create_default_argspec,
 )
-
-from ansible_collections.community.crypto.plugins.module_utils.acme.errors import (
+from ansible_collections.community.crypto.plugins.module_utils._acme.certificate import (
+    ACMECertificateClient,
+)
+from ansible_collections.community.crypto.plugins.module_utils._acme.errors import (
     ModuleFailException,
 )
 
-from ansible_collections.community.crypto.plugins.module_utils.acme.certificate import (
-    ACMECertificateClient,
-)
+if t.TYPE_CHECKING:
+    from ansible_collections.community.crypto.plugins.module_utils._acme.certificates import (  # pragma: no cover
+        CertificateChain,
+    )
 
 
-def main():
+def main() -> t.NoReturn:
     argument_spec = create_default_argspec(with_certificate=True)
     argument_spec.update_argspec(
-        order_uri=dict(type='str', required=True),
-        cert_dest=dict(type='path'),
-        fullchain_dest=dict(type='path'),
-        chain_dest=dict(type='path'),
-        deactivate_authzs=dict(type='str', default='always', choices=['never', 'always', 'on_error', 'on_success']),
-        retrieve_all_alternates=dict(type='bool', default=False),
-        select_chain=dict(type='list', elements='dict', options=dict(
-            test_certificates=dict(type='str', default='all', choices=['first', 'last', 'all']),
-            issuer=dict(type='dict'),
-            subject=dict(type='dict'),
-            subject_key_identifier=dict(type='str'),
-            authority_key_identifier=dict(type='str'),
-        )),
+        order_uri={"type": "str", "required": True},
+        cert_dest={"type": "path"},
+        fullchain_dest={"type": "path"},
+        chain_dest={"type": "path"},
+        deactivate_authzs={
+            "type": "str",
+            "default": "always",
+            "choices": ["never", "always", "on_error", "on_success"],
+        },
+        retrieve_all_alternates={"type": "bool", "default": False},
+        select_chain={
+            "type": "list",
+            "elements": "dict",
+            "options": {
+                "test_certificates": {
+                    "type": "str",
+                    "default": "all",
+                    "choices": ["first", "last", "all"],
+                },
+                "issuer": {"type": "dict"},
+                "subject": {"type": "dict"},
+                "subject_key_identifier": {"type": "str"},
+                "authority_key_identifier": {"type": "str"},
+            },
+        },
     )
     module = argument_spec.create_ansible_module()
-    if module.params['acme_version'] == 1:
-        module.fail_json('The module does not support acme_version=1')
 
-    backend = create_backend(module, False)
+    backend = create_backend(module, needs_acme_v2=False)
 
     try:
-        client = ACMECertificateClient(module, backend)
-        select_chain_matcher = client.parse_select_chain(module.params['select_chain'])
-        other = dict()
+        client = ACMECertificateClient(module=module, backend=backend)
+        select_chain_matcher = client.parse_select_chain(module.params["select_chain"])
+        other = {}
         done = False
         order = None
         try:
             # Step 1: load order
             order = client.load_order()
 
-            download_all_chains = len(select_chain_matcher) > 0 or module.params['retrieve_all_alternates']
+            download_all_chains = (
+                len(select_chain_matcher) > 0
+                or module.params["retrieve_all_alternates"]
+            )
             changed = False
-            if order.status == 'valid':
+            alternate_chains: list[CertificateChain] | None
+            if order.status == "valid":
                 # Step 2 and 3: download certificate(s) and chain(s)
                 cert, alternate_chains = client.download_certificate(
                     order,
@@ -394,46 +402,48 @@ def main():
             # Step 4: pick chain, write certificates, and provide return values
             if alternate_chains is not None:
                 # Prepare return value for all alternate chains
-                if module.params['retrieve_all_alternates']:
+                if module.params["retrieve_all_alternates"]:
                     all_chains = [cert.to_json()]
                     for alt_chain in alternate_chains:
                         all_chains.append(alt_chain.to_json())
-                    other['all_chains'] = all_chains
+                    other["all_chains"] = all_chains
 
                 # Try to select alternate chain depending on criteria
                 if select_chain_matcher:
-                    matching_chain = client.find_matching_chain([cert] + alternate_chains, select_chain_matcher)
+                    matching_chain = client.find_matching_chain(
+                        chains=[cert] + alternate_chains,
+                        select_chain_matcher=select_chain_matcher,
+                    )
                     if matching_chain:
                         cert = matching_chain
                     else:
-                        module.debug('Found no matching alternative chain')
+                        module.debug("Found no matching alternative chain")
 
             if client.write_cert_chain(
-                cert,
-                cert_dest=module.params['cert_dest'],
-                fullchain_dest=module.params['fullchain_dest'],
-                chain_dest=module.params['chain_dest'],
+                cert=cert,
+                cert_dest=module.params["cert_dest"],
+                fullchain_dest=module.params["fullchain_dest"],
+                chain_dest=module.params["chain_dest"],
             ):
                 changed = True
 
             done = True
         finally:
             if (
-                module.params['deactivate_authzs'] == 'always' or
-                (module.params['deactivate_authzs'] == 'on_success' and done) or
-                (module.params['deactivate_authzs'] == 'on_error' and not done)
-            ):
-                if order:
-                    client.deactivate_authzs(order)
+                module.params["deactivate_authzs"] == "always"
+                or (module.params["deactivate_authzs"] == "on_success" and done)
+                or (module.params["deactivate_authzs"] == "on_error" and not done)
+            ) and order:
+                client.deactivate_authzs(order)
         module.exit_json(
             changed=changed,
             account_uri=client.client.account_uri,
             selected_chain=cert.to_json(),
-            **other
+            **other,
         )
     except ModuleFailException as e:
-        e.do_fail(module)
+        e.do_fail(module=module)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
