@@ -6,9 +6,7 @@
 # GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
 # SPDX-License-Identifier: GPL-3.0-or-later
 
-from __future__ import absolute_import, division, print_function
-__metaclass__ = type
-
+from __future__ import annotations
 
 DOCUMENTATION = r"""
 module: docker_compose_v2
@@ -20,11 +18,11 @@ version_added: 3.6.0
 description:
   - Uses Docker Compose to start or shutdown services.
 extends_documentation_fragment:
-  - community.docker.compose_v2
-  - community.docker.compose_v2.minimum_version
-  - community.docker.docker.cli_documentation
-  - community.docker.attributes
-  - community.docker.attributes.actiongroup_docker
+  - community.docker._compose_v2
+  - community.docker._compose_v2.minimum_version
+  - community.docker._docker.cli_documentation
+  - community.docker._attributes
+  - community.docker._attributes.actiongroup_docker
 
 attributes:
   check_mode:
@@ -438,163 +436,194 @@ actions:
 """
 
 import traceback
+import typing as t
 
 from ansible.module_utils.common.validation import check_type_int
-from ansible.module_utils.common.text.converters import to_native
-from ansible_collections.community.docker.plugins.module_utils._six import string_types
 
-from ansible_collections.community.docker.plugins.module_utils.common_cli import (
+from ansible_collections.community.docker.plugins.module_utils._common_cli import (
     AnsibleModuleDockerClient,
     DockerException,
 )
-
-from ansible_collections.community.docker.plugins.module_utils.compose_v2 import (
+from ansible_collections.community.docker.plugins.module_utils._compose_v2 import (
     BaseComposeManager,
     common_compose_argspec_ex,
     is_failed,
 )
-
-from ansible_collections.community.docker.plugins.module_utils.version import LooseVersion
+from ansible_collections.community.docker.plugins.module_utils._version import (
+    LooseVersion,
+)
 
 
 class ServicesManager(BaseComposeManager):
-    def __init__(self, client):
-        super(ServicesManager, self).__init__(client)
+    def __init__(self, client: AnsibleModuleDockerClient) -> None:
+        super().__init__(client)
         parameters = self.client.module.params
 
-        self.state = parameters['state']
-        self.dependencies = parameters['dependencies']
-        self.pull = parameters['pull']
-        self.build = parameters['build']
-        self.ignore_build_events = parameters['ignore_build_events']
-        self.recreate = parameters['recreate']
-        self.remove_images = parameters['remove_images']
-        self.remove_volumes = parameters['remove_volumes']
-        self.remove_orphans = parameters['remove_orphans']
-        self.renew_anon_volumes = parameters['renew_anon_volumes']
-        self.timeout = parameters['timeout']
-        self.services = parameters['services'] or []
-        self.scale = parameters['scale'] or {}
-        self.wait = parameters['wait']
-        self.wait_timeout = parameters['wait_timeout']
-        self.yes = parameters['assume_yes']
-        if self.compose_version < LooseVersion('2.32.0') and self.yes:
-            self.fail('assume_yes=true needs Docker Compose 2.32.0 or newer, not version %s' % (self.compose_version, ))
+        self.state: t.Literal["absent", "present", "stopped", "restarted"] = parameters[
+            "state"
+        ]
+        self.dependencies: bool = parameters["dependencies"]
+        self.pull: t.Literal["always", "missing", "never", "policy"] = parameters[
+            "pull"
+        ]
+        self.build: t.Literal["always", "never", "policy"] = parameters["build"]
+        self.ignore_build_events: bool = parameters["ignore_build_events"]
+        self.recreate: t.Literal["always", "never", "auto"] = parameters["recreate"]
+        self.remove_images: t.Literal["all", "local"] | None = parameters[
+            "remove_images"
+        ]
+        self.remove_volumes: bool = parameters["remove_volumes"]
+        self.remove_orphans: bool = parameters["remove_orphans"]
+        self.renew_anon_volumes: bool = parameters["renew_anon_volumes"]
+        self.timeout: int | None = parameters["timeout"]
+        self.services: list[str] = parameters["services"] or []
+        self.scale: dict[str, t.Any] = parameters["scale"] or {}
+        self.wait: bool = parameters["wait"]
+        self.wait_timeout: int | None = parameters["wait_timeout"]
+        self.yes: bool = parameters["assume_yes"]
+        if self.compose_version < LooseVersion("2.32.0") and self.yes:
+            self.fail(
+                f"assume_yes=true needs Docker Compose 2.32.0 or newer, not version {self.compose_version}"
+            )
 
         for key, value in self.scale.items():
-            if not isinstance(key, string_types):
-                self.fail('The key %s for `scale` is not a string' % repr(key))
+            if not isinstance(key, str):
+                self.fail(f"The key {key!r} for `scale` is not a string")
             try:
                 value = check_type_int(value)
-            except TypeError as exc:
-                self.fail('The value %s for `scale[%s]` is not an integer' % (repr(value), repr(key)))
+            except TypeError:
+                self.fail(f"The value {value!r} for `scale[{key!r}]` is not an integer")
             if value < 0:
-                self.fail('The value %s for `scale[%s]` is negative' % (repr(value), repr(key)))
+                self.fail(f"The value {value!r} for `scale[{key!r}]` is negative")
             self.scale[key] = value
 
-    def run(self):
-        if self.state == 'present':
+    def run(self) -> dict[str, t.Any]:
+        if self.state == "present":
             result = self.cmd_up()
-        elif self.state == 'stopped':
+        elif self.state == "stopped":
             result = self.cmd_stop()
-        elif self.state == 'restarted':
+        elif self.state == "restarted":
             result = self.cmd_restart()
-        elif self.state == 'absent':
+        elif self.state == "absent":
             result = self.cmd_down()
+        else:
+            raise AssertionError("Unexpected state")
 
-        result['containers'] = self.list_containers()
-        result['images'] = self.list_images()
+        result["containers"] = self.list_containers()
+        result["images"] = self.list_images()
         self.cleanup_result(result)
         return result
 
-    def get_up_cmd(self, dry_run, no_start=False):
-        args = self.get_base_args() + ['up', '--detach', '--no-color', '--quiet-pull']
-        if self.pull != 'policy':
-            args.extend(['--pull', self.pull])
+    def get_up_cmd(self, dry_run: bool, no_start: bool = False) -> list[str]:
+        args = self.get_base_args() + ["up", "--detach", "--no-color", "--quiet-pull"]
+        if self.pull != "policy":
+            args.extend(["--pull", self.pull])
         if self.remove_orphans:
-            args.append('--remove-orphans')
-        if self.recreate == 'always':
-            args.append('--force-recreate')
-        if self.recreate == 'never':
-            args.append('--no-recreate')
+            args.append("--remove-orphans")
+        if self.recreate == "always":
+            args.append("--force-recreate")
+        if self.recreate == "never":
+            args.append("--no-recreate")
         if self.renew_anon_volumes:
-            args.append('--renew-anon-volumes')
+            args.append("--renew-anon-volumes")
         if not self.dependencies:
-            args.append('--no-deps')
+            args.append("--no-deps")
         if self.timeout is not None:
-            args.extend(['--timeout', '%d' % self.timeout])
-        if self.build == 'always':
-            args.append('--build')
-        elif self.build == 'never':
-            args.append('--no-build')
+            args.extend(["--timeout", f"{self.timeout}"])
+        if self.build == "always":
+            args.append("--build")
+        elif self.build == "never":
+            args.append("--no-build")
         for key, value in sorted(self.scale.items()):
-            args.extend(['--scale', '%s=%d' % (key, value)])
+            args.extend(["--scale", f"{key}={value}"])
         if self.wait:
-            args.append('--wait')
+            args.append("--wait")
             if self.wait_timeout is not None:
-                args.extend(['--wait-timeout', str(self.wait_timeout)])
+                args.extend(["--wait-timeout", str(self.wait_timeout)])
         if no_start:
-            args.append('--no-start')
+            args.append("--no-start")
         if dry_run:
-            args.append('--dry-run')
+            args.append("--dry-run")
         if self.yes:
             # Note that for Docker Compose 2.32.x and 2.33.x, the long form is '--y' and not '--yes'.
             # This was fixed in Docker Compose 2.34.0 (https://github.com/docker/compose/releases/tag/v2.34.0).
-            args.append('-y' if self.compose_version < LooseVersion('2.34.0') else '--yes')
-        args.append('--')
+            args.append(
+                "-y" if self.compose_version < LooseVersion("2.34.0") else "--yes"
+            )
+        args.append("--")
         for service in self.services:
             args.append(service)
         return args
 
-    def cmd_up(self):
-        result = dict()
+    def cmd_up(self) -> dict[str, t.Any]:
+        result: dict[str, t.Any] = {}
         args = self.get_up_cmd(self.check_mode)
         rc, stdout, stderr = self.client.call_cli(*args, cwd=self.project_src)
         events = self.parse_events(stderr, dry_run=self.check_mode, nonzero_rc=rc != 0)
         self.emit_warnings(events)
-        self.update_result(result, events, stdout, stderr, ignore_service_pull_events=True, ignore_build_events=self.ignore_build_events)
+        self.update_result(
+            result,
+            events,
+            stdout,
+            stderr,
+            ignore_service_pull_events=True,
+            ignore_build_events=self.ignore_build_events,
+        )
         self.update_failed(result, events, args, stdout, stderr, rc)
         return result
 
-    def get_stop_cmd(self, dry_run):
-        args = self.get_base_args() + ['stop']
+    def get_stop_cmd(self, dry_run: bool) -> list[str]:
+        args = self.get_base_args() + ["stop"]
         if self.timeout is not None:
-            args.extend(['--timeout', '%d' % self.timeout])
+            args.extend(["--timeout", f"{self.timeout}"])
         if dry_run:
-            args.append('--dry-run')
-        args.append('--')
+            args.append("--dry-run")
+        args.append("--")
         for service in self.services:
             args.append(service)
         return args
 
-    def _are_containers_stopped(self):
-        for container in self.list_containers_raw():
-            if container['State'] not in ('created', 'exited', 'stopped', 'killed'):
-                return False
-        return True
+    def _are_containers_stopped(self) -> bool:
+        return all(
+            container["State"] in ("created", "exited", "stopped", "killed")
+            for container in self.list_containers_raw()
+        )
 
-    def cmd_stop(self):
+    def cmd_stop(self) -> dict[str, t.Any]:
         # Since 'docker compose stop' **always** claims it is stopping containers, even if they are already
         # stopped, we have to do this a bit more complicated.
 
-        result = dict()
+        result: dict[str, t.Any] = {}
         # Make sure all containers are created
         args_1 = self.get_up_cmd(self.check_mode, no_start=True)
         rc_1, stdout_1, stderr_1 = self.client.call_cli(*args_1, cwd=self.project_src)
-        events_1 = self.parse_events(stderr_1, dry_run=self.check_mode, nonzero_rc=rc_1 != 0)
+        events_1 = self.parse_events(
+            stderr_1, dry_run=self.check_mode, nonzero_rc=rc_1 != 0
+        )
         self.emit_warnings(events_1)
-        self.update_result(result, events_1, stdout_1, stderr_1, ignore_service_pull_events=True, ignore_build_events=self.ignore_build_events)
+        self.update_result(
+            result,
+            events_1,
+            stdout_1,
+            stderr_1,
+            ignore_service_pull_events=True,
+            ignore_build_events=self.ignore_build_events,
+        )
         is_failed_1 = is_failed(events_1, rc_1)
         if not is_failed_1 and not self._are_containers_stopped():
             # Make sure all containers are stopped
             args_2 = self.get_stop_cmd(self.check_mode)
-            rc_2, stdout_2, stderr_2 = self.client.call_cli(*args_2, cwd=self.project_src)
-            events_2 = self.parse_events(stderr_2, dry_run=self.check_mode, nonzero_rc=rc_2 != 0)
+            rc_2, stdout_2, stderr_2 = self.client.call_cli(
+                *args_2, cwd=self.project_src
+            )
+            events_2 = self.parse_events(
+                stderr_2, dry_run=self.check_mode, nonzero_rc=rc_2 != 0
+            )
             self.emit_warnings(events_2)
             self.update_result(result, events_2, stdout_2, stderr_2)
         else:
             args_2 = []
-            rc_2, stdout_2, stderr_2 = 0, b'', b''
+            rc_2, stdout_2, stderr_2 = 0, b"", b""
             events_2 = []
         # Compose result
         self.update_failed(
@@ -607,21 +636,21 @@ class ServicesManager(BaseComposeManager):
         )
         return result
 
-    def get_restart_cmd(self, dry_run):
-        args = self.get_base_args() + ['restart']
+    def get_restart_cmd(self, dry_run: bool) -> list[str]:
+        args = self.get_base_args() + ["restart"]
         if not self.dependencies:
-            args.append('--no-deps')
+            args.append("--no-deps")
         if self.timeout is not None:
-            args.extend(['--timeout', '%d' % self.timeout])
+            args.extend(["--timeout", f"{self.timeout}"])
         if dry_run:
-            args.append('--dry-run')
-        args.append('--')
+            args.append("--dry-run")
+        args.append("--")
         for service in self.services:
             args.append(service)
         return args
 
-    def cmd_restart(self):
-        result = dict()
+    def cmd_restart(self) -> dict[str, t.Any]:
+        result: dict[str, t.Any] = {}
         args = self.get_restart_cmd(self.check_mode)
         rc, stdout, stderr = self.client.call_cli(*args, cwd=self.project_src)
         events = self.parse_events(stderr, dry_run=self.check_mode, nonzero_rc=rc != 0)
@@ -630,25 +659,25 @@ class ServicesManager(BaseComposeManager):
         self.update_failed(result, events, args, stdout, stderr, rc)
         return result
 
-    def get_down_cmd(self, dry_run):
-        args = self.get_base_args() + ['down']
+    def get_down_cmd(self, dry_run: bool) -> list[str]:
+        args = self.get_base_args() + ["down"]
         if self.remove_orphans:
-            args.append('--remove-orphans')
+            args.append("--remove-orphans")
         if self.remove_images:
-            args.extend(['--rmi', self.remove_images])
+            args.extend(["--rmi", self.remove_images])
         if self.remove_volumes:
-            args.append('--volumes')
+            args.append("--volumes")
         if self.timeout is not None:
-            args.extend(['--timeout', '%d' % self.timeout])
+            args.extend(["--timeout", f"{self.timeout}"])
         if dry_run:
-            args.append('--dry-run')
-        args.append('--')
+            args.append("--dry-run")
+        args.append("--")
         for service in self.services:
             args.append(service)
         return args
 
-    def cmd_down(self):
-        result = dict()
+    def cmd_down(self) -> dict[str, t.Any]:
+        result: dict[str, t.Any] = {}
         args = self.get_down_cmd(self.check_mode)
         rc, stdout, stderr = self.client.call_cli(*args, cwd=self.project_src)
         events = self.parse_events(stderr, dry_run=self.check_mode, nonzero_rc=rc != 0)
@@ -658,33 +687,49 @@ class ServicesManager(BaseComposeManager):
         return result
 
 
-def main():
-    argument_spec = dict(
-        state=dict(type='str', default='present', choices=['absent', 'present', 'stopped', 'restarted']),
-        dependencies=dict(type='bool', default=True),
-        pull=dict(type='str', choices=['always', 'missing', 'never', 'policy'], default='policy'),
-        build=dict(type='str', choices=['always', 'never', 'policy'], default='policy'),
-        recreate=dict(type='str', default='auto', choices=['always', 'never', 'auto']),
-        renew_anon_volumes=dict(type='bool', default=False),
-        remove_images=dict(type='str', choices=['all', 'local']),
-        remove_volumes=dict(type='bool', default=False),
-        remove_orphans=dict(type='bool', default=False),
-        timeout=dict(type='int'),
-        services=dict(type='list', elements='str'),
-        scale=dict(type='dict'),
-        wait=dict(type='bool', default=False),
-        wait_timeout=dict(type='int'),
-        ignore_build_events=dict(type='bool', default=True),
-        assume_yes=dict(type='bool', default=False),
-    )
+def main() -> None:
+    argument_spec = {
+        "state": {
+            "type": "str",
+            "default": "present",
+            "choices": ["absent", "present", "stopped", "restarted"],
+        },
+        "dependencies": {"type": "bool", "default": True},
+        "pull": {
+            "type": "str",
+            "choices": ["always", "missing", "never", "policy"],
+            "default": "policy",
+        },
+        "build": {
+            "type": "str",
+            "choices": ["always", "never", "policy"],
+            "default": "policy",
+        },
+        "recreate": {
+            "type": "str",
+            "default": "auto",
+            "choices": ["always", "never", "auto"],
+        },
+        "renew_anon_volumes": {"type": "bool", "default": False},
+        "remove_images": {"type": "str", "choices": ["all", "local"]},
+        "remove_volumes": {"type": "bool", "default": False},
+        "remove_orphans": {"type": "bool", "default": False},
+        "timeout": {"type": "int"},
+        "services": {"type": "list", "elements": "str"},
+        "scale": {"type": "dict"},
+        "wait": {"type": "bool", "default": False},
+        "wait_timeout": {"type": "int"},
+        "ignore_build_events": {"type": "bool", "default": True},
+        "assume_yes": {"type": "bool", "default": False},
+    }
     argspec_ex = common_compose_argspec_ex()
-    argument_spec.update(argspec_ex.pop('argspec'))
+    argument_spec.update(argspec_ex.pop("argspec"))
 
     client = AnsibleModuleDockerClient(
         argument_spec=argument_spec,
         supports_check_mode=True,
         needs_api_version=False,
-        **argspec_ex
+        **argspec_ex,
     )
 
     try:
@@ -693,8 +738,11 @@ def main():
         manager.cleanup()
         client.module.exit_json(**result)
     except DockerException as e:
-        client.fail('An unexpected docker error occurred: {0}'.format(to_native(e)), exception=traceback.format_exc())
+        client.fail(
+            f"An unexpected Docker error occurred: {e}",
+            exception=traceback.format_exc(),
+        )
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
