@@ -118,7 +118,7 @@ _raw:
   elements: list
 """
 
-from subprocess import Popen, PIPE
+from subprocess import PIPE, Popen
 
 from ansible.errors import AnsibleError, AnsibleOptionsError
 from ansible.module_utils.common.text.converters import to_bytes, to_text
