@@ -151,6 +151,17 @@ options:
     type: list
     elements: str
 
+  valid_post_logout_redirect_uris:
+    description:
+      - Valid post logout redirect URIs for this client.
+      - This is stored as C(post.logout.redirect.uris) in the client attributes.
+      - Use V(+) as a single list element to allow all redirect URIs.
+    aliases:
+      - postLogoutRedirectUris
+    type: list
+    elements: str
+    version_added: "12.4.0"
+
   not_before:
     description:
       - Revoke any tokens issued before this date for this client (this is a UNIX timestamp). This is C(notBefore) in the
@@ -227,6 +238,15 @@ options:
       - frontchannelLogout
     type: bool
 
+  backchannel_logout_url:
+    description:
+      - URL that will cause the client to log itself out when a logout request is sent to this realm.
+      - This is stored as C(backchannel.logout.url) in the client attributes.
+    aliases:
+      - backchannelLogoutUrl
+    type: str
+    version_added: "12.4.0"
+
   protocol:
     description:
       - Type of client.
@@ -748,6 +768,9 @@ import copy
 
 from ansible.module_utils.basic import AnsibleModule
 
+from ansible_collections.community.general.plugins.module_utils.identity.keycloak._keycloak_utils import (
+    merge_settings_without_absent_nulls,
+)
 from ansible_collections.community.general.plugins.module_utils.identity.keycloak.keycloak import (
     KeycloakAPI,
     KeycloakError,
@@ -761,6 +784,21 @@ PROTOCOL_SAML = "saml"
 PROTOCOL_DOCKER_V2 = "docker-v2"
 CLIENT_META_DATA = ["authorizationServicesEnabled"]
 
+# Parameters that map to client attributes rather than top-level API fields.
+# Each entry maps the module parameter name to (attribute_key, transform_fn).
+# transform_fn converts the module param value to the attribute string value.
+# Use None for transform_fn when no transformation is needed (identity).
+ATTRIBUTE_PARAMS = {
+    "valid_post_logout_redirect_uris": (
+        "post.logout.redirect.uris",
+        "##".join,
+    ),
+    "backchannel_logout_url": (
+        "backchannel.logout.url",
+        None,
+    ),
+}
+
 
 def normalise_scopes_for_behavior(desired_client, before_client, clientScopesBehavior):
     """
@@ -1219,6 +1257,7 @@ def main():
         default_roles=dict(type="list", elements="str", aliases=["defaultRoles"]),
         redirect_uris=dict(type="list", elements="str", aliases=["redirectUris"]),
         web_origins=dict(type="list", elements="str", aliases=["webOrigins"]),
+        valid_post_logout_redirect_uris=dict(type="list", elements="str", aliases=["postLogoutRedirectUris"]),
         not_before=dict(type="int", aliases=["notBefore"]),
         bearer_only=dict(type="bool", aliases=["bearerOnly"]),
         consent_required=dict(type="bool", aliases=["consentRequired"]),
@@ -1229,6 +1268,7 @@ def main():
         authorization_services_enabled=dict(type="bool", aliases=["authorizationServicesEnabled"]),
         public_client=dict(type="bool", aliases=["publicClient"]),
         frontchannel_logout=dict(type="bool", aliases=["frontchannelLogout"]),
+        backchannel_logout_url=dict(type="str", aliases=["backchannelLogoutUrl"]),
         protocol=dict(type="str", choices=[PROTOCOL_OPENID_CONNECT, PROTOCOL_SAML, PROTOCOL_DOCKER_V2]),
         attributes=dict(type="dict"),
         full_scope_allowed=dict(type="bool", aliases=["fullScopeAllowed"]),
@@ -1308,28 +1348,48 @@ def main():
     # Build a proposed changeset from parameters given to this module
     changeset = {}
 
+    # Collect attribute-mapped parameters to inject into attributes later
+    attribute_overrides = {}
+    for param_name, (attr_key, transform_fn) in ATTRIBUTE_PARAMS.items():
+        param_value = module.params.get(param_name)
+        if param_value is not None:
+            attribute_overrides[attr_key] = transform_fn(param_value) if transform_fn else param_value
+
     for client_param in client_params:
         new_param_value = module.params.get(client_param)
 
+        # Skip attribute-mapped params; they are handled via attributes
+        if client_param in ATTRIBUTE_PARAMS:
+            continue
+
         # Unfortunately, the ansible argument spec checker introduces variables with null values when
         # they are not specified
         if client_param == "protocol_mappers":
             new_param_value = [{k: v for k, v in x.items() if v is not None} for x in new_param_value]
         elif client_param == "authentication_flow_binding_overrides":
-            new_param_value = flow_binding_from_dict_to_model(new_param_value, realm, kc)
-        elif client_param == "attributes" and "attributes" in before_client:
-            attributes_copy = copy.deepcopy(before_client["attributes"])
-            # Merge client attributes while excluding null-valued attributes that are not present in Keycloak's response.
-            # This ensures idempotency by treating absent attributes and null attributes as equivalent.
-            attributes_copy.update(
-                {key: value for key, value in new_param_value.items() if value is not None or key in attributes_copy}
+            desired_flow_binding_overrides = flow_binding_from_dict_to_model(new_param_value, realm, kc)
+            existing_flow_binding_overrides = before_client.get("authenticationFlowBindingOverrides")
+            # ensures idempotency
+            new_param_value = merge_settings_without_absent_nulls(
+                existing_flow_binding_overrides, desired_flow_binding_overrides
             )
-            new_param_value = attributes_copy
+        elif client_param == "attributes" and "attributes" in before_client:
+            desired_attributes = new_param_value
+            existing_attributes = copy.deepcopy(before_client["attributes"])
+            # ensures idempotency
+            new_param_value = merge_settings_without_absent_nulls(existing_attributes, desired_attributes)
         elif client_param in ["clientScopesBehavior", "client_scopes_behavior"]:
             continue
 
         changeset[camel(client_param)] = new_param_value
 
+    # Inject attribute-mapped parameters into the attributes dict
+    if attribute_overrides:
+        if "attributes" not in changeset:
+            changeset["attributes"] = copy.deepcopy(before_client.get("attributes", {}))
+        if isinstance(changeset["attributes"], dict):
+            changeset["attributes"].update(attribute_overrides)
+
     # Prepare the desired values using the existing values (non-existence results in a dict that is save to use as a basis)
     desired_client = copy.deepcopy(before_client)
     desired_client.update(changeset)
@@ -1393,7 +1453,7 @@ def main():
             if module.check_mode:
                 result["end_state"] = sanitize_cr(desired_client_with_scopes)
                 if module._diff:
-                    result["diff"] = dict(before=sanitize_cr(before_client), after=sanitize_cr(desired_client))
+                    result["diff"] = dict(before=sanitize_cr(before_norm), after=sanitize_cr(desired_norm))
                 module.exit_json(**result)
 
             # do the update
