@@ -465,17 +465,25 @@ class MavenDownloader:
             content = self._getContent(self.base + path, f"Failed to retrieve the maven metadata file: {path}")
             xml = etree.fromstring(content)
 
-            for snapshotArtifact in xml.xpath("/metadata/versioning/snapshotVersions/snapshotVersion"):
-                classifier = snapshotArtifact.xpath("classifier/text()")
-                artifact_classifier = classifier[0] if classifier else ""
-                extension = snapshotArtifact.xpath("extension/text()")
-                artifact_extension = extension[0] if extension else ""
-                if artifact_classifier == artifact.classifier and artifact_extension == artifact.extension:
-                    return self._uri_for_artifact(artifact, snapshotArtifact.xpath("value/text()")[0])
+            candidates = []
+            for snapshot_artifact in xml.xpath("/metadata/versioning/snapshotVersions/snapshotVersion"):
+                classifier = snapshot_artifact.xpath("classifier/text()")
+                extension = snapshot_artifact.xpath("extension/text()")
+                if (classifier[0] if classifier else "") == artifact.classifier and (
+                    extension[0] if extension else ""
+                ) == artifact.extension:
+                    value = snapshot_artifact.xpath("value/text()")
+                    updated = snapshot_artifact.xpath("updated/text()")
+                    if value:
+                        candidates.append((updated[0] if updated else "", value[0]))
+            if candidates:
+                # updated is yyyymmddHHMMSS, so lexical max == newest
+                return self._uri_for_artifact(artifact, max(candidates, key=lambda item: item[0])[1])
             timestamp_xmlpath = xml.xpath("/metadata/versioning/snapshot/timestamp/text()")
-            if timestamp_xmlpath:
+            build_number_xmlpath = xml.xpath("/metadata/versioning/snapshot/buildNumber/text()")
+            if timestamp_xmlpath and build_number_xmlpath:
                 timestamp = timestamp_xmlpath[0]
-                build_number = xml.xpath("/metadata/versioning/snapshot/buildNumber/text()")[0]
+                build_number = build_number_xmlpath[0]
                 return self._uri_for_artifact(
                     artifact, artifact.version.replace("SNAPSHOT", f"{timestamp}-{build_number}")
                 )
