@@ -23,7 +23,7 @@ attributes:
   check_mode:
     support: partial
     details:
-      - Note that check mode always returns C(changed=true) for existing templates, even if the template would not actually
+      - Note that check mode always returns RV(ignore:changed=true) for existing templates, even if the template would not actually
         change.
   diff_mode:
     support: none
@@ -226,10 +226,10 @@ class TemplateModule(OpenNebulaModule):
         return None
 
     def get_template_by_id(self, template_id, filter):
-        return self.get_template(lambda template: (template_id == template.ID), filter)
+        return self.get_template(lambda template: template_id == template.ID, filter)
 
     def get_template_by_name(self, name, filter):
-        return self.get_template(lambda template: (name == template.NAME), filter)
+        return self.get_template(lambda template: name == template.NAME, filter)
 
     def get_template_instance(self, requested_id, requested_name, filter):
         if requested_id:
