@@ -11,7 +11,6 @@
 
 from __future__ import annotations
 
-
 DOCUMENTATION = r"""
 module: pubnub_blocks
 short_description: PubNub blocks management module
@@ -208,9 +207,7 @@ import os
 
 try:
     # Import PubNub BLOCKS client.
-    from pubnub_blocks_client import User
-    from pubnub_blocks_client import Block, EventHandler
-    from pubnub_blocks_client import exceptions
+    from pubnub_blocks_client import Block, EventHandler, User, exceptions
 
     HAS_PUBNUB_BLOCKS_CLIENT = True
 except ImportError:
@@ -512,7 +509,7 @@ def _content_of_file_at_path(path):
     """
     content = None
     if path and os.path.exists(path):
-        with open(path, mode="rt") as opened_file:
+        with open(path) as opened_file:
             b_content = opened_file.read()
             try:
                 content = to_text(b_content, errors="surrogate_or_strict")
