@@ -1,5 +1,4 @@
 #!/usr/bin/python
-# -*- coding: utf-8 -*-
 #
 # Scaleway IP management module
 #
@@ -7,9 +6,7 @@
 # GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
 # SPDX-License-Identifier: GPL-3.0-or-later
 
-from __future__ import absolute_import, division, print_function
-
-__metaclass__ = type
+from __future__ import annotations
 
 DOCUMENTATION = r"""
 module: scaleway_ip
@@ -44,7 +41,14 @@ options:
     type: str
     description:
       - Scaleway organization identifier.
-    required: true
+      - Exactly one of O(project) and O(organization) must be specified.
+
+  project:
+    type: str
+    description:
+      - Project identifier.
+      - Exactly one of O(project) and O(organization) must be specified.
+    version_added: 12.3.0
 
   region:
     type: str
@@ -82,9 +86,9 @@ options:
 """
 
 EXAMPLES = r"""
-- name: Create an IP
+- name: Create an IP with a project ID
   community.general.scaleway_ip:
-    organization: '{{ scw_org }}'
+    project: '{{ project_id }}'
     state: present
     region: par1
   register: ip_creation_task
@@ -94,6 +98,13 @@ EXAMPLES = r"""
     id: '{{ ip_creation_task.scaleway_ip.id }}'
     state: absent
     region: par1
+
+- name: Create an IP in the default project with an organization ID (deprecated)
+  community.general.scaleway_ip:
+    organization: '{{ scw_org }}'
+    state: present
+    region: par1
+  register: ip_creation_task
 """
 
 RETURN = r"""
@@ -118,9 +129,14 @@ data:
     }
 """
 
-from ansible_collections.community.general.plugins.module_utils.scaleway import SCALEWAY_LOCATION, scaleway_argument_spec, Scaleway
 from ansible.module_utils.basic import AnsibleModule
 
+from ansible_collections.community.general.plugins.module_utils.scaleway import (
+    SCALEWAY_LOCATION,
+    Scaleway,
+    scaleway_argument_spec,
+)
+
 
 def ip_attributes_should_be_changed(api, target_ip, wished_ip):
     patch_payload = {}
@@ -150,20 +166,15 @@ def ip_attributes_should_be_changed(api, target_ip, wished_ip):
 
 
 def payload_from_wished_ip(wished_ip):
-    return {
-        k: v
-        for k, v in wished_ip.items()
-        if k != 'id' and v is not None
-    }
+    return {k: v for k, v in wished_ip.items() if k != "id" and v is not None}
 
 
 def present_strategy(api, wished_ip):
     changed = False
 
-    response = api.get('ips')
+    response = api.get("ips")
     if not response.ok:
-        api.module.fail_json(msg='Error getting IPs [{0}: {1}]'.format(
-            response.status_code, response.json['message']))
+        api.module.fail_json(msg=f"Error getting IPs [{response.status_code}: {response.json['message']}]")
 
     ips_list = response.json["ips"]
     ip_lookup = {ip["id"]: ip for ip in ips_list}
@@ -174,13 +185,10 @@ def present_strategy(api, wished_ip):
             return changed, {"status": "An IP would be created."}
 
         # Create IP
-        creation_response = api.post('/ips',
-                                     data=payload_from_wished_ip(wished_ip))
+        creation_response = api.post("/ips", data=payload_from_wished_ip(wished_ip))
 
         if not creation_response.ok:
-            msg = "Error during ip creation: %s: '%s' (%s)" % (creation_response.info['msg'],
-                                                               creation_response.json['message'],
-                                                               creation_response.json)
+            msg = f"Error during ip creation: {creation_response.info['msg']}: '{creation_response.json['message']}' ({creation_response.json})"
             api.module.fail_json(msg=msg)
         return changed, creation_response.json["ip"]
 
@@ -194,18 +202,18 @@ def present_strategy(api, wished_ip):
     if api.module.check_mode:
         return changed, {"status": "IP attributes would be changed."}
 
-    ip_patch_response = api.patch(path="ips/%s" % target_ip["id"],
-                                  data=patch_payload)
+    ip_patch_response = api.patch(path=f"ips/{target_ip['id']}", data=patch_payload)
 
     if not ip_patch_response.ok:
-        api.module.fail_json(msg='Error during IP attributes update: [{0}: {1}]'.format(
-            ip_patch_response.status_code, ip_patch_response.json['message']))
+        api.module.fail_json(
+            msg=f"Error during IP attributes update: [{ip_patch_response.status_code}: {ip_patch_response.json['message']}]"
+        )
 
     return changed, ip_patch_response.json["ip"]
 
 
 def absent_strategy(api, wished_ip):
-    response = api.get('ips')
+    response = api.get("ips")
     changed = False
 
     status_code = response.status_code
@@ -213,8 +221,7 @@ def absent_strategy(api, wished_ip):
     ips_list = ips_json["ips"]
 
     if not response.ok:
-        api.module.fail_json(msg='Error getting IPs [{0}: {1}]'.format(
-            status_code, response.json['message']))
+        api.module.fail_json(msg=f"Error getting IPs [{status_code}: {response.json['message']}]")
 
     ip_lookup = {ip["id"]: ip for ip in ips_list}
     if wished_ip["id"] not in ip_lookup.keys():
@@ -224,24 +231,24 @@ def absent_strategy(api, wished_ip):
     if api.module.check_mode:
         return changed, {"status": "IP would be destroyed"}
 
-    response = api.delete('/ips/' + wished_ip["id"])
+    response = api.delete(f"/ips/{wished_ip['id']}")
     if not response.ok:
-        api.module.fail_json(msg='Error deleting IP [{0}: {1}]'.format(
-            response.status_code, response.json))
+        api.module.fail_json(msg=f"Error deleting IP [{response.status_code}: {response.json}]")
 
     return changed, response.json
 
 
 def core(module):
     wished_ip = {
-        "organization": module.params['organization'],
+        "organization": module.params["organization"],
+        "project": module.params["project"],
         "reverse": module.params["reverse"],
         "id": module.params["id"],
-        "server": module.params["server"]
+        "server": module.params["server"],
     }
 
     region = module.params["region"]
-    module.params['api_url'] = SCALEWAY_LOCATION[region]["api_endpoint"]
+    module.params["api_url"] = SCALEWAY_LOCATION[region]["api_endpoint"]
 
     api = Scaleway(module=module)
     if module.params["state"] == "absent":
@@ -253,21 +260,30 @@ def core(module):
 
 def main():
     argument_spec = scaleway_argument_spec()
-    argument_spec.update(dict(
-        state=dict(default='present', choices=['absent', 'present']),
-        organization=dict(required=True),
-        server=dict(),
-        reverse=dict(),
-        region=dict(required=True, choices=list(SCALEWAY_LOCATION.keys())),
-        id=dict()
-    ))
+    argument_spec.update(
+        dict(
+            state=dict(default="present", choices=["absent", "present"]),
+            organization=dict(),
+            project=dict(),
+            server=dict(),
+            reverse=dict(),
+            region=dict(required=True, choices=list(SCALEWAY_LOCATION.keys())),
+            id=dict(),
+        )
+    )
     module = AnsibleModule(
         argument_spec=argument_spec,
         supports_check_mode=True,
+        mutually_exclusive=[
+            ("organization", "project"),
+        ],
+        required_one_of=[
+            ("organization", "project"),
+        ],
     )
 
     core(module)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
