@@ -3,7 +3,10 @@ import json  # noqa: F402
 import os  # noqa: F402
 import shlex  # noqa: F402
 
-from ansible.module_utils._text import to_bytes, to_native  # noqa: F402
+try:
+    from ansible.module_utils.common.text.converters import to_native, to_bytes  # noqa: F402
+except ImportError:
+    from ansible.module_utils.common.text import to_native, to_bytes  # noqa: F402
 from ansible_collections.containers.podman.plugins.module_utils.podman.common import (
     LooseVersion,
 )
@@ -1171,7 +1174,7 @@ class PodmanContainerDiff:
     # was configured; otherwise the config key isn't part of the config.
     def diffparam_healthcheck(self):
         before = ""
-        if "healthcheck" in self.info["config"]:
+        if "healthcheck" in self.info["config"] and self.info["config"]["healthcheck"]:
             # the "test" key is a list of 2 items where the first one is
             # "CMD-SHELL" and the second one is the actual healthcheck command.
             if len(self.info["config"]["healthcheck"]["test"]) > 1:
