@@ -1,7 +1,10 @@
 from __future__ import absolute_import, division, print_function
 import json  # noqa: F402
 
-from ansible.module_utils._text import to_bytes, to_native
+try:
+    from ansible.module_utils.common.text.converters import to_native, to_bytes  # noqa: F402
+except ImportError:
+    from ansible.module_utils.common.text import to_native, to_bytes  # noqa: F402
 from ansible_collections.containers.podman.plugins.module_utils.podman.common import (
     LooseVersion,
 )
