@@ -16,7 +16,6 @@ short_description: Configure DNS domain filters.
 description:
     - This module is able to configure a FortiManager device.
     - Examples include all parameters and values which need to be adjusted to data sources before usage.
-
 version_added: "2.0.0"
 author:
     - Xinwei Du (@dux-fortinet)
@@ -73,6 +72,9 @@ options:
         choices:
           - present
           - absent
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -123,6 +125,9 @@ options:
                             - 'simple'
                             - 'regex'
                             - 'wildcard'
+                    comment:
+                        type: str
+                        description: Comment.
             id:
                 type: int
                 description: ID.
@@ -135,6 +140,7 @@ options:
 EXAMPLES = '''
 - name: Example playbook
   hosts: fortimanagers
+  gather_facts: false
   connection: httpapi
   vars:
     ansible_httpapi_use_ssl: true
@@ -171,7 +177,7 @@ EXAMPLES = '''
           selector: "dnsfilter_domainfilter"
           params:
             adom: "ansible"
-            domain-filter: "your_value"
+            domain_filter: "your_value"
 '''
 
 RETURN = '''
@@ -215,27 +221,20 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/obj/dnsfilter/domain-filter',
         '/pm/config/global/obj/dnsfilter/domain-filter'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/obj/dnsfilter/domain-filter/{domain-filter}',
-        '/pm/config/global/obj/dnsfilter/domain-filter/{domain-filter}'
-    ]
-
     url_params = ['adom']
     module_primary_key = 'id'
     module_arg_spec = {
         'adom': {'required': True, 'type': 'str'},
+        'revision_note': {'type': 'str'},
         'dnsfilter_domainfilter': {
             'type': 'dict',
             'v_range': [['6.0.0', '']],
@@ -248,14 +247,14 @@ def main():
                         'domain': {'type': 'str'},
                         'id': {'type': 'int'},
                         'status': {'choices': ['disable', 'enable'], 'type': 'str'},
-                        'type': {'choices': ['simple', 'regex', 'wildcard'], 'type': 'str'}
+                        'type': {'choices': ['simple', 'regex', 'wildcard'], 'type': 'str'},
+                        'comment': {'v_range': [['7.6.4', '']], 'type': 'str'}
                     },
                     'elements': 'dict'
                 },
                 'id': {'required': True, 'type': 'int'},
                 'name': {'type': 'str'}
             }
-
         }
     }
 
@@ -264,14 +263,15 @@ def main():
     params_validation_blob = []
     check_galaxy_version(module_arg_spec)
     module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'dnsfilter_domainfilter'),
-                           supports_check_mode=False)
+                           supports_check_mode=True)
 
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_crud()
 
     module.exit_json(meta=module.params)
 
