@@ -16,7 +16,6 @@ short_description: Configure IPv4 interface policies.
 description:
     - This module is able to configure a FortiManager device.
     - Examples include all parameters and values which need to be adjusted to data sources before usage.
-
 version_added: "2.0.0"
 author:
     - Xinwei Du (@dux-fortinet)
@@ -73,6 +72,9 @@ options:
         choices:
           - present
           - absent
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -93,39 +95,46 @@ options:
         required: false
         type: dict
         suboptions:
-            address-type:
+            address_type:
+                aliases: ['address-type']
                 type: str
-                description: Deprecated, please rename it to address_type. Address type.
+                description: Address type.
                 choices:
                     - 'ipv4'
                     - 'ipv6'
-            application-list:
+            application_list:
+                aliases: ['application-list']
                 type: str
-                description: Deprecated, please rename it to application_list. Application list name.
-            application-list-status:
+                description: Application list name.
+            application_list_status:
+                aliases: ['application-list-status']
                 type: str
-                description: Deprecated, please rename it to application_list_status. Enable/disable application control.
+                description: Enable/disable application control.
                 choices:
                     - 'disable'
                     - 'enable'
-            av-profile:
+            av_profile:
+                aliases: ['av-profile']
                 type: str
-                description: Deprecated, please rename it to av_profile. Antivirus profile.
-            av-profile-status:
+                description: Antivirus profile.
+            av_profile_status:
+                aliases: ['av-profile-status']
                 type: str
-                description: Deprecated, please rename it to av_profile_status. Enable/disable antivirus.
+                description: Enable/disable antivirus.
                 choices:
                     - 'disable'
                     - 'enable'
             comments:
                 type: str
                 description: Comments.
-            dlp-sensor:
+            dlp_sensor:
+                aliases: ['dlp-sensor']
                 type: str
-                description: Deprecated, please rename it to dlp_sensor. DLP sensor name.
-            dlp-sensor-status:
+                description: DLP sensor name.
+            dlp_sensor_status:
+                aliases: ['dlp-sensor-status']
                 type: str
-                description: Deprecated, please rename it to dlp_sensor_status. Enable/disable DLP.
+                description: Enable/disable DLP.
                 choices:
                     - 'disable'
                     - 'enable'
@@ -141,12 +150,14 @@ options:
             interface:
                 type: str
                 description: Monitored interface name from available interfaces.
-            ips-sensor:
+            ips_sensor:
+                aliases: ['ips-sensor']
                 type: str
-                description: Deprecated, please rename it to ips_sensor. IPS sensor name.
-            ips-sensor-status:
+                description: IPS sensor name.
+            ips_sensor_status:
+                aliases: ['ips-sensor-status']
                 type: str
-                description: Deprecated, please rename it to ips_sensor_status. Enable/disable IPS.
+                description: Enable/disable IPS.
                 choices:
                     - 'disable'
                     - 'enable'
@@ -164,9 +175,10 @@ options:
                 type: int
                 description: Policy ID.
                 required: true
-            scan-botnet-connections:
+            scan_botnet_connections:
+                aliases: ['scan-botnet-connections']
                 type: str
-                description: Deprecated, please rename it to scan_botnet_connections. Enable/disable scanning for connections to Botnet servers.
+                description: Enable/disable scanning for connections to Botnet servers.
                 choices:
                     - 'disable'
                     - 'block'
@@ -174,12 +186,14 @@ options:
             service:
                 type: raw
                 description: (list or str) Service object from available options.
-            spamfilter-profile:
+            spamfilter_profile:
+                aliases: ['spamfilter-profile']
                 type: str
-                description: Deprecated, please rename it to spamfilter_profile. Antispam profile.
-            spamfilter-profile-status:
+                description: Antispam profile.
+            spamfilter_profile_status:
+                aliases: ['spamfilter-profile-status']
                 type: str
-                description: Deprecated, please rename it to spamfilter_profile_status. Enable/disable antispam.
+                description: Enable/disable antispam.
                 choices:
                     - 'disable'
                     - 'enable'
@@ -192,51 +206,61 @@ options:
                 choices:
                     - 'disable'
                     - 'enable'
-            webfilter-profile:
+            webfilter_profile:
+                aliases: ['webfilter-profile']
                 type: str
-                description: Deprecated, please rename it to webfilter_profile. Web filter profile.
-            webfilter-profile-status:
+                description: Web filter profile.
+            webfilter_profile_status:
+                aliases: ['webfilter-profile-status']
                 type: str
-                description: Deprecated, please rename it to webfilter_profile_status. Enable/disable web filtering.
+                description: Enable/disable web filtering.
                 choices:
                     - 'disable'
                     - 'enable'
-            emailfilter-profile:
+            emailfilter_profile:
+                aliases: ['emailfilter-profile']
                 type: str
-                description: Deprecated, please rename it to emailfilter_profile. Email filter profile.
-            emailfilter-profile-status:
+                description: Email filter profile.
+            emailfilter_profile_status:
+                aliases: ['emailfilter-profile-status']
                 type: str
-                description: Deprecated, please rename it to emailfilter_profile_status. Enable/disable email filter.
+                description: Enable/disable email filter.
                 choices:
                     - 'disable'
                     - 'enable'
             uuid:
                 type: str
                 description: Universally Unique Identifier
-            casi-profile:
+            casi_profile:
+                aliases: ['casi-profile']
                 type: str
-                description: Deprecated, please rename it to casi_profile. CASI profile name.
-            casi-profile-status:
+                description: CASI profile name.
+            casi_profile_status:
+                aliases: ['casi-profile-status']
                 type: str
-                description: Deprecated, please rename it to casi_profile_status. Enable/disable CASI.
+                description: Enable/disable CASI.
                 choices:
                     - 'disable'
                     - 'enable'
-            dlp-profile:
+            dlp_profile:
+                aliases: ['dlp-profile']
                 type: str
-                description: Deprecated, please rename it to dlp_profile. DLP profile name.
-            dlp-profile-status:
+                description: DLP profile name.
+            dlp_profile_status:
+                aliases: ['dlp-profile-status']
                 type: str
-                description: Deprecated, please rename it to dlp_profile_status. Enable/disable DLP.
+                description: Enable/disable DLP.
                 choices:
                     - 'disable'
                     - 'enable'
-            casb-profile:
+            casb_profile:
+                aliases: ['casb-profile']
                 type: raw
-                description: (list) Deprecated, please rename it to casb_profile. CASB profile.
-            casb-profile-status:
+                description: (list) CASB profile.
+            casb_profile_status:
+                aliases: ['casb-profile-status']
                 type: str
-                description: Deprecated, please rename it to casb_profile_status. Enable/disable CASB.
+                description: Enable/disable CASB.
                 choices:
                     - 'disable'
                     - 'enable'
@@ -245,6 +269,7 @@ options:
 EXAMPLES = '''
 - name: Example playbook
   hosts: fortimanagers
+  gather_facts: false
   connection: httpapi
   vars:
     ansible_httpapi_use_ssl: true
@@ -258,7 +283,7 @@ EXAMPLES = '''
         pkg: ansible # package name
         state: present
         pkg_firewall_interfacepolicy:
-          address-type: ipv4 # <value in [ipv4, ipv6]>
+          address_type: ipv4 # <value in [ipv4, ipv6]>
           comments: "ansible-comment"
           interface: sslvpn_tun_intf
           policyid: 1
@@ -280,7 +305,7 @@ EXAMPLES = '''
           params:
             adom: "ansible"
             pkg: "ansible" # package name
-            interface-policy: "your_value"
+            interface_policy: "your_value"
 '''
 
 RETURN = '''
@@ -324,65 +349,86 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/pkg/{pkg}/firewall/interface-policy'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/pkg/{pkg}/firewall/interface-policy/{interface-policy}'
-    ]
-
     url_params = ['adom', 'pkg']
     module_primary_key = 'policyid'
     module_arg_spec = {
         'adom': {'required': True, 'type': 'str'},
         'pkg': {'required': True, 'type': 'str'},
+        'revision_note': {'type': 'str'},
         'pkg_firewall_interfacepolicy': {
             'type': 'dict',
-            'v_range': [['6.0.0', '7.2.2'], ['7.4.3', '']],
+            'v_range': [['6.0.0', '7.2.2'], ['7.2.6', '7.2.11'], ['7.4.3', '']],
             'options': {
-                'address-type': {'v_range': [['6.0.0', '7.2.2'], ['7.4.3', '']], 'choices': ['ipv4', 'ipv6'], 'type': 'str'},
-                'application-list': {'v_range': [['6.0.0', '7.2.2'], ['7.4.3', '']], 'type': 'str'},
-                'application-list-status': {'v_range': [['6.0.0', '7.2.2'], ['7.4.3', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                'av-profile': {'v_range': [['6.0.0', '7.2.2'], ['7.4.3', '']], 'type': 'str'},
-                'av-profile-status': {'v_range': [['6.0.0', '7.2.2'], ['7.4.3', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                'comments': {'v_range': [['6.0.0', '7.2.2'], ['7.4.3', '']], 'type': 'str'},
-                'dlp-sensor': {'v_range': [['6.0.0', '7.2.2'], ['7.4.3', '']], 'type': 'str'},
-                'dlp-sensor-status': {'v_range': [['6.0.0', '7.2.2'], ['7.4.3', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                'dsri': {'v_range': [['6.0.0', '7.2.2'], ['7.4.3', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                'dstaddr': {'v_range': [['6.0.0', '7.2.2'], ['7.4.3', '']], 'type': 'raw'},
-                'interface': {'v_range': [['6.0.0', '7.2.2'], ['7.4.3', '']], 'type': 'str'},
-                'ips-sensor': {'v_range': [['6.0.0', '7.2.2'], ['7.4.3', '']], 'type': 'str'},
-                'ips-sensor-status': {'v_range': [['6.0.0', '7.2.2'], ['7.4.3', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                'label': {'v_range': [['6.0.0', '7.2.2'], ['7.4.3', '']], 'type': 'str'},
-                'logtraffic': {'v_range': [['6.0.0', '7.2.2'], ['7.4.3', '']], 'choices': ['disable', 'all', 'utm'], 'type': 'str'},
-                'policyid': {'v_range': [['6.0.0', '7.2.2'], ['7.4.3', '']], 'required': True, 'type': 'int'},
+                'address-type': {'v_range': [['6.0.0', '7.2.2'], ['7.2.6', '7.2.11'], ['7.4.3', '']], 'choices': ['ipv4', 'ipv6'], 'type': 'str'},
+                'application-list': {'v_range': [['6.0.0', '7.2.2'], ['7.2.6', '7.2.11'], ['7.4.3', '']], 'type': 'str'},
+                'application-list-status': {
+                    'v_range': [['6.0.0', '7.2.2'], ['7.2.6', '7.2.11'], ['7.4.3', '']],
+                    'choices': ['disable', 'enable'],
+                    'type': 'str'
+                },
+                'av-profile': {'v_range': [['6.0.0', '7.2.2'], ['7.2.6', '7.2.11'], ['7.4.3', '']], 'type': 'str'},
+                'av-profile-status': {
+                    'v_range': [['6.0.0', '7.2.2'], ['7.2.6', '7.2.11'], ['7.4.3', '']],
+                    'choices': ['disable', 'enable'],
+                    'type': 'str'
+                },
+                'comments': {'v_range': [['6.0.0', '7.2.2'], ['7.2.6', '7.2.11'], ['7.4.3', '']], 'type': 'str'},
+                'dlp-sensor': {'v_range': [['6.0.0', '7.2.2'], ['7.2.6', '7.2.11'], ['7.4.3', '']], 'type': 'str'},
+                'dlp-sensor-status': {
+                    'v_range': [['6.0.0', '7.2.2'], ['7.2.6', '7.2.11'], ['7.4.3', '']],
+                    'choices': ['disable', 'enable'],
+                    'type': 'str'
+                },
+                'dsri': {'v_range': [['6.0.0', '7.2.2'], ['7.2.6', '7.2.11'], ['7.4.3', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'dstaddr': {'v_range': [['6.0.0', '7.2.2'], ['7.2.6', '7.2.11'], ['7.4.3', '']], 'type': 'raw'},
+                'interface': {'v_range': [['6.0.0', '7.2.2'], ['7.2.6', '7.2.11'], ['7.4.3', '']], 'type': 'str'},
+                'ips-sensor': {'v_range': [['6.0.0', '7.2.2'], ['7.2.6', '7.2.11'], ['7.4.3', '']], 'type': 'str'},
+                'ips-sensor-status': {
+                    'v_range': [['6.0.0', '7.2.2'], ['7.2.6', '7.2.11'], ['7.4.3', '']],
+                    'choices': ['disable', 'enable'],
+                    'type': 'str'
+                },
+                'label': {'v_range': [['6.0.0', '7.2.2'], ['7.2.6', '7.2.11'], ['7.4.3', '']], 'type': 'str'},
+                'logtraffic': {'v_range': [['6.0.0', '7.2.2'], ['7.2.6', '7.2.11'], ['7.4.3', '']], 'choices': ['disable', 'all', 'utm'], 'type': 'str'},
+                'policyid': {'v_range': [['6.0.0', '7.2.2'], ['7.2.6', '7.2.11'], ['7.4.3', '']], 'required': True, 'type': 'int'},
                 'scan-botnet-connections': {'v_range': [['6.0.0', '7.2.1']], 'choices': ['disable', 'block', 'monitor'], 'type': 'str'},
-                'service': {'v_range': [['6.0.0', '7.2.2'], ['7.4.3', '']], 'type': 'raw'},
+                'service': {'v_range': [['6.0.0', '7.2.2'], ['7.2.6', '7.2.11'], ['7.4.3', '']], 'type': 'raw'},
                 'spamfilter-profile': {'v_range': [['6.0.0', '7.2.1']], 'type': 'str'},
                 'spamfilter-profile-status': {'v_range': [['6.0.0', '7.2.1']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                'srcaddr': {'v_range': [['6.0.0', '7.2.2'], ['7.4.3', '']], 'type': 'raw'},
-                'status': {'v_range': [['6.0.0', '7.2.2'], ['7.4.3', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                'webfilter-profile': {'v_range': [['6.0.0', '7.2.2'], ['7.4.3', '']], 'type': 'str'},
-                'webfilter-profile-status': {'v_range': [['6.0.0', '7.2.2'], ['7.4.3', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                'emailfilter-profile': {'v_range': [['6.2.0', '7.2.2'], ['7.4.3', '']], 'type': 'str'},
-                'emailfilter-profile-status': {'v_range': [['6.2.0', '7.2.2'], ['7.4.3', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                'uuid': {'v_range': [['6.2.1', '7.2.0'], ['7.4.3', '']], 'type': 'str'},
-                'casi-profile': {'v_range': [['6.2.0', '6.2.12']], 'type': 'str'},
-                'casi-profile-status': {'v_range': [['6.2.0', '6.2.12']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                'dlp-profile': {'v_range': [['7.2.0', '7.2.1'], ['7.4.3', '']], 'type': 'str'},
-                'dlp-profile-status': {'v_range': [['7.2.0', '7.2.1'], ['7.4.3', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'srcaddr': {'v_range': [['6.0.0', '7.2.2'], ['7.2.6', '7.2.11'], ['7.4.3', '']], 'type': 'raw'},
+                'status': {'v_range': [['6.0.0', '7.2.2'], ['7.2.6', '7.2.11'], ['7.4.3', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'webfilter-profile': {'v_range': [['6.0.0', '7.2.2'], ['7.2.6', '7.2.11'], ['7.4.3', '']], 'type': 'str'},
+                'webfilter-profile-status': {
+                    'v_range': [['6.0.0', '7.2.2'], ['7.2.6', '7.2.11'], ['7.4.3', '']],
+                    'choices': ['disable', 'enable'],
+                    'type': 'str'
+                },
+                'emailfilter-profile': {'v_range': [['6.2.0', '7.2.2'], ['7.2.6', '7.2.11'], ['7.4.3', '']], 'type': 'str'},
+                'emailfilter-profile-status': {
+                    'v_range': [['6.2.0', '7.2.2'], ['7.2.6', '7.2.11'], ['7.4.3', '']],
+                    'choices': ['disable', 'enable'],
+                    'type': 'str'
+                },
+                'uuid': {'v_range': [['6.2.1', '7.2.0'], ['7.2.6', '7.2.11'], ['7.4.3', '']], 'type': 'str'},
+                'casi-profile': {'v_range': [['6.2.0', '6.2.13']], 'type': 'str'},
+                'casi-profile-status': {'v_range': [['6.2.0', '6.2.13']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'dlp-profile': {'v_range': [['7.2.0', '7.2.1'], ['7.2.6', '7.2.11'], ['7.4.3', '']], 'type': 'str'},
+                'dlp-profile-status': {
+                    'v_range': [['7.2.0', '7.2.1'], ['7.2.6', '7.2.11'], ['7.4.3', '']],
+                    'choices': ['disable', 'enable'],
+                    'type': 'str'
+                },
                 'casb-profile': {'v_range': [['7.4.3', '']], 'type': 'raw'},
                 'casb-profile-status': {'v_range': [['7.4.3', '']], 'choices': ['disable', 'enable'], 'type': 'str'}
             }
-
         }
     }
 
@@ -391,14 +437,15 @@ def main():
     params_validation_blob = []
     check_galaxy_version(module_arg_spec)
     module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'pkg_firewall_interfacepolicy'),
-                           supports_check_mode=False)
+                           supports_check_mode=True)
 
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_crud()
 
     module.exit_json(meta=module.params)
 
