@@ -16,7 +16,6 @@ short_description: Filter for FortiAnalyzer3 logging.
 description:
     - This module is able to configure a FortiManager device.
     - Examples include all parameters and values which need to be adjusted to data sources before usage.
-
 version_added: "2.0.0"
 author:
     - Xinwei Du (@dux-fortinet)
@@ -469,6 +468,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -477,54 +477,54 @@ EXAMPLES = '''
     - name: Filter for FortiAnalyzer3 logging.
       fortinet.fortimanager.fmgr_system_locallog_fortianalyzer3_filter:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         system_locallog_fortianalyzer3_filter:
-          devcfg: <value in [disable, enable]>
-          devops: <value in [disable, enable]>
-          diskquota: <value in [disable, enable]>
-          dm: <value in [disable, enable]>
-          dvm: <value in [disable, enable]>
-          ediscovery: <value in [disable, enable]>
-          epmgr: <value in [disable, enable]>
-          event: <value in [disable, enable]>
-          eventmgmt: <value in [disable, enable]>
-          faz: <value in [disable, enable]>
-          fazha: <value in [disable, enable]>
-          fazsys: <value in [disable, enable]>
-          fgd: <value in [disable, enable]>
-          fgfm: <value in [disable, enable]>
-          fips: <value in [disable, enable]>
-          fmgws: <value in [disable, enable]>
-          fmlmgr: <value in [disable, enable]>
-          fmwmgr: <value in [disable, enable]>
-          fortiview: <value in [disable, enable]>
-          glbcfg: <value in [disable, enable]>
-          ha: <value in [disable, enable]>
-          hcache: <value in [disable, enable]>
-          iolog: <value in [disable, enable]>
-          logd: <value in [disable, enable]>
-          logdb: <value in [disable, enable]>
-          logdev: <value in [disable, enable]>
-          logfile: <value in [enable, disable]>
-          logging: <value in [disable, enable]>
-          lrmgr: <value in [disable, enable]>
-          objcfg: <value in [disable, enable]>
-          report: <value in [disable, enable]>
-          rev: <value in [disable, enable]>
-          rtmon: <value in [disable, enable]>
-          scfw: <value in [disable, enable]>
-          scply: <value in [disable, enable]>
-          scrmgr: <value in [disable, enable]>
-          scvpn: <value in [disable, enable]>
-          system: <value in [disable, enable]>
-          webport: <value in [disable, enable]>
-          incident: <value in [disable, enable]>
-          aid: <value in [disable, enable]>
-          docker: <value in [disable, enable]>
-          controller: <value in [disable, enable]>
+          # devcfg: <value in [disable, enable]>
+          # devops: <value in [disable, enable]>
+          # diskquota: <value in [disable, enable]>
+          # dm: <value in [disable, enable]>
+          # dvm: <value in [disable, enable]>
+          # ediscovery: <value in [disable, enable]>
+          # epmgr: <value in [disable, enable]>
+          # event: <value in [disable, enable]>
+          # eventmgmt: <value in [disable, enable]>
+          # faz: <value in [disable, enable]>
+          # fazha: <value in [disable, enable]>
+          # fazsys: <value in [disable, enable]>
+          # fgd: <value in [disable, enable]>
+          # fgfm: <value in [disable, enable]>
+          # fips: <value in [disable, enable]>
+          # fmgws: <value in [disable, enable]>
+          # fmlmgr: <value in [disable, enable]>
+          # fmwmgr: <value in [disable, enable]>
+          # fortiview: <value in [disable, enable]>
+          # glbcfg: <value in [disable, enable]>
+          # ha: <value in [disable, enable]>
+          # hcache: <value in [disable, enable]>
+          # iolog: <value in [disable, enable]>
+          # logd: <value in [disable, enable]>
+          # logdb: <value in [disable, enable]>
+          # logdev: <value in [disable, enable]>
+          # logfile: <value in [enable, disable]>
+          # logging: <value in [disable, enable]>
+          # lrmgr: <value in [disable, enable]>
+          # objcfg: <value in [disable, enable]>
+          # report: <value in [disable, enable]>
+          # rev: <value in [disable, enable]>
+          # rtmon: <value in [disable, enable]>
+          # scfw: <value in [disable, enable]>
+          # scply: <value in [disable, enable]>
+          # scrmgr: <value in [disable, enable]>
+          # scvpn: <value in [disable, enable]>
+          # system: <value in [disable, enable]>
+          # webport: <value in [disable, enable]>
+          # incident: <value in [disable, enable]>
+          # aid: <value in [disable, enable]>
+          # docker: <value in [disable, enable]>
+          # controller: <value in [disable, enable]>
 '''
 
 RETURN = '''
@@ -568,21 +568,14 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/cli/global/system/locallog/fortianalyzer3/filter'
     ]
-
-    perobject_jrpc_urls = [
-        '/cli/global/system/locallog/fortianalyzer3/filter/{filter}'
-    ]
-
     url_params = []
     module_primary_key = None
     module_arg_spec = {
@@ -630,11 +623,14 @@ def main():
                 'system': {'choices': ['disable', 'enable'], 'type': 'str'},
                 'webport': {'choices': ['disable', 'enable'], 'type': 'str'},
                 'incident': {'v_range': [['6.4.0', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                'aid': {'v_range': [['6.4.1', '7.2.4']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                'docker': {'v_range': [['6.4.3', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                'controller': {'v_range': [['7.0.9', '7.0.10'], ['7.2.4', '7.2.4'], ['7.4.1', '']], 'choices': ['disable', 'enable'], 'type': 'str'}
+                'aid': {'v_range': [['6.4.1', '7.2.11']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'docker': {
+                    'v_range': [['6.4.3', '7.0.14'], ['7.2.0', '7.2.10'], ['7.4.0', '7.4.7'], ['7.6.0', '7.6.3']],
+                    'choices': ['disable', 'enable'],
+                    'type': 'str'
+                },
+                'controller': {'v_range': [['7.0.9', '7.0.15'], ['7.2.4', '7.2.11'], ['7.4.1', '']], 'choices': ['disable', 'enable'], 'type': 'str'}
             }
-
         }
     }
 
@@ -643,17 +639,15 @@ def main():
     params_validation_blob = []
     check_galaxy_version(module_arg_spec)
     module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'system_locallog_fortianalyzer3_filter'),
-                           supports_check_mode=False)
+                           supports_check_mode=True)
 
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    connection.set_option('access_token', module.params.get('access_token', None))
-    connection.set_option('enable_log', module.params.get('enable_log', False))
-    connection.set_option('forticloud_access_token', module.params.get('forticloud_access_token', None))
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('partial crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_partial_curd(argument_specs=module_arg_spec)
+    fmgr.process_partial_crud()
 
     module.exit_json(meta=module.params)
 
