@@ -16,7 +16,6 @@ short_description: Maximum length of parameter in URL.
 description:
     - This module is able to configure a FortiManager device.
     - Examples include all parameters and values which need to be adjusted to data sources before usage.
-
 version_added: "2.0.0"
 author:
     - Xinwei Du (@dux-fortinet)
@@ -64,6 +63,9 @@ options:
         description: The rc codes list with which the conditions to fail will be overriden.
         type: list
         elements: int
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -118,6 +120,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -126,18 +129,18 @@ EXAMPLES = '''
     - name: Maximum length of parameter in URL.
       fortinet.fortimanager.fmgr_waf_profile_constraint_urlparamlength:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
         profile: <your own value>
         waf_profile_constraint_urlparamlength:
-          action: <value in [allow, block]>
-          length: <integer>
-          log: <value in [disable, enable]>
-          severity: <value in [low, medium, high]>
-          status: <value in [disable, enable]>
+          # action: <value in [allow, block]>
+          # length: <integer>
+          # log: <value in [disable, enable]>
+          # severity: <value in [low, medium, high]>
+          # status: <value in [disable, enable]>
 '''
 
 RETURN = '''
@@ -195,6 +198,7 @@ def main():
     module_arg_spec = {
         'adom': {'required': True, 'type': 'str'},
         'profile': {'required': True, 'type': 'str'},
+        'revision_note': {'type': 'str'},
         'waf_profile_constraint_urlparamlength': {
             'type': 'dict',
             'v_range': [['6.0.0', '']],
