@@ -11,6 +11,7 @@ try:
     from ..common.hv_log import Log
     from ..common.ansible_common import log_entry_exit
     from ..message.vsp_shadow_image_pair_msgs import VSPShadowImagePairValidateMsg
+    from ..common.ansible_common_constants import MAX_WORKER_THREADS
 
 except ImportError:
     from common.vsp_constants import Endpoints
@@ -37,11 +38,15 @@ class VSPShadowImagePairDirectGateway:
             connection_info.password,
             connection_info.api_token,
         )
+        self.all_pairs = []
+        self.all_si_pairs = None
 
     @log_entry_exit
     def get_all_shadow_image_pairs(self, serial, refresh=None):
         funcName = "VSPShadowImagePairDirectGateway: get_all_shadow_image_pairs"
         self.logger.writeEnterSDK(funcName)
+        if self.all_si_pairs is not None:
+            return self.all_si_pairs
         response = self.get_all_shadow_image_pairs_by_copy_group(serial, refresh)
         self.logger.writeDebug("{} Response={}", funcName, response)
         shadow_image_list = []
@@ -50,9 +55,54 @@ class VSPShadowImagePairDirectGateway:
             if shadow_image is not None:
                 shadow_image_list.append(shadow_image)
         self.logger.writeExitSDK(funcName)
-        return VSPShadowImagePairsInfo(
+        si_pais = VSPShadowImagePairsInfo(
             dicts_to_dataclass_list(shadow_image_list, VSPShadowImagePairInfo)
         )
+        self.all_si_pairs = si_pais
+        return self.all_si_pairs
+
+    @log_entry_exit
+    def get_specific_cg_pair_by_pvol_svol(
+        self,
+        pvol,
+        svol,
+        cg_name=None,
+        cp_name=None,
+        pm_device_grp_name=None,
+        sec_device_grp_name=None,
+    ):
+        funcName = "VSPShadowImagePairDirectGateway: get_specific_cg_pair_by_pvol_svol"
+        self.logger.writeEnterSDK(funcName)
+
+        copy_group_name = (
+            self.generate_copy_group_name(pvol, svol) if cg_name is None else cg_name
+        )
+        pvol_device_grp_name = (
+            copy_group_name + "P_" if pm_device_grp_name is None else pm_device_grp_name
+        )
+        svol_device_grp_name = (
+            copy_group_name + "S_"
+            if sec_device_grp_name is None
+            else sec_device_grp_name
+        )
+        copy_pair_name = (
+            self.generate_copy_pair_name(pvol, svol) if cp_name is None else cp_name
+        )
+        pair_id = f"{copy_group_name},{pvol_device_grp_name},{svol_device_grp_name},{copy_pair_name}"
+        end_point = Endpoints.DIRECT_GET_SHADOW_IMAGE_PAIR_BY_ID.format(pairId=pair_id)
+
+        try:
+            response = self.connectionManager.read(end_point)
+            shadow_image_pair = self.parse_shadow_image_data(
+                serial=None, response=response
+            )
+            self.logger.writeDebug("{} Response={}", funcName, shadow_image_pair)
+            self.logger.writeExitSDK(funcName)
+
+            return VSPShadowImagePairInfo(**shadow_image_pair)
+        except Exception as e:
+            self.logger.writeError(f"An error occurred: {str(e)}")
+            return None
 
     @log_entry_exit
     def get_shadow_image_pair_by_pvol(self, serial, pvol):
@@ -172,13 +222,17 @@ class VSPShadowImagePairDirectGateway:
         return response
 
     def generate_create_payload(self, serial, createShadowImagePairSpec):
+        pvol_mu_number = 0
         if (
             createShadowImagePairSpec.is_new_group_creation is None
             or createShadowImagePairSpec.is_new_group_creation is True
         ):
-            pvol_mu_number = self.get_pvol_mu_number(
-                serial, createShadowImagePairSpec.pvol
+            pvol_mu_number = (
+                self.get_pvol_mu_number(serial, createShadowImagePairSpec.pvol)
+                if createShadowImagePairSpec.pvol_mu_number is None
+                else createShadowImagePairSpec.pvol_mu_number
             )
+
         if createShadowImagePairSpec.copy_group_name is not None:
             copy_group_name = createShadowImagePairSpec.copy_group_name
         else:
@@ -194,6 +248,9 @@ class VSPShadowImagePairDirectGateway:
         copy_pace = self.get_copy_pace_value(
             createShadowImagePairSpec.copy_pace_track_size
         )
+        createShadowImagePairSpec.is_new_group_creation = (
+            False if self.__check_group_exists(copy_group_name) else True
+        )
         payload = {
             "copyGroupName": copy_group_name,
             "copyPairName": copy_pair_name,
@@ -210,11 +267,7 @@ class VSPShadowImagePairDirectGateway:
                 if createShadowImagePairSpec.secondary_volume_device_group_name is None
                 else createShadowImagePairSpec.secondary_volume_device_group_name
             ),
-            "isNewGroupCreation": (
-                createShadowImagePairSpec.is_new_group_creation
-                if createShadowImagePairSpec.is_new_group_creation is not None
-                else True
-            ),
+            "isNewGroupCreation": createShadowImagePairSpec.is_new_group_creation,
             "copyPace": (
                 copy_pace
                 if createShadowImagePairSpec.create_for_migration is None
@@ -340,15 +393,20 @@ class VSPShadowImagePairDirectGateway:
     def get_pvol_mu_number(self, serial, pvol):
         pvol_mu_number = None
         shadow_image_pairs = self.get_shadow_image_pair_by_pvol(serial, pvol=pvol)
-        if len(shadow_image_pairs.data_to_list()) == 0:
+        shadow_image_pairs_data_list = shadow_image_pairs.data_to_list()
+        self.logger.writeDebug(
+            f"GW:get_pvol_mu_number: shadow_image_pairs_data_list = {shadow_image_pairs_data_list}"
+        )
+        if len(shadow_image_pairs_data_list) == 0:
             pvol_mu_number = 0
             return pvol_mu_number
-        if len(shadow_image_pairs.data_to_list()) == 3:
+        if len(shadow_image_pairs_data_list) == 3:
             raise SystemError(VSPShadowImagePairValidateMsg.MAX_3_PAIR_EXISTS.value)
         mu_numbers = [0, 1, 2]
-        for sip in shadow_image_pairs.data_to_list():
+        for sip in shadow_image_pairs_data_list:
             if sip.get("_VSPShadowImagePairInfo__pvolMuNumber") in mu_numbers:
                 mu_numbers.remove(sip.get("_VSPShadowImagePairInfo__pvolMuNumber"))
+        self.logger.writeDebug(f"GW:get_pvol_mu_number: mu_numbers = {mu_numbers}")
         pvol_mu_number = mu_numbers[0]
         return pvol_mu_number
 
@@ -394,9 +452,7 @@ class VSPShadowImagePairDirectGateway:
             else None
         )
         shadow_image_obj["status"] = response["pvolStatus"]
-        shadow_image_obj["_VSPShadowImagePairInfo__pvolMuNumber"] = response[
-            "pvolMuNumber"
-        ]
+        shadow_image_obj["pvolMuNumber"] = response["pvolMuNumber"]
         shadow_image_obj["mirrorUnitId"] = response["pvolMuNumber"]
         shadow_image_obj["copyRate"] = (
             response["copyProgressRate"]
@@ -419,13 +475,19 @@ class VSPShadowImagePairDirectGateway:
         funcName = (
             "VSPShadowImagePairDirectGateway: get_all_shadow_image_pairs_by_copy_pair"
         )
+        if self.all_pairs:
+            return {"data": self.all_pairs}
+
         self.logger.writeEnterSDK(funcName)
         end_point = Endpoints.DIRECT_GET_ALL_COPY_PAIR_GROUP
         local_cp_pairs = Endpoints.DIRECT_GET_SI_BY_CPG
         response = self.connectionManager.read(end_point)
         self.logger.writeDebug("{} Copy Group Response={}", funcName, response)
         shadow_image_list = []
-        for copy_group_item in response["data"]:
+
+        import concurrent.futures
+
+        def fetch_copy_group_data(copy_group_item):
             copy_group_id = copy_group_item["localCloneCopygroupId"]
             if refresh is not None and refresh is True:
                 uri = local_cp_pairs.format(copy_group_id) + "&refresh=true"
@@ -433,11 +495,49 @@ class VSPShadowImagePairDirectGateway:
                 uri = local_cp_pairs.format(copy_group_id)
             try:
                 resp = self.connectionManager.read(uri)
-                for shadow_image_item in resp.get("data"):
-                    shadow_image_list.append(shadow_image_item)
+                return resp.get("data", [])
             except Exception as e:
                 self.logger.writeError(f"An error occurred: {str(e)}")
+                return []
 
+        # Use ThreadPoolExecutor for concurrent requests
+        executor = concurrent.futures.ThreadPoolExecutor(
+            max_workers=MAX_WORKER_THREADS, thread_name_prefix="FetchCopyGroups"
+        )
+        try:
+            self.logger.writeDebug(
+                f"Fetching shadow image items concurrently for {len(response['data'])} copy groups"
+            )
+            future_to_copy_group = {
+                executor.submit(fetch_copy_group_data, copy_group_item): copy_group_item
+                for copy_group_item in response["data"]
+            }
+
+            for future in concurrent.futures.as_completed(future_to_copy_group):
+                shadow_image_items = future.result()
+                shadow_image_list.extend(shadow_image_items)
+            self.logger.writeDebug(
+                f"Total shadow image items fetched = {len(shadow_image_list)}"
+            )
+        except KeyboardInterrupt:
+            executor.shutdown(wait=False, cancel_futures=True)
+            raise
+        finally:
+            executor.shutdown(wait=True)
         self.logger.writeExitSDK(funcName)
         data = {"data": shadow_image_list}
+        self.all_pairs = shadow_image_list
         return data
+
+    def __check_group_exists(self, copy_group_name):
+        copy_groups = self.get_all_copy_groups()
+        for copy_group_item in copy_groups["data"]:
+            if copy_group_item["copyGroupName"] == copy_group_name:
+                return True
+        return False
+
+    @log_entry_exit
+    def get_all_copy_groups(self):
+        end_point = Endpoints.DIRECT_GET_ALL_COPY_PAIR_GROUP
+        response = self.connectionManager.read(end_point)
+        return response
