@@ -4,18 +4,28 @@ from typing import Optional, List
 try:
     from .common_base_models import BaseDataClass, SingleBaseClass
     from ..common.hv_log import Log
-    from ..common.ansible_common import convert_mib_to_mb, convert_capacity_to_mib
+    from ..common.ansible_common import (
+        convert_capacity_to_mib,
+        normalize_ldev_id,
+        volume_id_to_hex_format,
+    )
 
 except ImportError:
     from .common_base_models import BaseDataClass, SingleBaseClass
     from common.hv_log import Log
+    from common.ansible_common import (
+        convert_capacity_to_mib,
+        normalize_ldev_id,
+        volume_id_to_hex_format,
+    )
 
 logger = Log()
 
 
 @dataclass
 class VolumeFactSpec:
-    ldev_id: Optional[str] = None
+    ldev_id: Optional[int] = None
+    ldev_ids: Optional[List[int]] = None
     name: Optional[str] = None
     count: Optional[int] = None
     end_ldev_id: Optional[int] = None
@@ -27,6 +37,16 @@ class VolumeFactSpec:
     journal_id: Optional[int] = None
     parity_group_id: Optional[str] = None
 
+    def __post_init__(self):
+        if self.ldev_id:
+            self.ldev_id = normalize_ldev_id(self.ldev_id)
+        if self.start_ldev_id:
+            self.start_ldev_id = normalize_ldev_id(self.start_ldev_id)
+        if self.end_ldev_id:
+            self.end_ldev_id = normalize_ldev_id(self.end_ldev_id)
+        if self.ldev_ids:
+            self.ldev_ids = [normalize_ldev_id(ldev_id) for ldev_id in self.ldev_ids]
+
 
 @dataclass
 class TieringPolicySpec:
@@ -71,9 +91,8 @@ class CreateVolumeSpec:
     name: Optional[str] = None
     size: Optional[str] = None
     block_size: Optional[int] = None
-    ldev_id: Optional[str] = None
-    # sng20241205 vldev_id
-    vldev_id: Optional[str] = None
+    ldev_id: Optional[int] = None
+    vldev_id: Optional[int] = None
     pool_id: Optional[int] = None
     capacity_saving: Optional[str] = None
     parity_group: Optional[str] = None
@@ -104,12 +123,26 @@ class CreateVolumeSpec:
     is_alua_enabled: Optional[bool] = None
     format_type: Optional[str] = None
     is_task_timeout: Optional[bool] = None
+    cylinder: Optional[int] = None
+    emulation_type: Optional[str] = None
+    is_tse_volume: Optional[bool] = None
+    is_ese_volume: Optional[bool] = None
+    ssid: Optional[str] = None
+    should_stop_all_volume_format: Optional[bool] = None
     # added comment for ldev module
     comment: Optional[str] = None
 
     def __post_init__(self):
         if self.qos_settings:
             self.qos_settings = VolumeQosParamsSpec(**self.qos_settings)
+        if self.ldev_id:
+            self.ldev_id = normalize_ldev_id(self.ldev_id)
+        if self.vldev_id:
+            self.vldev_id = normalize_ldev_id(self.vldev_id)
+        if self.start_ldev_id:
+            self.start_ldev_id = normalize_ldev_id(self.start_ldev_id)
+        if self.end_ldev_id:
+            self.end_ldev_id = normalize_ldev_id(self.end_ldev_id)
 
 
 @dataclass
@@ -212,6 +245,10 @@ class VSPVolumeInfo(SingleBaseClass):
     dataReductionProcessMode: Optional[str] = None
     isRelocationEnabled: Optional[bool] = None
     isFullAllocationEnabled: Optional[bool] = None
+    parentVolumeId: Optional[int] = None
+    parentLdevId: Optional[int] = None
+    ssid: Optional[str] = None
+    cylinder: Optional[int] = None
 
     def __init__(self, **kwargs):
         try:
@@ -223,6 +260,17 @@ class VSPVolumeInfo(SingleBaseClass):
 
         super().__init__(**kwargs)
         try:
+
+            self.isDataReductionShareEnabled = (
+                True if "DRS" in self.attributes else None
+            )
+
+            if self.qosSettings is not None:
+                self.qosSettings = VolumeQosParamsOutput(**self.qosSettings)
+
+            if self.parentLdevId is not None and self.parentVolumeId is None:
+                self.parentVolumeId = self.parentLdevId
+
             storage_info = get_basic_storage_details()
             if storage_info is None:
                 return
@@ -237,17 +285,14 @@ class VSPVolumeInfo(SingleBaseClass):
             else:
                 self.canonicalName = self.naaId
 
-            self.isDataReductionShareEnabled = (
-                True if "DRS" in self.attributes else None
-            )
-
-            if self.qosSettings is not None:
-                self.qosSettings = VolumeQosParamsOutput(**self.qosSettings)
-
         except Exception as ex:
             logger.writeDebug(f"MODEL: exception in initializing VSPVolumeInfo {ex}")
         return
 
+    def camel_to_snake_dict(self):
+        camel_dict = super().camel_to_snake_dict()
+        return camel_dict
+
 
 @dataclass
 class VSPVolumesInfo(BaseDataClass):
@@ -367,13 +412,17 @@ class VSPVolume_V2:
 
 
 @dataclass
-class VSPUndefinedVolumeInfo:
+class VSPUndefinedVolumeInfo(SingleBaseClass):
     ldevId: int = 0
     emulationType: str = None
     ssid: str = None
+    attributes: List[str] = None
     resourceGroupId: int = 0
     virtualLdevId: int = 0
 
+    def __init__(self, **kwargs):
+        super().__init__(**kwargs)
+
 
 @dataclass
 class VSPUndefinedVolumeInfoList(BaseDataClass):
@@ -440,6 +489,13 @@ class SimpleAPILuns(SingleBaseClass):
     serverId: int
 
 
+@dataclass
+class PavAttribute(SingleBaseClass):
+    type: Optional[str] = None
+    numberOfAssignAliasVolumes: Optional[int] = None
+    assignAliasVolumeIds: Optional[List[int]] = None
+
+
 @dataclass
 class SalamanderSimpleVolumeInfo(SingleBaseClass):
     id: Optional[int] = None
@@ -454,6 +510,7 @@ class SalamanderSimpleVolumeInfo(SingleBaseClass):
     usedCapacityInMB: Optional[int] = None
     reservedCapacity: Optional[int] = None
     savingSetting: Optional[str] = None
+    capacitySaving: Optional[str] = None
     isDataReductionShareEnabled: Optional[bool] = None
     compressionAcceleration: Optional[bool] = None
     compressionAccelerationStatus: Optional[str] = None
@@ -465,21 +522,47 @@ class SalamanderSimpleVolumeInfo(SingleBaseClass):
     qosSettings: Optional[dict] = None
     parentVolumeId: Optional[int] = None
     capacitySavingProgress: Optional[int] = None
+    cuId: Optional[int] = None
+    ssid: Optional[str] = None
+    systemType: Optional[str] = None
+    emulationType: Optional[str] = None
+    capacityUnit: Optional[str] = None
+    clprId: Optional[int] = None
+    currentMpu: Optional[int] = None
+    currentMpuLocId: Optional[str] = None
+    pav: Optional[PavAttribute] = None
+
+    def __init__(self, **kwargs):
+        super().__init__(**kwargs)
+        self.__post_init__()
 
     def __post_init__(self):
         # if self.qosSettings:
         #     self.qosSettings = SimpleVolumeQosConfig(**self.qosSettings)
         if self.totalCapacity is not None:
             # Convert totalCapacity from bytes to MiB
-            self.totalCapacityInMB = convert_mib_to_mb(self.totalCapacity)
+            self.totalCapacityInMB = self.totalCapacity
         if self.usedCapacity is not None:
             # Convert usedCapacity from bytes to MiB
-            self.usedCapacityInMB = convert_mib_to_mb(self.usedCapacity)
+            self.usedCapacityInMB = self.usedCapacity
         if self.freeCapacity is not None:
             # Convert freeCapacity from bytes to MiB
-            self.freeCapacityInMB = convert_mib_to_mb(self.freeCapacity)
+            self.freeCapacityInMB = self.freeCapacity
         if self.luns is not None:
             self.luns = [SimpleAPILuns(**lun) for lun in self.luns]
+        if self.capacitySaving is None:
+            self.capacitySaving = self.savingSetting
+        if self.pav is not None:
+            self.pav = PavAttribute(**self.pav)
+
+    def camel_to_snake_dict(self):
+        camel_dict = super().camel_to_snake_dict()
+        camel_dict.pop("saving_setting")
+        camel_dict["id_hex"] = volume_id_to_hex_format(self.id)
+        camel_dict["parent_volume_id_hex"] = volume_id_to_hex_format(
+            self.parentVolumeId
+        )
+        return camel_dict
 
 
 @dataclass
@@ -528,7 +611,8 @@ class SalamanderCreateVolumeRequestSpec(SingleBaseClass):
     capacity: Optional[int] = None  # in MiB
     number_of_volumes: Optional[int] = 1
     volume_name: Optional[SalamanderNicknameParam] = None
-    saving_setting: Optional[str] = None
+    # saving_setting: Optional[str] = None
+    capacity_saving: Optional[str] = None
     is_data_reduction_share_enabled: Optional[bool] = False
     pool_id: Optional[int] = None
     volume_id: Optional[int] = None
@@ -536,6 +620,7 @@ class SalamanderCreateVolumeRequestSpec(SingleBaseClass):
     server_ids: Optional[List[str]] = None
     comments: Optional[List[str]] = None
     compression_acceleration: Optional[bool] = None
+    volume_ids: Optional[List[int]] = None  # For multiple volume
 
     def __post_init__(self):
         # Convert dict to NicknameParam instance if needed
@@ -548,6 +633,12 @@ class SalamanderCreateVolumeRequestSpec(SingleBaseClass):
             self.comments = []
         if self.qos_settings and isinstance(self.qos_settings, dict):
             self.qos_settings = SimpleVolumeQosParamsSpec(**self.qos_settings)
+        if self.volume_id:
+            self.volume_id = normalize_ldev_id(self.volume_id)
+        if self.volume_ids:
+            self.volume_ids = [
+                normalize_ldev_id(ldev_id) for ldev_id in self.volume_ids
+            ]
 
 
 @dataclass
@@ -600,11 +691,15 @@ class SimpleAPIVolumeFactsSpec(SingleBaseClass):
     def __init__(self, **kwargs):
         super().__init__(**kwargs)
         for key, value in kwargs.items():
-            if isinstance(value, int) and value < 0 :
-                raise ValueError(f"Invalid value for '{key}': Negative value is not allowed")
+            if isinstance(value, int) and value < 0:
+                raise ValueError(
+                    f"Invalid value for '{key}': Negative value is not allowed"
+                )
         count = kwargs.get("count", None)
         if count is not None and count < 1:
-            raise ValueError("Invalid value for 'count': Must be greater than or equal to 1")
+            raise ValueError(
+                "Invalid value for 'count': Must be greater than or equal to 1"
+            )
 
         self.__post_init__()
 
@@ -617,3 +712,7 @@ class SimpleAPIVolumeFactsSpec(SingleBaseClass):
             self.min_used_capacity = convert_capacity_to_mib(self.min_used_capacity)
         if self.max_used_capacity is not None:
             self.max_used_capacity = convert_capacity_to_mib(self.max_used_capacity)
+        if self.start_volume_id:
+            self.start_volume_id = normalize_ldev_id(self.start_volume_id)
+        if self.volume_id:
+            self.volume_id = normalize_ldev_id(self.volume_id)
