@@ -11,7 +11,7 @@ try:
         convert_decimal_size_to_bytes,
     )
     from ..model.vsp_hur_models import VSPHurPairInfoList
-    from .vsp_true_copy_provisioner import RemoteReplicationHelperForSVol
+    from .vsp_remote_replication_helper import RemoteReplicationHelperForSVol
     from ..message.vsp_hur_msgs import VSPHurValidateMsg, HurFailedMsg
 
     from ..model.vsp_copy_groups_models import (
@@ -30,7 +30,7 @@ except ImportError:
     )
     from model.vsp_hur_models import VSPHurPairInfoList
     from message.vsp_hur_msgs import VSPHurValidateMsg, HurFailedMsg
-    from .vsp_true_copy_provisioner import RemoteReplicationHelperForSVol
+    from .vsp_remote_replication_helper import RemoteReplicationHelperForSVol
     from model.vsp_copy_groups_models import (
         DirectCopyPairInfo,
         DirectSpecificCopyGroupInfoList,
@@ -277,7 +277,6 @@ class VSPHurProvisioner:
 
     @log_entry_exit
     def get_hur_facts(self, spec=None):
-        # primary_volume_id = spec.get('primary_volume_id',None)
         primary_volume_id = spec.primary_volume_id
         if spec is None or (spec and primary_volume_id is None):
             return self.get_all_hurpairs()
@@ -410,6 +409,13 @@ class VSPHurProvisioner:
     @log_entry_exit
     def swap_resync_hur_pair(self, primary_volume_id, spec=None):
         pair_exiting = self.gateway.get_replication_pair(spec)
+        if pair_exiting is None:
+            err_msg = (
+                HurFailedMsg.PAIR_SWAP_RESYNC_FAILED.value
+                + VSPHurValidateMsg.NO_HUR_PAIR_FOUND.value.format(spec.copy_pair_name)
+            )
+            logger.writeError(err_msg)
+            raise ValueError(err_msg)
         if (
             pair_exiting["pvol_status"] == "PAIR"
             and pair_exiting["svol_status"] == "PAIR"
@@ -469,7 +475,15 @@ class VSPHurProvisioner:
 
     @log_entry_exit
     def swap_split_hur_pair(self, primary_volume_id, spec=None):
+        err_msg = ""
         pair_exiting = self.gateway.get_replication_pair(spec)
+        if pair_exiting is None:
+            err_msg = (
+                HurFailedMsg.PAIR_SWAP_SPLIT_FAILED.value
+                + VSPHurValidateMsg.NO_HUR_PAIR_FOUND.value.format(spec.copy_pair_name)
+            )
+            logger.writeError(err_msg)
+            raise ValueError(err_msg)
         if (
             pair_exiting["pvol_status"] == "PSUS"
             and pair_exiting["svol_status"] == "SSWS"
@@ -481,6 +495,13 @@ class VSPHurProvisioner:
         self.connection_info.changed = True
         return pair
 
+    @log_entry_exit
+    def secondary_takeover_hur_pair(self, spec=None):
+        pair = self.gateway.secondary_takeover_hur_pair(spec)
+        self.logger.writeDebug(f"PV:secondary_takeover_hur_pair: pair=  {pair}")
+        self.connection_info.changed = True
+        return pair
+
     @log_entry_exit
     def is_resize_needed(self, volume_data, spec):
         size_in_bytes = convert_decimal_size_to_bytes(spec.new_volume_size)
@@ -546,18 +567,10 @@ class VSPHurProvisioner:
     def get_copy_group_by_name(self, spec):
         return self.cg_gw.get_copy_group_by_name(spec)
 
-    # 20240808 - prov.create_hur
     @log_entry_exit
     def create_hur_pair(self, spec):
-        return self.create_hur_direct(spec)
-
-    @log_entry_exit
-    def create_hur_direct(self, spec):
         pair_exiting = self.gateway.get_replication_pair(spec)
-        # if spec.begin_secondary_volume_id or spec.end_secondary_volume_id:
-        #     raise ValueError(
-        #         VSPHurValidateMsg.SECONDARY_RANGE_ID_IS_NOT_SUPPORTED.value
-        #     )
+
         if pair_exiting is not None:
             if pair_exiting["pvol_ldev_id"] != spec.primary_volume_id:
                 return "Copy pair name : {} already exits in copy group: {}".format(
@@ -623,11 +636,10 @@ class VSPHurProvisioner:
             spec.secondary_volume_id = secondary_vol_id
             spec.is_data_reduction_force_copy = pvol.isDataReductionShareEnabled
             result = self.gateway.create_hur_pair(spec)
-            self.logger.writeDebug(f"create_hur_direct result: {result}")
+            self.logger.writeDebug(f"create_hur result: {result}")
 
             # get immediately after create returning Unable to find the resource. give 5 secs
             time.sleep(5)
-            # return self.get_replication_pair_by_id(result)
             pair = self.gateway.get_replication_pair(spec)
             self.connection_info.changed = True
             return pair
@@ -644,16 +656,15 @@ class VSPHurProvisioner:
                         pvol.namespaceId,
                     )
                 else:
-                    rr_prov.delete_volume(secondary_vol_id)
+                    if spec.provisioned_secondary_volume_id is None:
+                        rr_prov.delete_volume(secondary_vol_id)
                 logger.writeError(err_msg)
             raise ValueError(err_msg)
 
     @log_entry_exit
     def get_volume_by_id(self, primary_volume_id):
         volume = self.vol_gw.get_volume_by_id(primary_volume_id)
-        # return vol_gw.get_volume_by_id(device_id, primary_volume_id)
         self.logger.writeDebug(f"PROV:get_volume_by_id:volume: {volume}")
-
         return volume
 
     @log_entry_exit
