@@ -44,12 +44,20 @@ class VSPShadowImagePairReconciler:
         self.shadowImagePairSpec = shadowImagePairSpec
         self.provisioner = VSPShadowImagePairProvisioner(self.connectionInfo)
         self.port_provisioner = VSPStoragePortProvisioner(connectionInfo)
-        self.port_type_dict = {}
-        self.get_port_type_dict()
+        self.port_type_dict = None
+        # self.get_port_type_dict()
         if self.serial is None:
             self.serial = self.get_storage_serial_number()
 
+    @log_entry_exit
     def get_port_type_dict(self):
+        if self.port_type_dict is None:
+            self.port_type_dict = {}
+            self._populate_port_type_dict()
+        return self.port_type_dict
+
+    @log_entry_exit
+    def _populate_port_type_dict(self):
         port_info = self.port_provisioner.get_all_storage_ports().data_to_list()
         # self.logger.writeDebug(f"20250324 port_info: {port_info}")
         for port in port_info:
@@ -67,14 +75,13 @@ class VSPShadowImagePairReconciler:
                 self.serial, None, shadowImagePairSpec.refresh
             )
         elif shadowImagePairSpec.copy_pair_name and shadowImagePairSpec.copy_group_name:
-            data = self.provisioner.get_shadow_image_pair_by_copy_pair_name(
-                self.serial,
+            data = self.get_shadow_image_pair_by_copy_pair_name(
                 shadowImagePairSpec.copy_pair_name,
                 shadowImagePairSpec.copy_group_name,
             )
             data = (
                 ShadowImagePairPropertyExtractor(self.serial).extract(
-                    [data], self.port_type_dict
+                    [data], self.get_port_type_dict()
                 )[0]
                 if isinstance(data, dict)
                 else data
@@ -85,7 +92,7 @@ class VSPShadowImagePairReconciler:
                 self.serial, shadowImagePairSpec.pvol, None
             )
         return ShadowImagePairPropertyExtractor(self.serial).extract(
-            data, self.port_type_dict
+            data, self.get_port_type_dict()
         )
 
     @log_entry_exit
@@ -100,25 +107,37 @@ class VSPShadowImagePairReconciler:
         shadow_image_response = None
         copy_group_name = None
         shadow_image_data = None
-        try:
-            if self.shadowImagePairSpec.pvol and self.shadowImagePairSpec.svol:
-                shadow_image_data = self.shadow_image_pair_get_by_pvol_and_svol(
-                    self.shadowImagePairSpec.pvol, self.shadowImagePairSpec.svol
-                )
-            elif (
-                self.shadowImagePairSpec.copy_pair_name
-                and self.shadowImagePairSpec.copy_group_name
-            ):
-                shadow_image_data = self.get_shadow_image_pair_by_copy_pair_name(
-                    self.shadowImagePairSpec.copy_pair_name,
-                    self.shadowImagePairSpec.copy_group_name,
-                )
-            else:
-                raise ValueError(
-                    "Either pvol and svol or copy_pair_name and copy_group_name must be provided."
-                )
-        except Exception as e:
-            logger.writeError(f"An error occurred: {str(e)}")
+
+        if (
+            self.shadowImagePairSpec.pvol_mu_number is not None
+            and self.shadowImagePairSpec.pvol is not None
+            and self.shadowImagePairSpec.svol is not None
+            and state == StateValue.PRESENT
+        ):
+            shadow_image_data = None
+        elif (
+            self.shadowImagePairSpec.copy_pair_name is not None
+            and self.shadowImagePairSpec.copy_group_name is not None
+        ):
+            shadow_image_data = self.get_shadow_image_pair_by_copy_pair_name(
+                self.shadowImagePairSpec.copy_pair_name,
+                self.shadowImagePairSpec.copy_group_name,
+            )
+        elif (
+            self.shadowImagePairSpec.pvol is not None
+            and self.shadowImagePairSpec.svol is not None
+        ):
+            shadow_image_data = self.shadow_image_pair_get_by_pvol_and_svol(
+                self.shadowImagePairSpec.pvol, self.shadowImagePairSpec.svol
+            )
+            shadow_image_data = (
+                shadow_image_data.to_dict() if shadow_image_data is not None else None
+            )
+        else:
+            raise ValueError(
+                "Either pvol and svol or copy_pair_name and copy_group_name must be provided."
+            )
+
         pairId = None
         if shadow_image_data is not None:
             pairId = shadow_image_data.get("resourceId")
@@ -126,18 +145,12 @@ class VSPShadowImagePairReconciler:
             svolId = shadow_image_data.get("secondaryVolumeId")
             copy_group_name = shadow_image_data.get("copyGroupName")
             self.shadowImagePairSpec.secondary_volume_id = svolId
+
         if pairId is not None:
             self.shadowImagePairSpec.pair_id = pairId
         try:
             if state == StateValue.PRESENT:
-                if (
-                    (pairId is not None)
-                    and (int(self.shadowImagePairSpec.primary_volume_id) == int(pvolId))
-                    and (self.shadowImagePairSpec.secondary_volume_id is not None)
-                    and (
-                        int(self.shadowImagePairSpec.secondary_volume_id) == int(svolId)
-                    )
-                ):
+                if pairId is not None:
                     shadow_image_response = shadow_image_data
                     self.connectionInfo.changed = False
                 else:
@@ -154,10 +167,37 @@ class VSPShadowImagePairReconciler:
                                 ]
                         else:
                             self.shadowImagePairSpec.is_new_group_creation = True
-                    shadow_image_response = self.shadow_image_pair_create(
-                        self.shadowImagePairSpec
-                    )
-                    self.connectionInfo.changed = True
+                    try:
+                        shadow_image_response = self.shadow_image_pair_create(
+                            self.shadowImagePairSpec
+                        )
+                        self.connectionInfo.changed = True
+                    except Exception as e:
+                        logger.writeError(f"Error creating shadow image pair: {e}")
+                        if (
+                            "Another copy pair might already be using the specified LDEV"
+                            in str(e)
+                        ):
+                            raise Exception(
+                                f"Another copy pair might already be using the specified primary volume {self.shadowImagePairSpec.primary_volume_id}. "
+                                f"and secondary volume {self.shadowImagePairSpec.secondary_volume_id}. "
+                                "Please verify and try again with correct copy group name and copy pair name."
+                            )
+                        elif (
+                            "specified for the object (copyPairName) is already being used by the chosen copy group"
+                            in str(e)
+                        ):
+                            shadow_image_data = (
+                                self.provisioner.get_specific_cg_pair_by_pvol_svol(
+                                    self.shadowImagePairSpec.pvol,
+                                    self.shadowImagePairSpec.svol,
+                                )
+                            )
+                            if shadow_image_data is not None:
+                                shadow_image_response = shadow_image_data.to_dict()
+                                self.connectionInfo.changed = False
+                        else:
+                            raise e
             elif state == StateValue.SPLIT:
                 if pairId is not None:
                     if (
@@ -252,7 +292,7 @@ class VSPShadowImagePairReconciler:
 
         shadow_image_response = (
             ShadowImagePairPropertyExtractor(self.serial).extract(
-                [shadow_image_response], self.port_type_dict
+                [shadow_image_response], self.get_port_type_dict()
             )[0]
             if isinstance(shadow_image_response, dict)
             else shadow_image_response
@@ -261,6 +301,10 @@ class VSPShadowImagePairReconciler:
 
     @log_entry_exit
     def shadow_image_pair_create(self, shadowImagePairSpec):
+        if shadowImagePairSpec.pvol is None:
+            raise ValueError(
+                "Primary volume ID (pvol) must be provided when creating a shadow image pair."
+            )
         data = self.provisioner.create_shadow_image_pair(
             self.serial, shadowImagePairSpec
         )
@@ -303,10 +347,18 @@ class VSPShadowImagePairReconciler:
 
     @log_entry_exit
     def get_shadow_image_pair_by_copy_pair_name(self, copy_pair_name, copy_group_name):
-        data = self.provisioner.get_shadow_image_pair_by_copy_pair_name(
-            self.serial, copy_pair_name, copy_group_name
-        )
-        return data
+        try:
+            pvol_device_grp_name = copy_group_name + "P_"
+            svol_device_grp_name = copy_group_name + "S_"
+            pair_id = f"{copy_group_name},{pvol_device_grp_name},{svol_device_grp_name},{copy_pair_name}"
+            data = self.provisioner.get_shadow_image_pair_by_id(self.serial, pair_id)
+            logger.writeDebug(f"20250324 data: {data}")
+            return data.to_dict()
+        except Exception as e:
+            data = self.provisioner.get_shadow_image_pair_by_copy_pair_name(
+                self.serial, copy_pair_name, copy_group_name
+            )
+            return data
 
     @log_entry_exit
     def shadow_image_pair_delete(self, shadowImagePairSpec):
@@ -318,25 +370,18 @@ class VSPShadowImagePairReconciler:
 
 class ShadowImagePairPropertyExtractor:
     def __init__(self, serial):
-        self.entitlement_properties = {
-            # "partner_id": str,
-            # "subscriber_id": str,
-            # "entitlement_status": str,
-        }
         self.common_properties = {
             # "resource_id": str,
             "consistency_group_id": int,
-            "copy_pace_track_size": str,
+            # "copy_pace_track_size": str,
             "copy_rate": int,
             "mirror_unit_id": int,
-            "primary_hex_volume_id": str,
+            "primary_volume_id_hex": str,
             "primary_volume_id": int,
             "storage_serial_number": str,
-            "secondary_hex_volume_id": str,
+            "secondary_volume_id_hex": str,
             "secondary_volume_id": int,
             "status": str,
-            "svol_access_mode": str,
-            # "type": str,
             "copy_group_name": str,
             "copy_pair_name": str,
             "pvol_nvm_subsystem_name": str,
@@ -350,18 +395,6 @@ class ShadowImagePairPropertyExtractor:
         new_items = []
         for response in responses:
             new_dict = {"storage_serial_number": self.serial}
-            for key, value_type in self.entitlement_properties.items():
-                # Assign the value based on the response key and its data type
-                cased_key = snake_to_camel_case(key)
-                # Get the corresponding key from the response or its mapped key
-                response_key = response.get(cased_key)
-
-                if response_key is not None:
-                    new_dict[key] = value_type(response_key)
-                else:
-                    # Handle missing keys by assigning default values
-                    default_value = get_default_value(value_type)
-                    new_dict[key] = default_value
 
             for key, value_type in self.common_properties.items():
                 # Assign the value based on the response key and its data type
@@ -378,10 +411,10 @@ class ShadowImagePairPropertyExtractor:
                     new_dict[key] = default_value
 
                 if value_type == list and response_key:
-                    logger.writeDebug(f"20250324 key: {key}")
-                    logger.writeDebug(f"20250324 response_key: {response_key}")
+                    # logger.writeDebug(f"20250324 key: {key}")
+                    # logger.writeDebug(f"20250324 response_key: {response_key}")
                     new_dict[key] = self.process_list(response_key)
-                    logger.writeDebug(f"20250324 new_dict[key]: {new_dict[key]}")
+                    # logger.writeDebug(f"20250324 new_dict[key]: {new_dict[key]}")
 
             if new_dict.get("pvol_host_groups"):
                 self.split_host_groups(
@@ -399,12 +432,12 @@ class ShadowImagePairPropertyExtractor:
                     port_type_dict,
                 )
                 # del new_dict["svolHostGroups"]
-            if new_dict.get("primary_hex_volume_id") == "":
-                new_dict["primary_hex_volume_id"] = volume_id_to_hex_format(
+            if new_dict.get("primary_volume_id_hex") == "":
+                new_dict["primary_volume_id_hex"] = volume_id_to_hex_format(
                     new_dict.get("primary_volume_id")
                 )
-            if new_dict.get("secondary_hex_volume_id") == "":
-                new_dict["secondary_hex_volume_id"] = volume_id_to_hex_format(
+            if new_dict.get("secondary_volume_id_hex") == "":
+                new_dict["secondary_volume_id_hex"] = volume_id_to_hex_format(
                     new_dict.get("secondary_volume_id")
                 )
             new_items.append(new_dict)
@@ -412,8 +445,8 @@ class ShadowImagePairPropertyExtractor:
 
     def split_host_groups(self, items, new_dict, key, port_type_dict):
         logger = Log()
-        logger.writeDebug(f"20250324 key: {key}")
-        logger.writeDebug(f"20250324 items: {items}")
+        # logger.writeDebug(f"20250324 key: {key}")
+        # logger.writeDebug(f"20250324 items: {items}")
         if items is None:
             return
 
@@ -425,15 +458,12 @@ class ShadowImagePairPropertyExtractor:
             # logger.writeDebug(f"20250324 item: {item}")
             port_id = item["port_id"]
             port_type = port_type_dict[port_id]
-            logger.writeDebug(f"20250324 port_id: {port_id}")
-            logger.writeDebug(f"20250324 port_type: {port_type}")
+            # logger.writeDebug(f"20250324 port_id: {port_id}")
+            # logger.writeDebug(f"20250324 port_type: {port_type}")
             if port_type == "ISCSI":
                 its.append(item)
             else:
                 hgs.append(item)
-            # if self.port_type_dict[item[]]
-            # new_dict["pvol_host_groups"] = items
-            # new_dict["pvol_iscsi_targets"] = items
 
         if key == "pvolHostGroups":
             new_dict["pvol_iscsi_targets"] = its
@@ -447,18 +477,6 @@ class ShadowImagePairPropertyExtractor:
     def extract_object(self, response):
 
         new_dict = {"storage_serial_number": self.serial}
-        for key, value_type in self.entitlement_properties.items():
-            # Assign the value based on the response key and its data type
-            cased_key = snake_to_camel_case(key)
-            # Get the corresponding key from the response or its mapped key
-            response_key = response.get(cased_key)
-
-            if response_key is not None:
-                new_dict[key] = value_type(response_key)
-            else:
-                # Handle missing keys by assigning default values
-                default_value = get_default_value(value_type)
-                new_dict[key] = default_value
         for key, value_type in self.common_properties.items():
             # Assign the value based on the response key and its data type
             cased_key = snake_to_camel_case(key)
@@ -472,12 +490,12 @@ class ShadowImagePairPropertyExtractor:
                 default_value = get_default_value(value_type)
                 new_dict[key] = default_value
 
-        if new_dict.get("primary_hex_volume_id") == "":
-            new_dict["primary_hex_volume_id"] = volume_id_to_hex_format(
+        if new_dict.get("primary_volume_id_hex") == "":
+            new_dict["primary_volume_id_hex"] = volume_id_to_hex_format(
                 new_dict.get("primary_volume_id")
             )
-        if new_dict.get("secondary_hex_volume_id") == "":
-            new_dict["secondary_hex_volume_id"] = volume_id_to_hex_format(
+        if new_dict.get("secondary_volume_id_hex") == "":
+            new_dict["secondary_volume_id_hex"] = volume_id_to_hex_format(
                 new_dict.get("secondary_volume_id")
             )
         return new_dict
