@@ -11,9 +11,9 @@ __metaclass__ = type
 DOCUMENTATION = """
 ---
 module: hv_external_path_group_facts
-short_description: Retrieves information about External Path Group from Hitachi VSP storage systems.
+short_description: Retrieves information about External Path Group from VSP block storage systems.
 description:
-  - This module retrieves information about External Volume from Hitachi VSP storage systems.
+  - This module retrieves information about External Volume from VSP block storage systems.
   - For examples, go to URL
     U(https://github.com/hitachi-vantara/vspone-block-ansible/blob/main/playbooks/vsp_direct/external_path_group_facts.yml)
 version_added: '3.5.0'
