@@ -10,9 +10,9 @@ __metaclass__ = type
 DOCUMENTATION = """
 ---
 module: hv_nvm_subsystems
-short_description: Manages NVM subsystems on Hitachi VSP storage systems.
+short_description: Manages NVM subsystems on VSP block storage systems.
 description:
-  - This module allows creation, deletion, and other operations on NVM subsystems on Hitachi VSP storage systems.
+  - This module allows creation, deletion, and other operations on NVM subsystems on VSP block storage systems.
   - For examples go to URL
     U(https://github.com/hitachi-vantara/vspone-block-ansible/blob/main/playbooks/vsp_direct/nvm_subsystems.yml)
 version_added: '3.2.0'
@@ -134,7 +134,7 @@ options:
         required: false
         suboptions:
           ldev_id:
-            description: The LDEV ID of the namespace.
+            description: The LDEV ID of the namespace. Can be decimal or hexadecimal.
               Required for the Create an NVM Subsystem with a specific ID
               /Create an NVM Subsystem with a free ID
               /Add namespaces and namespace paths to an NVM Subsystem with a specific ID
@@ -259,46 +259,46 @@ EXAMPLES = """
 RETURN = """
 nvm_subsystems:
   description: The NVM subsystem information.
-  returned: always
   type: list
   elements: dict
+  returned: success
   contains:
     storage_serial_number:
       description: The serial number of the storage system.
       type: str
-      sample: "810005"
+      sample: "810045"
     host_nqn_info:
-      description: List of host NQNs and their nicknames.
+      description: List of host NQN information.
       type: list
       elements: dict
       contains:
         host_nqn:
-          description: The host NQN.
+          description: Host NQN.
           type: str
-          sample: "nqn.2014-08.org.example:uuid:4b73e622-ddc1-449a-99f7-412c0d3baa40"
+          sample: "nqn.2014-08.com.ucpa-sc-hv:nvme:scpodl-esxi235"
         host_nqn_nickname:
-          description: The nickname of the host NQN.
+          description: Nickname for the host NQN.
           type: str
-          sample: "my_host_nqn_40"
+          sample: ""
     namespace_paths_info:
       description: List of namespace paths information.
       type: list
       elements: dict
       contains:
         host_nqn:
-          description: The host NQN.
+          description: Host NQN.
           type: str
-          sample: "nqn.2014-08.org.example:uuid:4b73e622-ddc1-449a-99f7-412c0d3baa40"
+          sample: "nqn.2014-08.com.ucpa-sc-hv:nvme:scpodl-esxi235"
         ldev_id:
-          description: The LDEV ID of the namespace.
+          description: Logical device ID.
           type: int
-          sample: 11101
-        ldev_hex_id:
-          description: The hexadecimal ID of the LDEV.
+          sample: 5555
+        ldev_id_hex:
+          description: Logical device hex ID.
           type: str
-          sample: "00:2b:5c"
+          sample: "00:15:B3"
         namespace_id:
-          description: The ID of the namespace.
+          description: Namespace ID.
           type: int
           sample: 3
     namespaces_info:
@@ -307,68 +307,72 @@ nvm_subsystems:
       elements: dict
       contains:
         block_capacity:
-          description: The block capacity of the namespace.
+          description: Block capacity of the namespace.
           type: int
-          sample: 23068672
+          sample: 20971520
+        capacity_in_mb:
+          description: Capacity in MB.
+          type: float
+          sample: 10240.0
         capacity_in_unit:
-          description: The capacity of the namespace in human-readable format.
+          description: Capacity in human-readable unit.
           type: str
-          sample: "11.00 G"
+          sample: "10.00GB"
         ldev_id:
-          description: The LDEV ID of the namespace.
+          description: Logical device ID.
           type: int
-          sample: 11101
+          sample: 2000
         ldev_id_hex:
-          description: The hexadecimal ID of the LDEV.
+          description: Logical device hex ID.
           type: str
-          sample: "00:2B:5C"
+          sample: "00:07:D0"
         namespace_id:
-          description: The ID of the namespace.
+          description: Namespace ID.
           type: int
-          sample: 3
+          sample: 2
         namespace_nickname:
-          description: The nickname of the namespace.
+          description: Nickname for the namespace.
           type: str
-          sample: "nickname"
+          sample: ""
     nvm_subsystem_info:
       description: Information about the NVM subsystem.
       type: dict
       contains:
         host_mode:
-          description: The host mode of the NVM subsystem.
+          description: Host mode.
           type: str
           sample: "VMWARE_EX"
         namespace_security_setting:
-          description: The namespace security setting.
+          description: Namespace security setting.
           type: str
           sample: "Enable"
         nvm_subsystem_id:
-          description: The ID of the NVM subsystem.
+          description: NVM subsystem ID.
           type: int
-          sample: 1000
+          sample: 1
         nvm_subsystem_name:
-          description: The name of the NVM subsystem.
+          description: NVM subsystem name.
           type: str
-          sample: "nvm_tcp_01"
+          sample: "NVME-TCP-CL1-D-01"
         resource_group_id:
-          description: The resource group ID of the NVM subsystem.
+          description: Resource group ID.
           type: int
-          sample: 0
+          sample: 8
         t10pi_mode:
-          description: The T10PI mode of the NVM subsystem.
+          description: T10PI mode.
           type: str
           sample: "Disable"
-    port:
-      description: List of ports of the NVM subsystem.
+    port_info:
+      description: List of port information.
       type: list
       elements: dict
       contains:
         port_id:
-          description: The ID of the port.
+          description: Port ID.
           type: str
           sample: "CL1-D"
         port_type:
-          description: The type of the port.
+          description: Port type.
           type: str
           sample: "NVME_TCP"
 """
