@@ -11,7 +11,7 @@ __metaclass__ = type
 DOCUMENTATION = """
 ---
 module: hv_truecopy
-short_description: Manages TrueCopy pairs on Hitachi VSP storage systems.
+short_description: Manages TrueCopy pairs on VSP block storage systems.
 description:
   - This module allows for the creation, deletion, splitting, re-syncing and resizing of TrueCopy pairs.
   - It also allows swap-splitting and swap-resyncing operations of TrueCopy pairs.
@@ -22,16 +22,16 @@ version_added: '3.1.0'
 author:
   - Hitachi Vantara LTD (@hitachi-vantara)
 requirements:
-  - python >= 3.8
+  - python >= 3.9
 attributes:
   check_mode:
     description: Determines if the module should run in check mode.
     support: none
 extends_documentation_fragment:
 - hitachivantara.vspone_block.common.gateway_note
+- hitachivantara.vspone_block.common.connection_with_type
+- hitachivantara.vspone_block.common.true_copy_note
 notes:
-  - The input parameters C(allocate_new_consistency_group), C(begin_secondary_volume_id) and C(end_secondary_volume_id) were removed in version 3.4.0.
-    They were deprecated due to internal API simplification and are no longer supported.
   - The output parameters C(entitlement_status), C(subscriber_id), and C(partner_id) were removed in version 3.4.0.
     They were also deprecated due to internal API simplification and are no longer supported.
 options:
@@ -69,44 +69,17 @@ options:
         type: str
         required: true
       username:
-        description: Username for authentication. This is a required field.
+        description: Username for authentication. This is a required field if api_token is not provided.
         type: str
         required: false
       password:
-        description: Password for authentication. This is a required field.
+        description: Password for authentication.This is a required field if api_token is not provided.
         type: str
         required: false
       api_token:
         description: This field is used to pass the value of the lock token of the secondary storage to operate on locked resources.
         type: str
         required: false
-  connection_info:
-    description: Information required to establish a connection to the storage system.
-    type: dict
-    required: true
-    suboptions:
-      address:
-        description: IP address or hostname of the storage system.
-        type: str
-        required: true
-      username:
-        description: Username for authentication. This is a required field.
-        type: str
-        required: false
-      password:
-        description: Password for authentication. This is a required field.
-        type: str
-        required: false
-      api_token:
-        description: This field is used to pass the value of the lock token to operate on locked resources.
-        type: str
-        required: false
-      connection_type:
-        description: Type of connection to the storage system.
-        type: str
-        required: false
-        choices: ['direct']
-        default: 'direct'
   spec:
     description: Specification for the TrueCopy pairs task.
     type: dict
@@ -115,11 +88,34 @@ options:
       copy_group_name:
         description: Name of the copy group. This is a required field for create operation.
           For other operations, this field is optional, but when provided, the time to complete the operation is faster.
+          Required for the Split TrueCopy pair by copy_group_name and primary volume ID
+          /Resync TrueCopy pair by copy_group_name and copy_pair_name
+          /Resync TrueCopy pair
+          /Resync TrueCopy pair by copy_group_name and primary volume ID
+          /Swap-Split TrueCopy pair by copy_group_name and copy_pair_name
+          /Swap-Split TrueCopy pair
+          /Swap-Split TrueCopy pair by copy_group_name and primary volume ID
+          /Swap-Resync TrueCopy pair by copy_group_name and copy_pair_name
+          /Swap-Resync TrueCopy pair
+          /Swap-Resync TrueCopy pair by copy_group_name and primary volume ID
+          /Delete TrueCopy pair by copy_group_name and copy_pair_name
+          /Delete TrueCopy pair
+          /Delete TrueCopy pair by copy_group_name and primary volume ID
+          /Expand TrueCopy pair tasks.
         type: str
         required: false
       copy_pair_name:
         description: Name of the copy pair. This is a required field for create operation.
           For other operations, this field is optional, but when provided, the time to complete the operation is faster.
+          Required for the Resync TrueCopy pair by copy_group_name and copy_pair_name
+          /Resync TrueCopy pair
+          /Swap-Split TrueCopy pair by copy_group_name and copy_pair_name
+          /Swap-Split TrueCopy pair
+          /Swap-Resync TrueCopy pair by copy_group_name and copy_pair_name
+          /Swap-Resync TrueCopy pair
+          /Delete TrueCopy pair by copy_group_name and copy_pair_name
+          /Delete TrueCopy pair
+          /Expand TrueCopy pair tasks.
         type: str
         required: false
       remote_device_group_name:
@@ -132,7 +128,12 @@ options:
         required: false
       primary_volume_id:
         description: Primary volume ID. This is a required field for create operation.
-        type: int
+          Required for the Split TrueCopy pair by copy_group_name and primary volume ID
+          /Resync TrueCopy pair by copy_group_name and primary volume ID
+          /Swap-Split TrueCopy pair by copy_group_name and primary volume ID
+          /Swap-Resync TrueCopy pair by copy_group_name and primary volume ID
+          /Delete TrueCopy pair by copy_group_name and primary volume ID tasks.
+        type: str
         required: false
       consistency_group_id:
         description: Consistency Group ID, 0 to 255. This is an optional field.
@@ -147,21 +148,75 @@ options:
         default: 'NEVER'
       secondary_pool_id:
         description: ID of the dynamic pool where the secondary volume will be created.
+          Required for the Create a TrueCopy pair by specifying only the required fields
+          /Create a TC pair using a range for secondary volume ID
+          /Create a TrueCopy-NVMe pair by specifying only the required fields
+          /Create a TrueCopy-NVMe pair by specifying all the fields
+          /Create a TrueCopy-ISCSI pair by specifying only the required fields
+          /Create a TrueCopy-ISCSI pair by specifying all the fields tasks.
         type: int
         required: false
-      copy_pace:
-        description: Copy speed.
+      provisioned_secondary_volume_id:
+        description: ID of the provisioned secondary volume that you want to use for the true copy creation.
+          Required for the Create a TrueCopy pair with provisioned_secondary_volume_id
+          /Create a TrueCopy pair with provisioned_secondary_volume_id and hostgroups tasks.
         type: str
         required: false
+      begin_secondary_volume_id:
+        description: >
+          Specify beginning ldev id for LDEV range for svol. This is an optional field during create operation.
+          If this field is specified, end_secondary_volume_id must also be specified.
+          If this field is not specified, Ansible modules will try to create SVOL ID same as the PVOL ID if available,
+          otherwise it will use the first available LDEV ID.
+        required: false
+        type: str
+      end_secondary_volume_id:
+        description: >
+          Specify end ldev id for LDEV range for svol. This is an optional field during create operation.
+          If this field is specified, begin_secondary_volume_id must also be specified.
+          If this field is not specified, Ansible modules will try to create SVOL ID same as PVOL ID iff available,
+          otherwise it will use the first available LDEV ID.
+        required: false
+        type: str
+      copy_pace:
+        description: Copy speed.
+          This is optional for the create operation.
+        type: str
+        required: false
+        choices: ['SLOW', 'MEDIUM', 'FAST']
+        default: 'MEDIUM'
       is_svol_readwriteable:
         description: It is applicable for split pair operation only. If true, the secondary volume will be read-writeable after split.
+          Optional for the Split TrueCopy pair by specifying only the required fields
+          /Split TrueCopy pair tasks.
         type: bool
         required: false
         default: false
       secondary_hostgroup:
         description: Host group details of the secondary volume.
+          Required for the Create a TrueCopy pair by specifying only the required fields
+          /Create a TrueCopy pair with provisioned_secondary_volume_id and hostgroups
+          /Create a TC pair using a range for secondary volume ID tasks.
         type: dict
         required: false
+        suboptions:
+          name:
+            description: Name of the host group on the secondary storage system. This is required for create operation.
+            type: str
+            required: true
+          port:
+            description: Port of the host group on the secondary storage system. This is required for create operation.
+            type: str
+            required: true
+          lun_id:
+            description: LUN ID of the host group on the secondary storage system. This is required for create operation.
+            type: int
+            required: false
+      secondary_hostgroups:
+        description: List of hostgroup objects for the secondary volume.
+        type: list
+        elements: dict
+        required: false
         suboptions:
           name:
             description: Name of the host group on the secondary storage system. This is required for create operation.
@@ -177,33 +232,47 @@ options:
             required: false
       secondary_iscsi_targets:
         description: The list of iscsi targets on the secondary storage device.
+          Required for the Create a TrueCopy-ISCSI pair by specifying only the required fields
+          /Create a TrueCopy-ISCSI pair by specifying all the fields tasks.
         type: list
         elements: dict
         required: false
         suboptions:
           name:
             description: ISCSI target name.
+              Required for the Create a TrueCopy-ISCSI pair by specifying only the required fields
+              /Create a TrueCopy-ISCSI pair by specifying all the fields tasks.
             type: str
             required: true
           port:
             description: Port name.
+              Required for the Create a TrueCopy-ISCSI pair by specifying only the required fields
+              /Create a TrueCopy-ISCSI pair by specifying all the fields tasks.
             type: str
             required: true
           lun_id:
             description: LUN ID.
+              Required for the Create a TrueCopy-ISCSI pair by specifying only the required fields
+              /Create a TrueCopy-ISCSI pair by specifying all the fields tasks.
             type: int
             required: false
       secondary_nvm_subsystem:
         description: NVM subsystem details of the secondary volume.
+          Required for the Create a TrueCopy-NVMe pair by specifying only the required fields
+          /Create a TrueCopy-NVMe pair by specifying all the fields tasks.
         type: dict
         required: false
         suboptions:
           name:
-            description: Name of the NVM subsytem on the secondary storage system.
+            description: Name of the NVM subsystem on the secondary storage system.
+              Required for the Create a TrueCopy-NVMe pair by specifying only the required fields
+              /Create a TrueCopy-NVMe pair by specifying all the fields tasks.
             type: str
             required: true
           paths:
             description: Host NQN paths information on the secondary storage system.
+              Required for the Create a TrueCopy-NVMe pair by specifying only the required fields
+              /Create a TrueCopy-NVMe pair by specifying all the fields tasks.
             type: list
             elements: str
             required: false
@@ -230,13 +299,9 @@ options:
         type: int
         required: false
       new_volume_size:
-        description: Required only for resize or expand operation. Value should be grater than the current volume size.
+        description: Required only for resize or expand operation. Value should be greater than the current volume size.
         type: str
         required: false
-      secondary_volume_id:
-        description: Secondary volume id.
-        type: int
-        required: false
       is_consistency_group:
         description: >
           This is an optional field during create operation.
@@ -247,6 +312,7 @@ options:
         default: false
       should_delete_svol:
         description: Specify true to delete the SVOL.
+          Optional for the Delete TrueCopy pair task.
         type: bool
         required: false
         default: false
@@ -369,10 +435,11 @@ EXAMPLES = """
 """
 
 RETURN = r"""
-data:
-  description: Newly created TrueCopy pair object for direct connection.
+truecopy_info:
+  description: List of TrueCopy pair objects returned by the module.
   returned: success
-  type: dict
+  type: list
+  elements: dict
   contains:
     consistency_group_id:
       description: Consistency Group ID.
@@ -381,11 +448,11 @@ data:
     copy_group_name:
       description: Name of the copy group.
       type: str
-      sample: "TC_TEST_1107"
+      sample: "ESD_TC_CG"
     copy_pair_name:
       description: Name of the copy pair.
       type: str
-      sample: "rd_copy_pair_202"
+      sample: "ESD_TC_CP"
     copy_progress_rate:
       description: Copy progress rate.
       type: int
@@ -394,18 +461,14 @@ data:
       description: Fence level.
       type: str
       sample: "NEVER"
-    primary_hex_volume_id:
-      description: Primary hex volume ID.
-      type: str
-      sample: "00:02:77"
-    primary_or_secondary:
-      description: Primary or secondary.
-      type: str
-      sample: ""
     primary_volume_id:
       description: Primary volume ID.
       type: int
-      sample: 631
+      sample: 11
+    primary_volume_id_hex:
+      description: Primary volume ID in hex format.
+      type: str
+      sample: "00:00:0B"
     pvol_status:
       description: PVOL status.
       type: str
@@ -413,31 +476,23 @@ data:
     pvol_storage_device_id:
       description: PVOL storage device ID.
       type: str
-      sample: "A34000810045"
+      sample: "A00000970041"
     remote_mirror_copy_pair_id:
       description: Remote mirror copy pair ID.
       type: str
-      sample: "A34000810045,TC_TEST_1107,TC_TEST_1107P_,TC_TEST_1107S_,rd_copy_pair_202"
-    secondary_hex_volume_id:
-      description: Secondary hex volume ID.
-      type: str
-      sample: "00:00:ca"
+      sample: "A00000970045,ESD_TC_CG,ESD_TC_CGP_,ESD_TC_CGS_,ESD_TC_CP"
     secondary_volume_id:
       description: Secondary volume ID.
       type: int
-      sample: 202
-    status:
-      description: Status.
+      sample: 11
+    secondary_volume_id_hex:
+      description: Secondary volume ID in hex format.
       type: str
-      sample: ""
+      sample: "00:00:0B"
     storage_serial_number:
       description: Storage serial number.
       type: str
-      sample: "810050"
-    svol_access_mode:
-      description: SVOL access mode.
-      type: str
-      sample: ""
+      sample: "70041"
     svol_status:
       description: SVOL status.
       type: str
@@ -445,7 +500,7 @@ data:
     svol_storage_device_id:
       description: SVOL storage device ID.
       type: str
-      sample: "A34000810050"
+      sample: "A00000970045"
 """
 
 from ansible.module_utils.basic import AnsibleModule
@@ -495,9 +550,7 @@ class VSPSTrueCopyManager:
         self.logger.writeInfo("=== Start of TrueCopy operation. ===")
         data = None
         registration_message = validate_ansible_product_registration()
-        self.logger.writeDebug(
-            f"{self.params_manager.connection_info.connection_type} connection type"
-        )
+
         self.logger.writeDebug("state = {}", self.state)
         try:
             data = self.true_copy_module()
