@@ -1,6 +1,6 @@
 #!/usr/bin/python
 
-# (c) 2018-2022, NetApp, Inc
+# (c) 2018-2025, NetApp, Inc
 # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 
 '''
@@ -16,7 +16,7 @@ short_description: NetApp ONTAP manage broadcast domains.
 extends_documentation_fragment:
     - netapp.ontap.netapp.na_ontap
 version_added: 2.6.0
-author: NetApp Ansible Team (@carchi8py) <ng-ansibleteam@netapp.com>
+author: NetApp Ansible Team (@carchi8py) <ng-ansible-team@netapp.com>
 description:
   - Modify a ONTAP broadcast domain.
 options:
@@ -74,110 +74,110 @@ options:
 '''
 
 EXAMPLES = """
-    - name: create broadcast domain
-      netapp.ontap.na_ontap_broadcast_domain:
-        state: present
-        username: "{{ netapp_username }}"
-        password: "{{ netapp_password }}"
-        hostname: "{{ netapp_hostname }}"
-        name: ansible_domain
-        mtu: 1000
-        ipspace: Default
-        ports: ["khutton-vsim1:e0d-12", "khutton-vsim1:e0d-13"]
-    - name: modify broadcast domain
-      netapp.ontap.na_ontap_broadcast_domain:
-        state: present
-        username: "{{ netapp_username }}"
-        password: "{{ netapp_password }}"
-        hostname: "{{ netapp_hostname }}"
-        name: ansible_domain
-        mtu: 1100
-        ipspace: Default
-        ports: ["khutton-vsim1:e0d-12", "khutton-vsim1:e0d-13"]
-    - name: split broadcast domain
-      netapp.ontap.na_ontap_broadcast_domain:
-        state: present
-        username: "{{ netapp_username }}"
-        password: "{{ netapp_password }}"
-        hostname: "{{ netapp_hostname }}"
-        from_name: ansible_domain
-        name: new_ansible_domain
-        mtu: 1200
-        ipspace: Default
-        ports: khutton-vsim1:e0d-12
-    - name: delete broadcast domain
-      netapp.ontap.na_ontap_broadcast_domain:
-        state: absent
-        username: "{{ netapp_username }}"
-        password: "{{ netapp_password }}"
-        hostname: "{{ netapp_hostname }}"
-        name: ansible_domain
-        ipspace: Default
-    - name: create broadcast domain REST
-      netapp.ontap.na_ontap_broadcast_domain:
-        state: present
-        username: "{{ netapp_username }}"
-        password: "{{ netapp_password }}"
-        hostname: "{{ netapp_hostname }}"
-        name: ansible_domain
-        mtu: 1200
-        ipspace: Default
-        ports: ["khutton-vsim1:e0d-12","khutton-vsim1:e0d-13","khutton-vsim1:e0d-14"]
-    - name: rename broadcast domain if exact match of ports REST
-      netapp.ontap.na_ontap_broadcast_domain:
-        state: present
-        username: "{{ netapp_username }}"
-        password: "{{ netapp_password }}"
-        hostname: "{{ netapp_hostname }}"
-        from_name: ansible_domain
-        name: new_ansible_domain
-        mtu: 1200
-        ipspace: Default
-        ports: ["khutton-vsim1:e0d-12","khutton-vsim1:e0d-13","khutton-vsim1:e0d-14"]
-    - name: if partial match, remove e0d-12 from new_ansible_domain & create new domain ansible_domain with port e0d-12 REST
-      netapp.ontap.na_ontap_broadcast_domain:
-        state: present
-        username: "{{ netapp_username }}"
-        password: "{{ netapp_password }}"
-        hostname: "{{ netapp_hostname }}"
-        from_name: new_ansible_domain
-        name: ansible_domain
-        mtu: 1200
-        ipspace: Default
-        ports: ["khutton-vsim1:e0d-12"]
-    - name: Modify both broadcast domain and ipspace REST.
-      netapp.ontap.na_ontap_broadcast_domain:
-        state: present
-        username: "{{ netapp_username }}"
-        password: "{{ netapp_password }}"
-        hostname: "{{ netapp_hostname }}"
-        from_name: ansible_domain
-        from_ipspace: Default
-        name: ansible_domain_ip1
-        ipspace: ipspace_1
-        mtu: 1200
-        ports: ["khutton-vsim1:e0d-12"]
-    - name: Modify ipspace only REST.
-      netapp.ontap.na_ontap_broadcast_domain:
-        state: present
-        username: "{{ netapp_username }}"
-        password: "{{ netapp_password }}"
-        hostname: "{{ netapp_hostname }}"
-        from_ipspace: ipspace_1
-        name: ansible_domain_ip1
-        ipspace: Default
-        mtu: 1200
-        ports: ["khutton-vsim1:e0d-12"]
-    - name: delete broadcast domain new_ansible_domain.
-      netapp.ontap.na_ontap_broadcast_domain:
-        state: absent
-        username: "{{ netapp_username }}"
-        password: "{{ netapp_password }}"
-        hostname: "{{ netapp_hostname }}"
-        name: new_ansible_domain
-        mtu: 1200
-        ipspace: Default
-        ports: ["khutton-vsim1:e0d-13","khutton-vsim1:e0d-14"]
+- name: Create broadcast domain
+  netapp.ontap.na_ontap_broadcast_domain:
+    state: present
+    username: "{{ netapp_username }}"
+    password: "{{ netapp_password }}"
+    hostname: "{{ netapp_hostname }}"
+    name: ansible_domain
+    mtu: 1000
+    ipspace: Default
+    ports: ["khutton-vsim1:e0d-12", "khutton-vsim1:e0d-13"]
+- name: Modify broadcast domain
+  netapp.ontap.na_ontap_broadcast_domain:
+    state: present
+    username: "{{ netapp_username }}"
+    password: "{{ netapp_password }}"
+    hostname: "{{ netapp_hostname }}"
+    name: ansible_domain
+    mtu: 1100
+    ipspace: Default
+    ports: ["khutton-vsim1:e0d-12", "khutton-vsim1:e0d-13"]
+- name: Split broadcast domain
+  netapp.ontap.na_ontap_broadcast_domain:
+    state: present
+    username: "{{ netapp_username }}"
+    password: "{{ netapp_password }}"
+    hostname: "{{ netapp_hostname }}"
+    from_name: ansible_domain
+    name: new_ansible_domain
+    mtu: 1200
+    ipspace: Default
+    ports: khutton-vsim1:e0d-12
+- name: Delete broadcast domain
+  netapp.ontap.na_ontap_broadcast_domain:
+    state: absent
+    username: "{{ netapp_username }}"
+    password: "{{ netapp_password }}"
+    hostname: "{{ netapp_hostname }}"
+    name: ansible_domain
+    ipspace: Default
+- name: Create broadcast domain REST
+  netapp.ontap.na_ontap_broadcast_domain:
+    state: present
+    username: "{{ netapp_username }}"
+    password: "{{ netapp_password }}"
+    hostname: "{{ netapp_hostname }}"
+    name: ansible_domain
+    mtu: 1200
+    ipspace: Default
+    ports: ["khutton-vsim1:e0d-12", "khutton-vsim1:e0d-13", "khutton-vsim1:e0d-14"]
+- name: Rename broadcast domain if exact match of ports REST
+  netapp.ontap.na_ontap_broadcast_domain:
+    state: present
+    username: "{{ netapp_username }}"
+    password: "{{ netapp_password }}"
+    hostname: "{{ netapp_hostname }}"
+    from_name: ansible_domain
+    name: new_ansible_domain
+    mtu: 1200
+    ipspace: Default
+    ports: ["khutton-vsim1:e0d-12", "khutton-vsim1:e0d-13", "khutton-vsim1:e0d-14"]
+- name: If partial match, remove e0d-12 from new_ansible_domain & create new domain ansible_domain with port e0d-12 REST
+  netapp.ontap.na_ontap_broadcast_domain:
+    state: present
+    username: "{{ netapp_username }}"
+    password: "{{ netapp_password }}"
+    hostname: "{{ netapp_hostname }}"
+    from_name: new_ansible_domain
+    name: ansible_domain
+    mtu: 1200
+    ipspace: Default
+    ports: ["khutton-vsim1:e0d-12"]
+- name: Modify both broadcast domain and ipspace REST.
+  netapp.ontap.na_ontap_broadcast_domain:
+    state: present
+    username: "{{ netapp_username }}"
+    password: "{{ netapp_password }}"
+    hostname: "{{ netapp_hostname }}"
+    from_name: ansible_domain
+    from_ipspace: Default
+    name: ansible_domain_ip1
+    ipspace: ipspace_1
+    mtu: 1200
+    ports: ["khutton-vsim1:e0d-12"]
+- name: Modify ipspace only REST.
+  netapp.ontap.na_ontap_broadcast_domain:
+    state: present
+    username: "{{ netapp_username }}"
+    password: "{{ netapp_password }}"
+    hostname: "{{ netapp_hostname }}"
+    from_ipspace: ipspace_1
+    name: ansible_domain_ip1
+    ipspace: Default
+    mtu: 1200
+    ports: ["khutton-vsim1:e0d-12"]
+- name: Delete broadcast domain new_ansible_domain.
+  netapp.ontap.na_ontap_broadcast_domain:
+    state: absent
+    username: "{{ netapp_username }}"
+    password: "{{ netapp_password }}"
+    hostname: "{{ netapp_hostname }}"
+    name: new_ansible_domain
+    mtu: 1200
+    ipspace: Default
+    ports: ["khutton-vsim1:e0d-13", "khutton-vsim1:e0d-14"]
 """
 
 RETURN = """
@@ -618,16 +618,15 @@ class NetAppOntapBroadcastDomain(object):
         if error:
             self.module.fail_json(msg=error)
         if record:
-            current = {'uuid': record['uuid'], 'name': record['name']}
+            current = {'uuid': record['uuid'], 'name': record['name'], 'node': record['node']}
             return current
         return None
 
     def ports_to_add_move_from_desired(self, ports):
         ports_to_add_move = []
         for port in ports:
-            port_name = port.split(':')[1]
             for port_to_add_or_move in self.desired_ports:
-                if port_name == port_to_add_or_move['name']:
+                if port == port_to_add_or_move['node']['name'] + ':' + port_to_add_or_move['name']:
                     ports_to_add_move.append({'uuid': port_to_add_or_move['uuid']})
         return ports_to_add_move
 
