@@ -39,6 +39,9 @@ API_APPS_ENDPOINTS = dict(
         "providers": {},
         "provider_networks": {},
     },
+    core={
+        "data_sources": {},
+    },
     dcim={
         "cables": {},
         "console_ports": {},
@@ -58,6 +61,8 @@ API_APPS_ENDPOINTS = dict(
         "inventory_item_roles": {},
         "locations": {},
         "manufacturers": {},
+        "modules": {},
+        "module_bays": {},
         "module_types": {},
         "platforms": {},
         "power_feeds": {},
@@ -76,12 +81,14 @@ API_APPS_ENDPOINTS = dict(
         "sites": {},
         "site_groups": {},
         "virtual_chassis": {},
+        "mac_addresses": {},
     },
     extras={
         "config_contexts": {},
         "config_templates": {},
         "tags": {},
         "custom_fields": {},
+        "custom_field_choice_sets": {},
         "custom_links": {},
         "export_templates": {},
         "journal_entries": {},
@@ -110,9 +117,16 @@ API_APPS_ENDPOINTS = dict(
         "tenants": {},
         "tenant_groups": {},
         "contacts": {},
+        "contact_assignments": {},
         "contact_groups": {},
         "contact_roles": {},
     },
+    users={
+        "groups": {},
+        "permissions": {},
+        "tokens": {},
+        "users": {},
+    },
     virtualization={
         "cluster_groups": {},
         "cluster_types": {},
@@ -128,6 +142,9 @@ API_APPS_ENDPOINTS = dict(
     vpn={
         "l2vpns": {"introduced": "3.7"},
         "l2vpn_terminations": {"introduced": "3.7"},
+        "tunnels": {"introduced": "3.7"},
+        "tunnel_groups": {"introduced": "3.7"},
+        "ipsec_profiles": {"introduced": "3.7"},
     },
 )
 
@@ -142,9 +159,10 @@ QUERY_TYPES = dict(
     cluster_type="slug",
     config_context="name",
     config_template="name",
-    contact_group="name",
+    contact_groups="name",
     contact_role="name",
     custom_field="name",
+    choice_set="name",
     custom_link="name",
     device="name",
     device_role="slug",
@@ -154,6 +172,7 @@ QUERY_TYPES = dict(
     fhrp_groups="group_id",
     fhrp_group_assignments="id",
     group="slug",
+    groups="name",
     installed_device="name",
     inventory_item_role="name",
     import_targets="name",
@@ -161,6 +180,8 @@ QUERY_TYPES = dict(
     l2vpn_termination="id",
     location="slug",
     manufacturer="slug",
+    modules="id",
+    module_bays="name",
     module_type="model",
     nat_inside="address",
     nat_outside="address",
@@ -179,6 +200,7 @@ QUERY_TYPES = dict(
     primary_ip4="address",
     primary_ip6="address",
     oob_ip="address",
+    permissions="name",
     provider="slug",
     provider_network="name",
     rack="name",
@@ -195,7 +217,10 @@ QUERY_TYPES = dict(
     site_group="slug",
     tenant="slug",
     tenant_group="slug",
+    token="slug",
+    tunnel="name",
     time_zone="timezone",
+    user="username",
     virtual_chassis="name",
     virtual_machine="name",
     virtual_machine_role="slug",
@@ -206,6 +231,7 @@ QUERY_TYPES = dict(
     webhook="name",
     wireless_lan="ssid",
     wireless_lan_group="slug",
+    mac_address="mac_address",
 )
 
 # Specifies keys within data that need to be converted to ID and the endpoint to be used when queried
@@ -225,7 +251,9 @@ CONVERT_TO_ID = {
     "component": "interfaces",
     "config_context": "config_contexts",
     "config_template": "config_templates",
-    "contact_groups": "contact_groups",
+    "contact_group": "contact_groups",  # Netbox version <4.3
+    "contact_groups": "contact_groups",  # Netbox version >=4.3
+    "choice_set": "custom_field_choice_sets",
     "dcim.consoleport": "console_ports",
     "dcim.consoleserverport": "console_server_ports",
     "dcim.frontport": "front_ports",
@@ -241,6 +269,7 @@ CONVERT_TO_ID = {
     "device_types": "device_types",
     "export_targets": "route_targets",
     "group": "tenant_groups",
+    "groups": "groups",
     "import_targets": "route_targets",
     "installed_device": "devices",
     "interface": "interfaces",
@@ -250,10 +279,14 @@ CONVERT_TO_ID = {
     "inventory_item_role": "inventory_item_roles",
     "ip_addresses": "ip_addresses",
     "ipaddresses": "ip_addresses",
+    "ipsec_profile": "ipsec_profiles",
     "location": "locations",
     "lag": "interfaces",
+    "primary_mac_address": "mac_addresses",
     "manufacturer": "manufacturers",
     "master": "devices",
+    "module": "modules",
+    "module_bay": "module_bays",
     "module_type": "module_types",
     "nat_inside": "ip_addresses",
     "nat_outside": "ip_addresses",
@@ -267,6 +300,7 @@ CONVERT_TO_ID = {
     "parent_site_group": "site_groups",
     "parent_tenant_group": "tenant_groups",
     "parent_wireless_lan_group": "wireless_lan_groups",
+    "permissions": "permissions",
     "platforms": "platforms",
     "power_panel": "power_panels",
     "power_port": "power_ports",
@@ -304,7 +338,9 @@ CONVERT_TO_ID = {
     "tenant_groups": "tenant_groups",
     "termination_a": "interfaces",
     "termination_b": "interfaces",
+    "tunnel_group": "tunnel_groups",
     "untagged_vlan": "vlans",
+    "user": "users",
     "virtual_chassis": "virtual_chassis",
     "virtual_machine": "virtual_machines",
     "virtual_machine_role": "device_roles",
@@ -335,10 +371,13 @@ ENDPOINT_NAME_MAPPING = {
     "console_server_ports": "console_server_port",
     "console_server_port_templates": "console_server_port_template",
     "contacts": "contact",
+    "contact_assignments": "contact_assignment",
     "contact_groups": "contact_group",
     "contact_roles": "contact_role",
     "custom_fields": "custom_field",
+    "custom_field_choice_sets": "choice_set",
     "custom_links": "custom_link",
+    "data_sources": "data_source",
     "device_bays": "device_bay",
     "device_bay_templates": "device_bay_template",
     "devices": "device",
@@ -349,6 +388,7 @@ ENDPOINT_NAME_MAPPING = {
     "fhrp_group_assignments": "fhrp_group_assignment",
     "front_ports": "front_port",
     "front_port_templates": "front_port_template",
+    "groups": "user_group",
     "journal_entries": "journal_entry",
     "interfaces": "interface",
     "interface_templates": "interface_template",
@@ -359,7 +399,10 @@ ENDPOINT_NAME_MAPPING = {
     "l2vpn_terminations": "l2vpn_termination",
     "locations": "location",
     "manufacturers": "manufacturer",
+    "modules": "module",
+    "module_bays": "module_bay",
     "module_types": "module_type",
+    "permissions": "permission",
     "platforms": "platform",
     "power_feeds": "power_feed",
     "power_outlets": "power_outlet",
@@ -387,6 +430,10 @@ ENDPOINT_NAME_MAPPING = {
     "tags": "tags",
     "tenants": "tenant",
     "tenant_groups": "tenant_group",
+    "tokens": "token",
+    "tunnels": "tunnel",
+    "tunnel_groups": "tunnel_group",
+    "users": "user",
     "virtual_chassis": "virtual_chassis",
     "virtual_machines": "virtual_machine",
     "virtual_disks": "virtual_disk",
@@ -397,6 +444,7 @@ ENDPOINT_NAME_MAPPING = {
     "wireless_lans": "wireless_lan",
     "wireless_lan_groups": "wireless_lan_group",
     "wireless_links": "wireless_link",
+    "mac_addresses": "mac_address",
 }
 
 ALLOWED_QUERY_PARAMS = {
@@ -435,10 +483,14 @@ ALLOWED_QUERY_PARAMS = {
     "console_server_port": set(["name", "device"]),
     "console_server_port_template": set(["name", "device_type"]),
     "contact": set(["name", "group"]),
+    "contact_assignment": set(["object_type", "object_id", "contact", "role"]),
     "contact_group": set(["name"]),
     "contact_role": set(["name"]),
     "custom_field": set(["name"]),
+    "custom_field_choice_set": set(["name"]),
+    "choice_set": set(["name"]),
     "custom_link": set(["name"]),
+    "data_source": set(["name"]),
     "dcim.consoleport": set(["name", "device"]),
     "dcim.consoleserverport": set(["name", "device"]),
     "dcim.frontport": set(["name", "device", "rear_port"]),
@@ -477,18 +529,22 @@ ALLOWED_QUERY_PARAMS = {
     ),
     "lag": set(["name"]),
     "location": set(["name", "slug", "site"]),
+    "mac_address": set(["mac_address"]),
+    "module": set(["device", "module_bay", "module_type"]),
+    "module_bay": set(["device", "name"]),
     "module_type": set(["model"]),
     "manufacturer": set(["slug"]),
     "master": set(["name"]),
     "nat_inside": set(["vrf", "address"]),
     "parent_contact_group": set(["name"]),
-    "parent_location": set(["slug"]),
+    "parent_location": set(["slug", "name", "site"]),
     "parent_interface": set(["name"]),
     "parent_inventory_item": set(["name", "device"]),
     "parent_vm_interface": set(["name"]),
     "parent_region": set(["slug"]),
     "parent_site_group": set(["slug"]),
     "parent_tenant_group": set(["slug"]),
+    "permission": set(["name"]),
     "platform": set(["slug"]),
     "power_feed": set(["name", "power_panel"]),
     "power_outlet": set(["name", "device"]),
@@ -511,7 +567,17 @@ ALLOWED_QUERY_PARAMS = {
     "rir": set(["slug"]),
     "role": set(["slug"]),
     "route_target": set(["name"]),
-    "services": set(["device", "virtual_machine", "name", "port", "protocol"]),
+    "services": set(
+        [
+            "device",
+            "virtual_machine",
+            "name",
+            "port",
+            "protocol",
+            "parent_object_type",
+            "parent_object_id",
+        ]
+    ),
     "service_template": set(["name"]),
     "site": set(["slug", "name"]),
     "site_group": set(["slug"]),
@@ -521,6 +587,11 @@ ALLOWED_QUERY_PARAMS = {
     "tenant_group": set(["slug"]),
     "termination_a": set(["name", "device", "virtual_machine"]),
     "termination_b": set(["name", "device", "virtual_machine"]),
+    "token": set(["key"]),
+    "tunnel": set(["name"]),
+    "tunnel_group": set(["slug"]),
+    "user": set(["username", "password"]),
+    "user_group": set(["name"]),
     "untagged_vlan": set(["group", "name", "site", "vid", "vlan_group", "tenant"]),
     "virtual_chassis": set(["name", "master"]),
     "virtual_machine": set(["name", "cluster"]),
@@ -561,6 +632,7 @@ REQUIRED_ID_FIND = {
     "console_port_templates": set(["type"]),
     "console_server_ports": set(["type"]),
     "console_server_port_templates": set(["type"]),
+    "contact_assignments": set(["priority"]),
     "devices": set(["status", "face"]),
     "device_types": set(["subdevice_role"]),
     "front_ports": set(["type"]),
@@ -591,7 +663,8 @@ CONVERT_KEYS = {
     "cluster_type": "type",
     "cluster_group": "group",
     "component": "component_id",
-    "contact_group": "group",
+    "contact_group": "group",  # Netbox version <4.3
+    "contact_groups": "groups",  # Netbox version >=4.3
     "device_role": "role",
     "fhrp_group": "group",
     "inventory_item_role": "role",
@@ -614,6 +687,7 @@ CONVERT_KEYS = {
     "tenant_group": "group",
     "termination_a": "termination_a_id",
     "termination_b": "termination_b_id",
+    "tunnel_group": "group",
     "virtual_machine_role": "role",
     "vlan_role": "role",
     "vlan_group": "group",
@@ -644,9 +718,11 @@ SLUG_REQUIRED = {
     "tags",
     "tenants",
     "tenant_groups",
+    "tunnel_groups",
     "manufacturers",
     "platforms",
     "providers",
+    "user_groups",
     "vlan_groups",
     "wireless_lan_groups",
 }
@@ -668,6 +744,7 @@ NETBOX_ARG_SPEC = dict(
     query_params=dict(required=False, type="list", elements="str"),
     validate_certs=dict(type="raw", default=True),
     cert=dict(type="raw", required=False),
+    headers=dict(type="dict", required=False),
 )
 
 
@@ -696,19 +773,22 @@ class NetboxModule(object):
         token = self.module.params["netbox_token"]
         ssl_verify = self.module.params["validate_certs"]
         cert = self.module.params["cert"]
+        headers = self.module.params["headers"]
 
         # Attempt to initiate connection to NetBox
         if nb_client is None:
-            self.nb = self._connect_netbox_api(url, token, ssl_verify, cert)
+            self.nb = self._connect_netbox_api(url, token, ssl_verify, cert, headers)
         else:
             self.nb = nb_client
             try:
-                self.version = self.nb.version
+                self.api_version = self._version_sanitize(self.nb.version)
                 try:
-                    self.full_version = self.nb.status().get("netbox-version")
+                    self.netbox_version = self._version_sanitize(
+                        self.nb.status().get("netbox-version")
+                    )
                 except Exception:
                     # For NetBox versions without /api/status endpoint
-                    self.full_version = f"{self.version}.0"
+                    self.netbox_version = f"{self.api_version}.0"
             except AttributeError:
                 self.module.fail_json(msg="Must have pynetbox >=4.1.0")
 
@@ -722,48 +802,62 @@ class NetboxModule(object):
         data = self._find_ids(choices_data, query_params)
         self.data = self._convert_identical_keys(data)
 
-    def _version_check_greater(self, greater, lesser, greater_or_equal=False):
+    @staticmethod
+    def _version_sanitize(raw_value: str) -> str:
+        """Return sanitized Netbox version.
+        Sanitize 4.2.9-Docker-3.2.1 and return only 4.2.9.
+        """
+        if not isinstance(raw_value, str):
+            raise ValueError(f"Invalid value {raw_value!r}: expected a string")
+
+        version_match = re.match(r"^(\d[\d.]*)", raw_value)
+        if version_match:
+            return version_match.group(1).rstrip(".")
+
+        raise ValueError(
+            f"Invalid version {raw_value!r}: must start with a digit (e.g. '1', '2.5', '4.2.9')"
+        )
+
+    def _version_check_greater(
+        self, greater: str, lesser: str, greater_or_equal=False
+    ) -> bool:
         """Determine if first argument is greater than second argument.
 
         Args:
             greater (str): decimal string
-            lesser (str): decimal string
+            lesser (str):  decimal string
         """
-        g_major, g_minor = greater.split(".")
-        l_major, l_minor = lesser.split(".")
+        t_greater = tuple(int(x) for x in self._version_sanitize(greater).split("."))
+        t_lesser = tuple(int(x) for x in self._version_sanitize(lesser).split("."))
 
-        # convert to ints
-        g_major = int(g_major)
-        g_minor = int(g_minor)
-        l_major = int(l_major)
-        l_minor = int(l_minor)
+        # Pad shorter tuple with zeros
+        max_len = max(len(t_greater), len(t_lesser))
+        t_greater += (0,) * (max_len - len(t_greater))
+        t_lesser += (0,) * (max_len - len(t_lesser))
 
-        # If major version is higher then return true right off the bat
-        if g_major > l_major:
-            return True
-        elif greater_or_equal and g_major == l_major and g_minor >= l_minor:
-            return True
-        # If major versions are equal, and minor version is higher, return True
-        elif g_major == l_major and g_minor > l_minor:
-            return True
+        return t_greater > t_lesser if not greater_or_equal else t_greater >= t_lesser
 
-        return False
-
-    def _connect_netbox_api(self, url, token, ssl_verify, cert):
+    def _connect_netbox_api(self, url, token, ssl_verify, cert, headers=None):
         try:
             session = requests.Session()
             session.verify = ssl_verify
+            if isinstance(headers, str):
+                headers = json.load(headers)
+            if isinstance(headers, dict):
+                session.headers.update(headers)
             if cert:
                 session.cert = tuple(i for i in cert)
             nb = pynetbox.api(url, token=token)
             nb.http_session = session
             try:
-                self.version = nb.version
+                self.api_version = self._version_sanitize(nb.version)
                 try:
-                    self.full_version = nb.status().get("netbox-version")
+                    self.netbox_version = self._version_sanitize(
+                        nb.status().get("netbox-version")
+                    )
                 except Exception:
                     # For NetBox versions without /api/status endpoint
-                    self.full_version = f"{self.version}.0"
+                    self.netbox_version = f"{self.api_version}.0"
             except AttributeError:
                 self.module.fail_json(msg="Must have pynetbox >=4.1.0")
             except Exception:
@@ -847,7 +941,7 @@ class NetboxModule(object):
         :params data (dict): Data dictionary after _find_ids method ran
         """
         temp_dict = dict()
-        if self._version_check_greater(self.version, "2.7", greater_or_equal=True):
+        if self._version_check_greater(self.api_version, "2.7", greater_or_equal=True):
             if data.get("form_factor"):
                 temp_dict["type"] = data.pop("form_factor")
 
@@ -856,7 +950,7 @@ class NetboxModule(object):
                 temp_dict[key] = data[key]
             # TODO: Remove this once the lowest supported Netbox version is 3.6 or greater as we can use default logic of CONVERT_KEYS moving forward.
             elif key == "device_role" and not self._version_check_greater(
-                self.version, "3.6", greater_or_equal=True
+                self.api_version, "3.6", greater_or_equal=True
             ):
                 temp_dict[key] = data[key]
             elif key in CONVERT_KEYS:
@@ -949,7 +1043,7 @@ class NetboxModule(object):
                     parent == "interface"
                     and "device" in module_data
                     and self._version_check_greater(
-                        self.version, "3.6", greater_or_equal=True
+                        self.api_version, "3.6", greater_or_equal=True
                     )
                 ):
                     query_dict.update(
@@ -1035,10 +1129,18 @@ class NetboxModule(object):
 
         elif parent == "rear_port_template" and self.endpoint == "front_port_templates":
             if isinstance(module_data.get("rear_port_template"), str):
-                rear_port_template = {
-                    "devicetype_id": module_data.get("device_type"),
-                    "name": module_data.get("rear_port_template"),
-                }
+                if self._version_check_greater(
+                    self.api_version, "4.0", greater_or_equal=True
+                ):
+                    rear_port_template = {
+                        "device_type_id": module_data.get("device_type"),
+                        "name": module_data.get("rear_port_template"),
+                    }
+                else:
+                    rear_port_template = {
+                        "devicetype_id": module_data.get("device_type"),
+                        "name": module_data.get("rear_port_template"),
+                    }
                 query_dict.update(rear_port_template)
 
         elif parent == "power_port" and self.endpoint == "power_outlets":
@@ -1054,10 +1156,18 @@ class NetboxModule(object):
             and self.endpoint == "power_outlet_templates"
         ):
             if isinstance(module_data.get("power_port_template"), str):
-                power_port_template = {
-                    "devicetype_id": module_data.get("device_type"),
-                    "name": module_data.get("power_port_template"),
-                }
+                if self._version_check_greater(
+                    self.api_version, "4.0", greater_or_equal=True
+                ):
+                    power_port_template = {
+                        "device_type_id": module_data.get("device_type"),
+                        "name": module_data.get("power_port_template"),
+                    }
+                else:
+                    power_port_template = {
+                        "devicetype_id": module_data.get("device_type"),
+                        "name": module_data.get("power_port_template"),
+                    }
                 query_dict.update(power_port_template)
         elif parent == "l2vpn_termination":
             query_param_mapping = {
@@ -1072,9 +1182,30 @@ class NetboxModule(object):
                     query_key: module_data.get("assigned_object_id"),
                 }
             )
+        elif parent == "module":
+            query_dict.update(
+                {
+                    "module_bay_id": query_dict.pop("module_bay"),
+                    "module_type_id": query_dict.pop("module_type"),
+                }
+            )
         elif "_template" in parent:
             if query_dict.get("device_type"):
-                query_dict["devicetype_id"] = query_dict.pop("device_type")
+                if self._version_check_greater(
+                    self.api_version, "4.0", greater_or_equal=True
+                ):
+                    query_dict["device_type_id"] = query_dict.pop("device_type")
+                else:
+                    query_dict["devicetype_id"] = query_dict.pop("device_type")
+        # TODO workaround for Netbox 4.3.0 - 4.4.3 - #20554
+        # Remove 'elif parent == "services":' block after support for
+        # Netbox 4.3.0 - 4.4.3 is removed
+        elif parent == "services":
+            if self._version_check_greater(
+                self.api_version, "4.3", greater_or_equal=True
+            ) and self._version_check_greater("4.4.4", self.netbox_version):
+                query_dict.pop("parent_object_id", None)
+                query_dict.pop("parent_object_type", None)
 
         if not query_dict:
             provided_kwargs = child.keys() if child else module_data.keys()
@@ -1082,7 +1213,9 @@ class NetboxModule(object):
                 user_query_params if user_query_params else query_params
             )
             self._handle_errors(
-                f"One or more of the kwargs provided are invalid for {parent}, provided kwargs: {', '.join(sorted(provided_kwargs))}. Acceptable kwargs: {', '.join(sorted(acceptable_query_params))}"
+                f"One or more of the kwargs provided are invalid for {parent}, provided"
+                f" kwargs: {', '.join(sorted(provided_kwargs))}. Acceptable kwargs:"
+                f" {', '.join(sorted(acceptable_query_params))}"
             )
 
         query_dict = self._convert_identical_keys(query_dict)
@@ -1096,7 +1229,12 @@ class NetboxModule(object):
             endpoint_choices = nb_endpoint.choices()
         except ValueError:
             self._handle_errors(
-                msg="Failed to fetch endpoint choices to validate against. This requires a write-enabled token. Make sure the token is write-enabled. If looking to fetch only information, use either the inventory or lookup plugin."
+                msg=(
+                    "Failed to fetch endpoint choices to validate against. This"
+                    " requires a write-enabled token. Make sure the token is"
+                    " write-enabled. If looking to fetch only information, use either"
+                    " the inventory or lookup plugin."
+                )
             )
 
         choices = list(chain.from_iterable(endpoint_choices.values()))
@@ -1139,13 +1277,15 @@ class NetboxModule(object):
             if endpoint in v.keys():
                 if "introduced" in v[endpoint]:
                     pre_introduction = self._version_check_greater(
-                        v[endpoint]["introduced"], self.version
+                        v[endpoint]["introduced"], self.api_version
                     )
                     if pre_introduction:
                         continue
                 if "deprecated" in v[endpoint]:
                     after_deprecation = self._version_check_greater(
-                        self.version, v[endpoint]["deprecated"], greater_or_equal=True
+                        self.api_version,
+                        v[endpoint]["deprecated"],
+                        greater_or_equal=True,
                     )
                     if after_deprecation:
                         continue
@@ -1165,7 +1305,7 @@ class NetboxModule(object):
             if k in CONVERT_TO_ID:
                 if (
                     not self._version_check_greater(
-                        self.version, "2.9", greater_or_equal=True
+                        self.api_version, "2.9", greater_or_equal=True
                     )
                     and k == "tags"
                 ) or (self.endpoint == "config_contexts" and k == "tags"):
@@ -1329,7 +1469,7 @@ class NetboxModule(object):
 
         # We need to assign the correct type for the assigned object so the user doesn't have to worry about this.
         # We determine it by whether or not they pass in a device or virtual_machine
-        if data.get("assigned_object"):
+        if data.get("assigned_object") and isinstance(data["assigned_object"], dict):
             if data["assigned_object"].get("device"):
                 data["assigned_object_type"] = "dcim.interface"
             if data["assigned_object"].get("virtual_machine"):
@@ -1389,7 +1529,7 @@ class NetboxModule(object):
             updated_obj["tags"] = set(data["tags"])
 
         # Ensure idempotency for site on older netbox versions
-        version_pre_30 = self._version_check_greater("3.0", self.version)
+        version_pre_30 = self._version_check_greater("3.0", self.api_version)
         if (
             serialized_nb_obj.get("latitude")
             and data.get("latitude")
@@ -1404,7 +1544,7 @@ class NetboxModule(object):
             updated_obj["longitude"] = str(data["longitude"])
 
         # Ensure idempotency for virtual machine on older netbox versions
-        version_pre_211 = self._version_check_greater("2.11", self.version)
+        version_pre_211 = self._version_check_greater("2.11", self.api_version)
         if serialized_nb_obj.get("vcpus") and data.get("vcpus"):
             if version_pre_211:
                 updated_obj["vcpus"] = int(data["vcpus"])
@@ -1412,7 +1552,7 @@ class NetboxModule(object):
                 updated_obj["vcpus"] = float(data["vcpus"])
 
         # Ensure idempotency for cable on netbox versions later than 3.3
-        version_post_33 = self._version_check_greater(self.version, "3.3", True)
+        version_post_33 = self._version_check_greater(self.api_version, "3.3", True)
         if (
             serialized_nb_obj.get("a_terminations")
             and serialized_nb_obj.get("b_terminations")
@@ -1447,11 +1587,14 @@ class NetboxModule(object):
                         data_after[key] = updated_obj[key]
                 except KeyError:
                     if key == "form_factor":
-                        msg = "form_factor is not valid for NetBox 2.7 onward. Please use the type key instead."
+                        msg = (
+                            "form_factor is not valid for NetBox 2.7 onward. Please use"
+                            " the type key instead."
+                        )
                     else:
                         msg = (
-                            "%s does not exist on existing object. Check to make sure valid field."
-                            % (key)
+                            "%s does not exist on existing object. Check to make sure"
+                            " valid field." % (key)
                         )
 
                     self._handle_errors(msg=msg)
