@@ -73,7 +73,7 @@ options:
     type: str
   now:
     description:
-    - Whether to initiate a snapshot of the protection group immeadiately
+    - Whether to initiate a snapshot of the protection group immediately
     type: bool
     default: false
   apply_retention:
@@ -83,7 +83,7 @@ options:
     default: false
   remote:
     description:
-    - Force immeadiate snapshot to remote targets
+    - Force immediate snapshot to remote targets
     type: bool
     default: false
   throttle:
@@ -95,7 +95,7 @@ options:
   with_default_protection:
     description:
     - Whether to add the default container protection groups to
-      those specified in I(add_to_pgs) as the inital protection
+      those specified in I(add_to_pgs) as the initial protection
       of a volume created from a snapshot.
     type: bool
     default: true
@@ -168,7 +168,7 @@ EXAMPLES = r"""
     api_token: e31060a7-21fc-e277-6240-25983c6c4592
     state: copy
 
-- name: Create snapshot of existing pgroup foo with suffix and force immeadiate copy to remote targets
+- name: Create snapshot of existing pgroup foo with suffix and force immediate copy to remote targets
   purestorage.flasharray.purefa_pgsnap:
     name: pgname
     suffix: force
@@ -293,22 +293,20 @@ def get_pgroupvolume(module, array):
                         group_names=[module.params["name"]]
                     ).items
                 )
-            for host in range(0, len(host_dict)):
+            for host in host_dict:
                 if LooseVersion(CONTEXT_API_VERSION) <= LooseVersion(api_version):
                     hostvols = list(
                         array.get_connections(
                             context_names=[module.params["context"]],
-                            host_names=[host_dict[host].member["name"]],
+                            host_names=[host.member["name"]],
                         ).items
                     )
                 else:
                     hostvols = list(
-                        array.get_connections(
-                            host_names=[host_dict[host].member["name"]]
-                        ).items
+                        array.get_connections(host_names=[host.member["name"]]).items
                     )
-                for hvol in range(0, len(hostvols)):
-                    volumes.append(hostvols[hvol].volume["name"])
+                for hvol in hostvols:
+                    volumes.append(hvol.volume["name"])
         elif pgroup.host_group_count > 0:  # We have a hostgroup PG
             if LooseVersion(CONTEXT_API_VERSION) <= LooseVersion(api_version):
                 hgroup_dict = list(
@@ -324,53 +322,53 @@ def get_pgroupvolume(module, array):
                     ).items
                 )
             # First check if there are any volumes in the host groups
-            for hgentry in range(0, len(hgroup_dict)):
+            for hgentry in hgroup_dict:
                 if LooseVersion(CONTEXT_API_VERSION) <= LooseVersion(api_version):
                     hgvols = list(
                         array.get_connections(
                             context_names=[module.params["context"]],
-                            host_group_names=[hgroup_dict[hgentry].member["name"]],
+                            host_group_names=[hgentry.member["name"]],
                         ).items
                     )
                 else:
                     hgvols = list(
                         array.get_connections(
-                            host_group_names=[hgroup_dict[hgentry].member["name"]]
+                            host_group_names=[hgentry.member["name"]]
                         ).items
                     )
-                for hgvol in range(0, len(hgvols)):
-                    volumes.append(hgvols[hgvol].volume["name"])
+                for hgvol in hgvols:
+                    volumes.append(hgvol.volume["name"])
             # Second check for host specific volumes
-            for hgroup in range(0, len(hgroup_dict)):
+            for hgroup in hgroup_dict:
                 if LooseVersion(CONTEXT_API_VERSION) <= LooseVersion(api_version):
                     hg_hosts = list(
                         array.get_host_groups_hosts(
                             context_names=[module.params["context"]],
-                            group_names=[hgroup_dict[hgroup].member["name"]],
+                            group_names=[hgroup.member["name"]],
                         ).items
                     )
                 else:
                     hg_hosts = list(
                         array.get_host_groups_hosts(
-                            group_names=[hgroup_dict[hgroup].member["name"]]
+                            group_names=[hgroup.member["name"]]
                         ).items
                     )
-                for hg_host in range(0, len(hg_hosts)):
+                for hg_host in hg_hosts:
                     if LooseVersion(CONTEXT_API_VERSION) <= LooseVersion(api_version):
                         host_vols = list(
                             array.get_connections(
                                 context_names=[module.params["context"]],
-                                host_names=[hg_hosts[hg_host].member["name"]],
+                                host_names=[hg_host.member["name"]],
                             ).items
                         )
                     else:
                         host_vols = list(
                             array.get_connections(
-                                host_names=[hg_hosts[hg_host].member["name"]]
+                                host_names=[hg_host.member["name"]]
                             ).items
                         )
-                    for host_vol in range(0, len(host_vols)):
-                        volumes.append(host_vols[host_vol].volume["name"])
+                    for host_vol in host_vols:
+                        volumes.append(host_vol.volume["name"])
         else:  # We have a volume PG
             if LooseVersion(CONTEXT_API_VERSION) <= LooseVersion(api_version):
                 vol_dict = list(
@@ -385,8 +383,8 @@ def get_pgroupvolume(module, array):
                         group_names=[module.params["name"]]
                     ).items
                 )
-            for entry in range(0, len(vol_dict)):
-                volumes.append(vol_dict[entry].member["name"])
+            for entry in vol_dict:
+                volumes.append(entry.member["name"])
         volumes = list(set(volumes))
         if "::" in module.params["name"]:
             restore_volume = (
@@ -625,10 +623,8 @@ def restore_pgsnapvolume(module, array):
         if LooseVersion(DEFAULT_API) <= LooseVersion(array.get_rest_version()):
             if module.params["add_to_pgs"]:
                 add_to_pgs = []
-                for add_pg in range(0, len(module.params["add_to_pgs"])):
-                    add_to_pgs.append(
-                        FixedReference(name=module.params["add_to_pgs"][add_pg])
-                    )
+                for add_pg in module.params["add_to_pgs"]:
+                    add_to_pgs.append(FixedReference(name=add_pg))
                 if LooseVersion(CONTEXT_API_VERSION) <= LooseVersion(api_version):
                     res = array.post_volumes(
                         names=[module.params["target"]],
@@ -978,7 +974,7 @@ def main():
             module.params["add_to_pgs"] or module.params["with_default_protection"]
         ):
             module.fail_json(
-                msg="overwrite and add_to_pgs or with_default_protection are incompatable"
+                msg="overwrite and add_to_pgs or with_default_protection are incompatible"
             )
         restore_pgsnapvolume(module, array)
     elif state == "present" and not pgsnap:
